@@ -2,7 +2,7 @@
 
     File: adv.c
 
-    Copyright (C) 1998-2006 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 1998-2007 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -35,64 +35,45 @@
 #include "common.h"
 #include "lang.h"
 #include "intrf.h"
+#include "intrfn.h"
 #include "fnctdsk.h"
 #include "chgtype.h"
 #include "testdisk.h"
 #include "dirpart.h"
 #include "fat.h"
 #include "ntfs.h"
+#include "hfs.h"
 #include "hfsp.h"
 #include "adv.h"
 #include "analyse.h"
 #include "intrface.h"
 #include "io_redir.h"
+#include "log.h"
 
 #define INTER_ADV_X	0
 #define INTER_ADV_Y	23
 #define INTER_ADV	15
 
-static int is_hfsp(const t_partition *partition);
-static int is_linux(const t_partition *partition);
+static int is_hfs(const partition_t *partition);
+static int is_hfsp(const partition_t *partition);
+static int is_linux(const partition_t *partition);
+static int is_part_hfs(const partition_t *partition);
+static int is_part_hfsp(const partition_t *partition);
 
-static int is_hfsp(const t_partition *partition)
+static int is_hfs(const partition_t *partition)
 {
-  switch(partition->part_type_i386)
-  {
-    case P_HFSP:
-      return 1;
-  }
-  switch(partition->part_type_mac)
-  {
-    case PMAC_HFS:
-      return 1;
-  }
-  switch(partition->upart_type)
-  {
-    case UP_HFSP:
-      return 1;
-    default:
-      break;
-  }
-  return 0;
+  return (is_part_hfs(partition) || partition->upart_type==UP_HFS);
 }
 
-static int is_linux(const t_partition *partition)
+static int is_hfsp(const partition_t *partition)
 {
-  switch(partition->part_type_i386)
-  {
-    case P_LINUX:
-      return 1;
-  }
-  switch(partition->part_type_sun)
-  {
-    case PSUN_LINUX:
-      return 1;
-  }
-  switch(partition->part_type_mac)
-  {
-    case PMAC_LINUX:
-      return 1;
-  }
+  return (is_part_hfsp(partition) || partition->upart_type==UP_HFSP);
+}
+
+static int is_linux(const partition_t *partition)
+{
+  if(is_part_linux(partition))
+    return 1;
   switch(partition->upart_type)
   {
     case UP_CRAMFS:
@@ -114,22 +95,72 @@ static int is_linux(const t_partition *partition)
   return 0;
 }
 
-void interface_adv(t_param_disk *disk_car, const int debug,const int dump_ind, const unsigned int expert, char**current_cmd)
+static int is_part_hfs(const partition_t *partition)
+{
+  switch(partition->part_type_i386)
+  {
+    case P_HFS:
+      return 1;
+  }
+  switch(partition->part_type_mac)
+  {
+    case PMAC_HFS:
+      return 1;
+  }
+  return 0;
+}
+
+static int is_part_hfsp(const partition_t *partition)
+{
+  switch(partition->part_type_i386)
+  {
+    case P_HFSP:
+      return 1;
+  }
+  switch(partition->part_type_mac)
+  {
+    case PMAC_HFS:
+      return 1;
+  }
+  return 0;
+}
+
+int is_part_linux(const partition_t *partition)
+{
+  switch(partition->part_type_i386)
+  {
+    case P_LINUX:
+      return 1;
+  }
+  switch(partition->part_type_sun)
+  {
+    case PSUN_LINUX:
+      return 1;
+  }
+  switch(partition->part_type_mac)
+  {
+    case PMAC_LINUX:
+      return 1;
+  }
+  return 0;
+}
+
+void interface_adv(disk_t *disk_car, const int debug,const int dump_ind, const unsigned int expert, char**current_cmd)
 {
   int quit;
   int offset=0;
   int current_element_num=0;
   int rewrite=1;
   const char *options;
-  t_list_part *element;
-  t_list_part *list_part;
-  t_list_part *current_element;
-  ecrit_rapport("\nInterface Advanced\n");
+  list_part_t *element;
+  list_part_t *list_part;
+  list_part_t *current_element;
+  log_info("\nInterface Advanced\n");
   list_part=disk_car->arch->read_part(disk_car,debug,0);
   current_element=list_part;
   for(element=list_part;element!=NULL;element=element->next)
   {
-    aff_part_rapport(disk_car,element->part);
+    log_partition(disk_car,element->part);
   }
   do
   {
@@ -138,6 +169,7 @@ void interface_adv(t_param_disk *disk_car, const int debug,const int dump_ind, c
       {'t',"Type","Change type, this setting will not be saved on disk"},
       {'b',"Boot","Boot sector recovery"},
       {'s',"Superblock",NULL},
+//      {'a',"Add", "Add temporary partition (Expert only)"},
       {'q',"Quit","Return to main menu"},
       {0,NULL,NULL}
     };
@@ -160,9 +192,9 @@ void interface_adv(t_param_disk *disk_car, const int debug,const int dump_ind, c
       wclrtoeol(stdscr);	/* before addstr for BSD compatibility */
       if(element==current_element)
       {
-	wattrset(stdscr,A_STANDOUT);
+	wattrset(stdscr, A_REVERSE);
 	aff_part(stdscr,AFF_PART_ORDER,disk_car,element->part);
-	wattroff(stdscr,A_STANDOUT);
+	wattroff(stdscr, A_REVERSE);
       } else
       {
 	aff_part(stdscr,AFF_PART_ORDER,disk_car,element->part);
@@ -173,13 +205,31 @@ void interface_adv(t_param_disk *disk_car, const int debug,const int dump_ind, c
     {
       options="q";
       wmove(stdscr,5+2,0);
-      wattrset(stdscr,A_STANDOUT);
+      wattrset(stdscr, A_REVERSE);
       wdoprintf(stdscr,"No partition available.");
-      wattroff(stdscr,A_STANDOUT);
+      wattroff(stdscr, A_REVERSE);
     }
     else
     {
-      if(is_fat(current_element->part) ||
+      if(is_part_fat(current_element->part) ||
+	  is_part_ntfs(current_element->part))
+      {
+	options="tbq";
+	menu=1;
+      }
+      else if(is_part_linux(current_element->part))
+      {
+	options="tsq";
+	menuAdv[2].desc="Locate EXT2/EXT3 backup superblock";
+	menu=1;
+      }
+      else if(is_part_hfs(current_element->part) || is_part_hfsp(current_element->part))
+      {
+	options="tsq";
+	menuAdv[2].desc="Locate HFS/HFS+ backup superblock";
+	menu=1;
+      }
+      else if(is_fat(current_element->part) ||
 	  is_ntfs(current_element->part))
       {
 	options="tbq";
@@ -191,10 +241,10 @@ void interface_adv(t_param_disk *disk_car, const int debug,const int dump_ind, c
 	menuAdv[2].desc="Locate EXT2/EXT3 backup superblock";
 	menu=1;
       }
-      else if(is_hfsp(current_element->part))
+      else if(is_hfs(current_element->part) || is_hfsp(current_element->part))
       {
 	options="tsq";
-	menuAdv[2].desc="Locate HFS+ backup superblock";
+	menuAdv[2].desc="Locate HFS/HFS+ backup superblock";
 	menu=1;
       }
       else
@@ -273,21 +323,44 @@ void interface_adv(t_param_disk *disk_car, const int debug,const int dump_ind, c
       case 'Q':
 	quit=1;
 	break;
+      case 'a':
+      case 'A':
+	{
+	  list_part=disk_car->arch->add_partition(disk_car,list_part, debug, current_cmd);
+	  current_element=list_part;
+	  rewrite=1;
+	}
+	break;
       case 'b':
       case 'B':
 	if(current_element!=NULL)
 	{
-	  if(is_fat32(current_element->part))
+	  if(is_part_fat32(current_element->part))
 	  {
 	    fat32_boot_sector(disk_car, current_element->part, debug, dump_ind, expert,current_cmd);
 	    rewrite=1;
 	  }
-	  else if(is_fat(current_element->part))
+	  else if(is_part_fat12(current_element->part) || is_part_fat16(current_element->part))
 	  {
 	    fat1x_boot_sector(disk_car, current_element->part, debug, dump_ind,expert,current_cmd);
 	    rewrite=1;
 	  }
-	  else if(is_ntfs(current_element->part))
+	  else if(is_part_ntfs(current_element->part))
+	  {
+	    ntfs_boot_sector(disk_car, current_element->part, debug, dump_ind, expert, current_cmd);
+	    rewrite=1;
+	  }
+	  else if(current_element->part->upart_type==UP_FAT32)
+	  {
+	    fat32_boot_sector(disk_car, current_element->part, debug, dump_ind, expert,current_cmd);
+	    rewrite=1;
+	  }
+	  else if(current_element->part->upart_type==UP_FAT12 || current_element->part->upart_type==UP_FAT16)
+	  {
+	    fat1x_boot_sector(disk_car, current_element->part, debug, dump_ind,expert,current_cmd);
+	    rewrite=1;
+	  }
+	  else if(current_element->part->upart_type==UP_NTFS)
 	  {
 	    ntfs_boot_sector(disk_car, current_element->part, debug, dump_ind, expert, current_cmd);
 	    rewrite=1;
@@ -300,13 +373,13 @@ void interface_adv(t_param_disk *disk_car, const int debug,const int dump_ind, c
 	{
 	  if(is_linux(current_element->part))
 	  {
-	    t_list_part *list_sb=search_superblock(disk_car,current_element->part,debug,dump_ind,1);
+	    list_part_t *list_sb=search_superblock(disk_car,current_element->part,debug,dump_ind,1);
 	    interface_superblock(disk_car,list_sb,current_cmd);
 	    delete_list_part(list_sb);
 	  }
-	  if(is_hfsp(current_element->part))
+	  if(is_hfs(current_element->part) || is_hfsp(current_element->part))
 	  {
-	    HFSP_boot_sector(disk_car, current_element->part, debug, dump_ind, expert, current_cmd);
+	    HFS_HFSP_boot_sector(disk_car, current_element->part, debug, dump_ind, expert, current_cmd);
 	  }
 	  rewrite=1;
 	}
@@ -324,7 +397,7 @@ void interface_adv(t_param_disk *disk_car, const int debug,const int dump_ind, c
   delete_list_part(list_part);
 }
 
-int fat1x_boot_sector(t_param_disk *disk_car, t_partition *partition, const int debug, const int dump_ind, const unsigned int expert, char **current_cmd)
+int fat1x_boot_sector(disk_t *disk_car, partition_t *partition, const int debug, const int dump_ind, const unsigned int expert, char **current_cmd)
 {
   unsigned char *buffer_bs;
   const char *options="DR";
@@ -353,8 +426,8 @@ int fat1x_boot_sector(t_param_disk *disk_car, t_partition *partition, const int
       mvwaddstr(stdscr,5,0,msg_PART_HEADER_LONG);
       wmove(stdscr,6,0);
       aff_part(stdscr,AFF_PART_ORDER,disk_car,partition);
-      ecrit_rapport("\nfat1x_boot_sector\n");
-      aff_part_rapport(disk_car,partition);
+      log_info("\nfat1x_boot_sector\n");
+      log_partition(disk_car,partition);
       if(expert==0)
 	options="DRC";
       else
@@ -423,7 +496,7 @@ int fat1x_boot_sector(t_param_disk *disk_car, t_partition *partition, const int
 	  wdoprintf(window,"%s",disk_car->description(disk_car));
 	  wmove(window,5,0);
 	  aff_part(window,AFF_PART_ORDER,disk_car,partition);
-	  ecrit_rapport("Boot sector\n");
+	  log_info("Boot sector\n");
 	  mvwaddstr(window,6,0, "Boot sector");
 	  dump(window,buffer_bs,FAT1x_BOOT_SECTOR_SIZE);
 	  delwin(window);
@@ -443,7 +516,7 @@ int fat1x_boot_sector(t_param_disk *disk_car, t_partition *partition, const int
   }
 }
 
-int fat32_boot_sector(t_param_disk *disk_car, t_partition *partition, const int debug, const int dump_ind, const unsigned int expert, char **current_cmd)
+int fat32_boot_sector(disk_t *disk_car, partition_t *partition, const int debug, const int dump_ind, const unsigned int expert, char **current_cmd)
 {
   unsigned char *buffer_bs;
   unsigned char *buffer_backup_bs;
@@ -479,8 +552,8 @@ int fat32_boot_sector(t_param_disk *disk_car, t_partition *partition, const int
       mvwaddstr(stdscr,5,0,msg_PART_HEADER_LONG);
       wmove(stdscr,6,0);
       aff_part(stdscr,AFF_PART_ORDER,disk_car,partition);
-      ecrit_rapport("\nfat32_boot_sector\n");
-      aff_part_rapport(disk_car,partition);
+      log_info("\nfat32_boot_sector\n");
+      log_partition(disk_car,partition);
       aff_buffer(BUFFER_ADD,"Boot sector\n");
       if(disk_car->read(disk_car,3*disk_car->sector_size, buffer_bs, partition->part_offset)!=0)
       {
@@ -595,7 +668,7 @@ int fat32_boot_sector(t_param_disk *disk_car, t_partition *partition, const int
       case 'O': /* O : copy original boot sector over backup boot */
 	if(ask_confirmation("Copy original FAT32 boot sector over backup boot, confirm ? (Y/N)")!=0)
 	{
-	  ecrit_rapport("copy original boot sector over backup boot\n");
+	  log_info("copy original boot sector over backup boot\n");
 	  if(disk_car->write(disk_car,3*disk_car->sector_size, buffer_bs, partition->part_offset+6*disk_car->sector_size)!=0)
 	  {
 	    display_message("Write error: Can't overwrite FAT32 backup boot sector\n");
@@ -606,7 +679,7 @@ int fat32_boot_sector(t_param_disk *disk_car, t_partition *partition, const int
       case 'B': /* B : copy backup boot sector over boot sector */
 	if(ask_confirmation("Copy backup FAT32 boot sector over boot sector, confirm ? (Y/N)")!=0)
 	{
-	  ecrit_rapport("copy backup boot sector over boot sector\n");
+	  log_info("copy backup boot sector over boot sector\n");
 	  if(disk_car->write(disk_car,3*disk_car->sector_size, buffer_backup_bs, partition->part_offset)!=0)
 	  {
 	    display_message("Write error: Can't overwrite FAT32 boot sector\n");
@@ -627,7 +700,7 @@ int fat32_boot_sector(t_param_disk *disk_car, t_partition *partition, const int
 	  wdoprintf(window,"%s",disk_car->description(disk_car));
 	  wmove(window,5,0);
 	  aff_part(window,AFF_PART_ORDER,disk_car,partition);
-	  ecrit_rapport("Boot sector                        Backup boot sector\n");
+	  log_info("Boot sector                        Backup boot sector\n");
 	  mvwaddstr(window,6,0, "Boot sector                        Backup boot sector");
 	  dump2(window,buffer_bs,buffer_backup_bs,3*disk_car->sector_size);
 	  delwin(window);
@@ -635,7 +708,7 @@ int fat32_boot_sector(t_param_disk *disk_car, t_partition *partition, const int
 #ifdef HAVE_TOUCHWIN
 	  touchwin(stdscr);
 #endif
-	  dump_2fat_rapport((const struct fat_boot_sector*)buffer_bs,(const struct fat_boot_sector*)buffer_backup_bs,UP_FAT32,disk_car->sector_size);
+	  log_fat2_dump((const struct fat_boot_sector*)buffer_bs,(const struct fat_boot_sector*)buffer_backup_bs,UP_FAT32,disk_car->sector_size);
 	}
 	break;
       case 'C':
@@ -645,7 +718,7 @@ int fat32_boot_sector(t_param_disk *disk_car, t_partition *partition, const int
   }
 }
 
-int ntfs_boot_sector(t_param_disk *disk_car, t_partition *partition, const int debug, const int dump_ind, const unsigned int expert, char **current_cmd)
+int ntfs_boot_sector(disk_t *disk_car, partition_t *partition, const int debug, const int dump_ind, const unsigned int expert, char **current_cmd)
 {
   unsigned char *buffer_bs;
   unsigned char *buffer_backup_bs;
@@ -662,6 +735,9 @@ int ntfs_boot_sector(t_param_disk *disk_car, t_partition *partition, const int d
     { 'R', "Rebuild BS","Rebuild boot sector"},
     { 'M', "Repair MFT","Check MFT"},
     { 'D', "Dump","Dump boot sector and backup boot sector"},
+#if 0
+    { 'U', "Undelete","Recover deleted files"},
+#endif
     { 0, NULL, NULL }
   };
   buffer_bs=(unsigned char*)MALLOC(NTFS_BOOT_SECTOR_SIZE);
@@ -676,6 +752,7 @@ int ntfs_boot_sector(t_param_disk *disk_car, t_partition *partition, const int d
       int opt_over=0;
       int opt_B=0;
       int opt_O=0;
+//      options="DRMLU";
       options="DRML";
       aff_copy(stdscr);
       wmove(stdscr,4,0);
@@ -683,8 +760,8 @@ int ntfs_boot_sector(t_param_disk *disk_car, t_partition *partition, const int d
       mvwaddstr(stdscr,5,0,msg_PART_HEADER_LONG);
       wmove(stdscr,6,0);
       aff_part(stdscr,AFF_PART_ORDER,disk_car,partition);
-      ecrit_rapport("\nntfs_boot_sector\n");
-      aff_part_rapport(disk_car,partition);
+      log_info("\nntfs_boot_sector\n");
+      log_partition(disk_car,partition);
       aff_buffer(BUFFER_ADD,"Boot sector\n");
       if(disk_car->read(disk_car,NTFS_BOOT_SECTOR_SIZE, buffer_bs, partition->part_offset)!=0)
       {
@@ -720,13 +797,13 @@ int ntfs_boot_sector(t_param_disk *disk_car, t_partition *partition, const int d
       aff_buffer(BUFFER_ADD,"\n");
       if(memcmp(buffer_bs,buffer_backup_bs,NTFS_BOOT_SECTOR_SIZE)==0)
       {
-	dump_ntfs_rapport((const struct ntfs_boot_sector *)buffer_bs);
+	log_ntfs_dump((const struct ntfs_boot_sector *)buffer_bs);
 	aff_buffer(BUFFER_ADD,"Sectors are identical.\n");
 	opt_over=0;
       }
       else
       {
-	dump_2ntfs_rapport((const struct ntfs_boot_sector *)buffer_bs, (const struct ntfs_boot_sector *)buffer_backup_bs);
+	log_ntfs2_dump((const struct ntfs_boot_sector *)buffer_bs, (const struct ntfs_boot_sector *)buffer_backup_bs);
 	aff_buffer(BUFFER_ADD,"Sectors are not identical.\n");
       }
       aff_buffer(BUFFER_ADD,"\n");
@@ -775,6 +852,12 @@ int ntfs_boot_sector(t_param_disk *disk_car, t_partition *partition, const int d
 	if(strchr(options,'B')!=NULL)
 	    command='B';
       }
+      else if(strncmp(*current_cmd,"repairmft",9)==0)
+      {
+	(*current_cmd)+=9;
+	if(strchr(options,'M')!=NULL)
+	    command='M';
+      }
       screen_buffer_to_log();
     }
     else
@@ -788,7 +871,7 @@ int ntfs_boot_sector(t_param_disk *disk_car, t_partition *partition, const int d
       case 'O': /* O : copy original boot sector over backup boot */
 	if(ask_confirmation("Copy original NTFS boot sector over backup boot, confirm ? (Y/N)")!=0)
 	{
-	  ecrit_rapport("copy original boot sector over backup boot\n");
+	  log_info("copy original boot sector over backup boot\n");
 	  if(disk_car->write(disk_car,NTFS_BOOT_SECTOR_SIZE, buffer_bs, partition->part_offset+partition->part_size-disk_car->sector_size)!=0)
 	  {
 	    display_message("Write error: Can't overwrite NTFS backup boot sector\n");
@@ -799,7 +882,7 @@ int ntfs_boot_sector(t_param_disk *disk_car, t_partition *partition, const int d
       case 'B': /* B : copy backup boot sector over boot sector */
 	if(ask_confirmation("Copy backup NTFS boot sector over boot sector, confirm ? (Y/N)")!=0)
 	{
-	  ecrit_rapport("copy backup boot sector over boot sector\n");
+	  log_info("copy backup boot sector over boot sector\n");
 	  if(disk_car->write(disk_car,NTFS_BOOT_SECTOR_SIZE, buffer_backup_bs, partition->part_offset)!=0)
 	  {
 	    display_message("Write error: Can't overwrite NTFS boot sector\n");
@@ -818,7 +901,7 @@ int ntfs_boot_sector(t_param_disk *disk_car, t_partition *partition, const int d
 	  dir_partition(disk_car, partition, 0,current_cmd);
 	break;
       case 'M':
-        repair_MFT(disk_car, partition, debug);
+        repair_MFT(disk_car, partition, debug, current_cmd);
 	break;
       case 'R': /* R : rebuild boot sector */
 	rebuild_NTFS_BS(disk_car,partition,debug,dump_ind,1,expert,current_cmd);
@@ -833,7 +916,7 @@ int ntfs_boot_sector(t_param_disk *disk_car, t_partition *partition, const int d
 	  wdoprintf(window,"%s",disk_car->description(disk_car));
 	  wmove(window,5,0);
 	  aff_part(window,AFF_PART_ORDER,disk_car,partition);
-	  ecrit_rapport("Boot sector                        Backup boot sector\n");
+	  log_info("Boot sector                        Backup boot sector\n");
 	  mvwaddstr(window,6,0, "Boot sector                        Backup boot sector");
 	  dump2(window,buffer_bs,buffer_backup_bs,NTFS_BOOT_SECTOR_SIZE);
 	  delwin(window);
@@ -843,11 +926,18 @@ int ntfs_boot_sector(t_param_disk *disk_car, t_partition *partition, const int d
 #endif
 	}
 	break;
+#if 0
+#ifdef HAVE_LIBNTFS
+      case 'U':
+	ntfs_undelete_part(disk_car, partition, debug);
+	break;
+#endif
+#endif
     }
   }
 }
 
-int HFSP_boot_sector(t_param_disk *disk_car, t_partition *partition, const int debug, const int dump_ind, const unsigned int expert, char **current_cmd)
+int HFS_HFSP_boot_sector(disk_t *disk_car, partition_t *partition, const int debug, const int dump_ind, const unsigned int expert, char **current_cmd)
 {
   unsigned char *buffer_bs;
   unsigned char *buffer_backup_bs;
@@ -882,40 +972,48 @@ int HFSP_boot_sector(t_param_disk *disk_car, t_partition *partition, const int d
       mvwaddstr(stdscr,5,0,msg_PART_HEADER_LONG);
       wmove(stdscr,6,0);
       aff_part(stdscr,AFF_PART_ORDER,disk_car,partition);
-      ecrit_rapport("\nHFSP_boot_sector\n");
-      aff_part_rapport(disk_car,partition);
+      log_info("\nHFS_HFSP_boot_sector\n");
+      log_partition(disk_car,partition);
       aff_buffer(BUFFER_ADD,"Superblock\n");
       if(disk_car->read(disk_car,HFSP_BOOT_SECTOR_SIZE, buffer_bs, partition->part_offset+0x400)!=0)
       {
-	aff_buffer(BUFFER_ADD,"HFSP_boot_sector: Can't read superblock.\n");
+	aff_buffer(BUFFER_ADD,"Bad: can't read HFS/HFS+ superblock.\n");
 	memset(buffer_bs,0,HFSP_BOOT_SECTOR_SIZE);
       }
-      if(test_HFSP(disk_car,(struct hfsp_vh*)buffer_bs,partition,debug,0)==0)
+      else if(test_HFSP(disk_car,(const struct hfsp_vh*)buffer_bs,partition,debug,0)==0)
       {
-	aff_buffer(BUFFER_ADD,"OK\n");
+	aff_buffer(BUFFER_ADD,"HFS+ OK\n");
+	opt_O=1;
+	opt_over=1;
+      }
+      else if(test_HFS(disk_car,(const hfs_mdb_t*)buffer_bs,partition,debug,0)==0)
+      {
+	aff_buffer(BUFFER_ADD,"HFS Ok\n");
 	opt_O=1;
 	opt_over=1;
       }
       else
-      {
 	aff_buffer(BUFFER_ADD,"Bad\n");
-      }
       aff_buffer(BUFFER_ADD,"\nBackup superblock\n");
       if(disk_car->read(disk_car,HFSP_BOOT_SECTOR_SIZE, buffer_backup_bs, partition->part_offset+partition->part_size-0x400)!=0)
       {
-	aff_buffer(BUFFER_ADD,"HFSP_boot_sector: Can't read backup superblock.\n");
+	aff_buffer(BUFFER_ADD,"Bad: can't read HFS/HFS+ backup superblock.\n");
 	memset(buffer_backup_bs,0,HFSP_BOOT_SECTOR_SIZE);
       }
-      if(test_HFSP(disk_car,(struct hfsp_vh*)buffer_backup_bs,partition,debug,0)==0)
+      else if(test_HFSP(disk_car,(const struct hfsp_vh*)buffer_backup_bs,partition,debug,0)==0)
       {
-	aff_buffer(BUFFER_ADD,"OK\n");
+	aff_buffer(BUFFER_ADD,"HFS+ OK\n");
+	opt_B=1;
+	opt_over=1;
+      }
+      else if(test_HFS(disk_car,(const hfs_mdb_t*)buffer_backup_bs,partition,debug,0)==0)
+      {
+	aff_buffer(BUFFER_ADD,"HFS Ok\n");
 	opt_B=1;
 	opt_over=1;
       }
       else
-      {
 	aff_buffer(BUFFER_ADD,"Bad\n");
-      }
       aff_buffer(BUFFER_ADD,"\n");
       if(memcmp(buffer_bs,buffer_backup_bs,HFSP_BOOT_SECTOR_SIZE)==0)
       {
@@ -970,23 +1068,23 @@ int HFSP_boot_sector(t_param_disk *disk_car, t_partition *partition, const int d
         free(buffer_backup_bs);
 	return 0;
       case 'O': /* O : copy original superblock over backup boot */
-	if(ask_confirmation("Copy original HFSP superblock over backup boot, confirm ? (Y/N)")!=0)
+	if(ask_confirmation("Copy original HFS/HFS+ superblock over backup boot, confirm ? (Y/N)")!=0)
 	{
-	  ecrit_rapport("copy original superblock over backup boot\n");
+	  log_info("copy original superblock over backup boot\n");
 	  if(disk_car->write(disk_car,HFSP_BOOT_SECTOR_SIZE, buffer_bs, partition->part_offset+partition->part_size-0x400)!=0)
 	  {
-	    display_message("Write error: Can't overwrite HFSP backup superblock\n");
+	    display_message("Write error: Can't overwrite HFS/HFS+ backup superblock\n");
 	  }
 	  rescan=1;
 	}
 	break;
       case 'B': /* B : copy backup superblock over main superblock */
-	if(ask_confirmation("Copy backup HFSP superblock over main superblock, confirm ? (Y/N)")!=0)
+	if(ask_confirmation("Copy backup HFS/HFS+ superblock over main superblock, confirm ? (Y/N)")!=0)
 	{
-	  ecrit_rapport("copy backup superblock over main superblock\n");
+	  log_info("copy backup superblock over main superblock\n");
 	  if(disk_car->write(disk_car,HFSP_BOOT_SECTOR_SIZE, buffer_backup_bs, partition->part_offset+0x400)!=0)
 	  {
-	    display_message("Write error: Can't overwrite HFSP main superblock\n");
+	    display_message("Write error: Can't overwrite HFS/HFS+ main superblock\n");
 	  }
 	  rescan=1;
 	}
@@ -1000,7 +1098,7 @@ int HFSP_boot_sector(t_param_disk *disk_car, t_partition *partition, const int d
 	  wdoprintf(window,"%s",disk_car->description(disk_car));
 	  wmove(window,5,0);
 	  aff_part(window,AFF_PART_ORDER,disk_car,partition);
-	  ecrit_rapport("Superblock                        Backup superblock\n");
+	  log_info("Superblock                        Backup superblock\n");
 	  mvwaddstr(window,6,0, "Superblock                        Backup superblock");
 	  dump2(window,buffer_bs,buffer_backup_bs,HFSP_BOOT_SECTOR_SIZE);
 	  delwin(window);
