@@ -2,7 +2,7 @@
 
     File: analyse.c
 
-    Copyright (C) 1998-2006 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 1998-2007 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -34,6 +34,7 @@
 #include "fnctdsk.h"
 #include "analyse.h"
 #include "intrf.h"
+#include "intrfn.h"
 #include "savehdr.h"
 #include "lang.h"
 #include "bfs.h"
@@ -56,22 +57,20 @@
 #include "sysv.h"
 #include "ufs.h"
 #include "xfs.h"
+#include "log.h"
 
-int search_NTFS_backup(unsigned char *buffer, t_param_disk *disk_car,t_partition *partition, const int debug, const int dump_ind)
+int search_NTFS_backup(unsigned char *buffer, disk_t *disk_car,partition_t *partition, const int debug, const int dump_ind)
 {
 //  assert(sizeof(struct ntfs_boot_sector)<=DEFAULT_SECTOR_SIZE);
   if(disk_car->read(disk_car,DEFAULT_SECTOR_SIZE, buffer, partition->part_offset)!=0)
     return -1;
   /* NTFS recovery using backup sector */
-  if(recover_NTFS(disk_car,(struct ntfs_boot_sector*)buffer,partition,debug,dump_ind,1)==0)
-  {
-    strncpy(partition->info,"NTFS found using backup sector!",sizeof(partition->info));
+  if(recover_NTFS(disk_car,(const struct ntfs_boot_sector*)buffer,partition,debug,dump_ind,1)==0)
     return 1;
-  }
   return 0;
 }
 
-int search_HFS_backup(unsigned char *buffer, t_param_disk *disk_car,t_partition *partition, const int debug, const int dump_ind)
+int search_HFS_backup(unsigned char *buffer, disk_t *disk_car,partition_t *partition, const int debug, const int dump_ind)
 {
 //  assert(sizeof(hfs_mdb_t)<=0x400);
 //  assert(sizeof(struct hfsp_vh)==0x200);
@@ -91,7 +90,7 @@ int search_HFS_backup(unsigned char *buffer, t_param_disk *disk_car,t_partition
   return 0;
 }
 
-int search_FAT_backup(unsigned char *buffer, t_param_disk *disk_car,t_partition *partition, const int debug, const int dump_ind)
+int search_FAT_backup(unsigned char *buffer, disk_t *disk_car,partition_t *partition, const int debug, const int dump_ind)
 {
 //  assert(sizeof(struct fat_boot_sector)==DEFAULT_SECTOR_SIZE);
   if(disk_car->read(disk_car,DEFAULT_SECTOR_SIZE, buffer, partition->part_offset)!=0)
@@ -105,7 +104,7 @@ int search_FAT_backup(unsigned char *buffer, t_param_disk *disk_car,t_partition
   return 0;
 }
 
-int search_type_0(unsigned char *buffer,t_param_disk *disk_car,t_partition *partition, const int debug, const int dump_ind)
+int search_type_0(unsigned char *buffer,disk_t *disk_car,partition_t *partition, const int debug, const int dump_ind)
 {
 //  assert(sizeof(union swap_header)<=8*DEFAULT_SECTOR_SIZE);
 //  assert(sizeof(pv_disk_t)<=8*DEFAULT_SECTOR_SIZE);
@@ -116,7 +115,7 @@ int search_type_0(unsigned char *buffer,t_param_disk *disk_car,t_partition *part
 //  assert(sizeof(struct disk_fatx)<=8*DEFAULT_SECTOR_SIZE);
   if(debug>2)
   {
-    ecrit_rapport("search_type_0 lba=%lu\n",(long unsigned)(partition->part_offset/disk_car->sector_size));
+    log_trace("search_type_0 lba=%lu\n",(long unsigned)(partition->part_offset/disk_car->sector_size));
   }
   if(disk_car->read(disk_car,8*DEFAULT_SECTOR_SIZE, buffer, partition->part_offset)!=0)
     return -1;
@@ -132,7 +131,7 @@ int search_type_0(unsigned char *buffer,t_param_disk *disk_car,t_partition *part
   return 0;
 }
 
-int search_type_1(unsigned char *buffer, t_param_disk *disk_car,t_partition *partition,const int debug, const int dump_ind)
+int search_type_1(unsigned char *buffer, disk_t *disk_car,partition_t *partition,const int debug, const int dump_ind)
 {
 //  assert(sizeof(struct disklabel)<=2*0x200);
 //  assert(sizeof(struct disk_super_block)<=0x200);
@@ -141,7 +140,7 @@ int search_type_1(unsigned char *buffer, t_param_disk *disk_car,t_partition *par
 //  assert(sizeof(sun_partition_i386)<=2*0x200);
   if(debug>2)
   {
-    ecrit_rapport("search_type_1 lba=%lu\n",(long unsigned)(partition->part_offset/disk_car->sector_size));
+    log_trace("search_type_1 lba=%lu\n",(long unsigned)(partition->part_offset/disk_car->sector_size));
   }
   if(disk_car->read(disk_car,8*DEFAULT_SECTOR_SIZE, buffer, partition->part_offset)!=0)
     return -1;
@@ -154,14 +153,14 @@ int search_type_1(unsigned char *buffer, t_param_disk *disk_car,t_partition *par
   return 0;
 }
 
-int search_type_2(unsigned char *buffer, t_param_disk *disk_car,t_partition *partition,const int debug, const int dump_ind)
+int search_type_2(unsigned char *buffer, disk_t *disk_car,partition_t *partition,const int debug, const int dump_ind)
 {
 //  assert(sizeof(struct ext2_super_block)<=1024);
 //  assert(sizeof(hfs_mdb_t)<=1024);
 //  assert(sizeof(struct hfsp_vh)<=1024);
   if(debug>2)
   {
-    ecrit_rapport("search_type_2 lba=%lu\n",(long unsigned)(partition->part_offset/disk_car->sector_size));
+    log_trace("search_type_2 lba=%lu\n",(long unsigned)(partition->part_offset/disk_car->sector_size));
   }
   if(disk_car->read(disk_car,1024, (buffer+0x400), partition->part_offset+1024)!=0)
     return -1;
@@ -171,12 +170,12 @@ int search_type_2(unsigned char *buffer, t_param_disk *disk_car,t_partition *par
   return 0;
 }
 
-int search_type_16(unsigned char *buffer, t_param_disk *disk_car,t_partition *partition,const int debug, const int dump_ind)
+int search_type_16(unsigned char *buffer, disk_t *disk_car,partition_t *partition,const int debug, const int dump_ind)
 {
 //  assert(sizeof(struct ufs_super_block)<=3*DEFAULT_SECTOR_SIZE);
   if(debug>2)
   {
-    ecrit_rapport("search_type_16 lba=%lu\n",(long unsigned)(partition->part_offset/disk_car->sector_size));
+    log_trace("search_type_16 lba=%lu\n",(long unsigned)(partition->part_offset/disk_car->sector_size));
   }
   if(disk_car->read(disk_car,3*DEFAULT_SECTOR_SIZE, buffer, partition->part_offset+16*512)!=0) /* 8k offset */
     return -1;
@@ -185,21 +184,27 @@ int search_type_16(unsigned char *buffer, t_param_disk *disk_car,t_partition *pa
   return 0;
 }
 
-int search_type_64(unsigned char *buffer, t_param_disk *disk_car,t_partition *partition,const int debug, const int dump_ind)
+int search_type_64(unsigned char *buffer, disk_t *disk_car,partition_t *partition,const int debug, const int dump_ind)
 {
 //  assert(sizeof(struct jfs_superblock)<=2*DEFAULT_SECTOR_SIZE);
   if(debug>2)
   {
-    ecrit_rapport("search_type_64 lba=%lu\n",(long unsigned)(partition->part_offset/disk_car->sector_size));
+    log_trace("search_type_64 lba=%lu\n",(long unsigned)(partition->part_offset/disk_car->sector_size));
   }
   /* Test JFS */
+#if 0
   if(disk_car->read(disk_car,2*DEFAULT_SECTOR_SIZE, buffer, partition->part_offset+64*512)!=0) /* 32k offset */
     return -1;
   if(recover_JFS(disk_car,(const struct jfs_superblock*)buffer,partition,debug,dump_ind)==0) return 1;
+#else
+  if(disk_car->read(disk_car,3*DEFAULT_SECTOR_SIZE, buffer, partition->part_offset+63*512)!=0) /* 32k offset */
+    return -1;
+  if(recover_JFS(disk_car,(const struct jfs_superblock*)(buffer+0x200),partition,debug,dump_ind)==0) return 1;
+#endif
   return 0;
 }
 
-int search_type_128(unsigned char *buffer, t_param_disk *disk_car,t_partition *partition,const int debug, const int dump_ind)
+int search_type_128(unsigned char *buffer, disk_t *disk_car,partition_t *partition,const int debug, const int dump_ind)
 {
   /* Reiserfs4 need to read the master superblock and the format40 superblock => 4096 */
 //  assert(sizeof(struct reiserfs_super_block)<=9*DEFAULT_SECTOR_SIZE);
@@ -207,28 +212,37 @@ int search_type_128(unsigned char *buffer, t_param_disk *disk_car,t_partition *p
 //  assert(sizeof(struct ufs_super_block)<=9*DEFAULT_SECTOR_SIZE);
   if(debug>2)
   {
-    ecrit_rapport("search_type_128 lba=%lu\n",(long unsigned)(partition->part_offset/disk_car->sector_size));
+    log_trace("search_type_128 lba=%lu\n",(long unsigned)(partition->part_offset/disk_car->sector_size));
   }
+#if 0
   /* Test ReiserFS */
   if(disk_car->read(disk_car,9*DEFAULT_SECTOR_SIZE, buffer, partition->part_offset+128*512)!=0) /* 64k offset */
     return -1;
   if(recover_rfs(disk_car,(const struct reiserfs_super_block*)buffer,partition,debug,dump_ind)==0) return 1;
   /* Test UFS2 */
   if(recover_ufs(disk_car,(const struct ufs_super_block*)buffer,partition,debug,dump_ind)==0) return 1;
+#else
+  /* Test ReiserFS */
+  if(disk_car->read(disk_car,11*DEFAULT_SECTOR_SIZE, buffer, partition->part_offset+126*512)!=0) /* 64k offset */
+    return -1;
+  if(recover_rfs(disk_car,(const struct reiserfs_super_block*)(buffer+0x400),partition,debug,dump_ind)==0) return 1;
+  /* Test UFS2 */
+  if(recover_ufs(disk_car,(const struct ufs_super_block*)(buffer+0x400),partition,debug,dump_ind)==0) return 1;
+#endif
   return 0;
 }
 
-t_list_part *search_superblock(t_param_disk *disk_car, const t_partition *partition, const int debug, const int dump_ind, const int interface)
+list_part_t *search_superblock(disk_t *disk_car, const partition_t *partition, const int debug, const int dump_ind, const int interface)
 {
   unsigned char *buffer=MALLOC(2*0x200);
   uint64_t hd_offset;
   int nbr_sb=0;
-  t_list_part *list_part=NULL;
+  list_part_t *list_part=NULL;
   int ind_stop=0;
   unsigned long int old_percent=0;
   struct ext2_super_block *sb=(struct ext2_super_block *)buffer;
-  t_partition *new_partition=partition_new();
-  ecrit_rapport("search_superblock\n");
+  partition_t *new_partition=partition_new();
+  log_trace("search_superblock\n");
   if(interface>0)
   {
     aff_copy(stdscr);
@@ -238,9 +252,9 @@ t_list_part *search_superblock(t_param_disk *disk_car, const t_partition *partit
     wmove(stdscr,6,0);
     aff_part(stdscr,AFF_PART_ORDER,disk_car,partition);
     wmove(stdscr,22,0);
-    wattrset(stdscr,A_STANDOUT);
+    wattrset(stdscr, A_REVERSE);
     waddstr(stdscr,"  Stop  ");
-    wattroff(stdscr,A_STANDOUT);
+    wattroff(stdscr, A_REVERSE);
   }
 
   for(hd_offset=0;hd_offset<partition->part_size && nbr_sb<10 && ind_stop==0;hd_offset+=DEFAULT_SECTOR_SIZE)
@@ -278,13 +292,13 @@ t_list_part *search_superblock(t_param_disk *disk_car, const t_partition *partit
       {
 	if(le16(sb->s_magic)==EXT2_SUPER_MAGIC)
 	{
-	  dup_t_partition(new_partition,partition);
+	  dup_partition_t(new_partition,partition);
 	  new_partition->part_offset+=hd_offset;
 	  if(recover_EXT2(disk_car,sb,new_partition,debug,dump_ind)==0)
 	  {
 	    if(hd_offset<=(EXT2_MIN_BLOCK_SIZE<<2))
 	      new_partition->part_offset-=hd_offset;
-	    ecrit_rapport("Ext2 superblock found at sector %llu (block=%llu, blocksize=%u)        \n",
+	    log_info("Ext2 superblock found at sector %llu (block=%llu, blocksize=%u)        \n",
 		(long long unsigned) hd_offset/DEFAULT_SECTOR_SIZE,
 		(long long unsigned) hd_offset>>(EXT2_MIN_BLOCK_LOG_SIZE+sb->s_log_block_size),
 		EXT2_MIN_BLOCK_SIZE<<(sb->s_log_block_size));
