@@ -32,7 +32,9 @@
 #include "bsd.h"
 #include "intrf.h"
 #include "fnctdsk.h"
-int check_BSD(t_param_disk *disk_car,t_partition *partition,const int debug, const unsigned int max_partitions)
+#include "log.h"
+
+int check_BSD(disk_t *disk_car,partition_t *partition,const int debug, const unsigned int max_partitions)
 {
   unsigned char *buffer;
   buffer=(unsigned char*)MALLOC(BSD_DISKLABEL_SIZE);
@@ -53,7 +55,7 @@ int check_BSD(t_param_disk *disk_car,t_partition *partition,const int debug, con
   return 0;
 }
 
-int test_BSD(t_param_disk *disk_car, const struct disklabel*bsd_header,t_partition *partition,const int debug, const int dump_ind, const unsigned int max_partitions)
+int test_BSD(disk_t *disk_car, const struct disklabel*bsd_header,partition_t *partition,const int debug, const int dump_ind, const unsigned int max_partitions)
 {
   if((le32(bsd_header->d_magic) == DISKMAGIC)&&
       (le32(bsd_header->d_magic2)==DISKMAGIC))
@@ -62,7 +64,7 @@ int test_BSD(t_param_disk *disk_car, const struct disklabel*bsd_header,t_partiti
     const uint16_t* cp;
     uint16_t crc;
     if(debug)
-      ecrit_rapport("\nBSD offset %lu, nbr_part %u, CHS=(%u,%u,%u) ",(long unsigned)(partition->part_offset/disk_car->sector_size),
+      log_info("\nBSD offset %lu, nbr_part %u, CHS=(%u,%u,%u) ",(long unsigned)(partition->part_offset/disk_car->sector_size),
 	  (unsigned int)bsd_header->d_npartitions,(unsigned int)bsd_header->d_ncylinders, (unsigned int)bsd_header->d_ntracks, (unsigned int)bsd_header->d_nsectors);
     if(bsd_header->d_npartitions>max_partitions)
       return 1;
@@ -74,11 +76,11 @@ int test_BSD(t_param_disk *disk_car, const struct disklabel*bsd_header,t_partiti
     {
       if(debug>0)
       {
-	ecrit_rapport("CRC Ok\n");
+	log_info("CRC Ok\n");
       }
     }
     else
-      ecrit_rapport("Bad CRC! CRC must be xor'd by %04X\n",crc);
+      log_error("Bad CRC! CRC must be xor'd by %04X\n",crc);
     for(i=0;i<bsd_header->d_npartitions;i++)
     {
       if(bsd_header->d_partitions[i].p_fstype>0)
@@ -86,29 +88,29 @@ int test_BSD(t_param_disk *disk_car, const struct disklabel*bsd_header,t_partiti
 	if(debug>0)
 	{
 	  /* UFS UFS2 SWAP */
-	  ecrit_rapport("BSD %c: ", 'a'+i);
+	  log_info("BSD %c: ", 'a'+i);
 	  switch(bsd_header->d_partitions[i].p_fstype)
 	  {
 	    case TST_FS_SWAP:
-	      ecrit_rapport("swap");
+	      log_info("swap");
 	      break;
 	    case TST_FS_BSDFFS:
-	      ecrit_rapport("4.2BSD fast filesystem");
+	      log_info("4.2BSD fast filesystem");
 	      break;
 	    case TST_FS_BSDLFS:
-	      ecrit_rapport("4.4BSD log-structured filesystem");
+	      log_info("4.4BSD log-structured filesystem");
 	      break;
 	    default:
-	      ecrit_rapport("type %02X", bsd_header->d_partitions[i].p_fstype);
+	      log_info("type %02X", bsd_header->d_partitions[i].p_fstype);
 	      break;
 	  }
-	  ecrit_rapport(", offset %9u, size %9u ",
+	  log_info(", offset %9u, size %9u ",
 	      (unsigned int)le32(bsd_header->d_partitions[i].p_offset),
 	      (unsigned int)le32(bsd_header->d_partitions[i].p_size));
-	  aff_LBA2CHS_rapport(disk_car,le32(bsd_header->d_partitions[i].p_offset));
-	  ecrit_rapport(" -> ");
-	  aff_LBA2CHS_rapport(disk_car,le32(bsd_header->d_partitions[i].p_offset)+le32(bsd_header->d_partitions[i].p_size)-1);
-	  ecrit_rapport("\n");
+	  log_CHS_from_LBA(disk_car,le32(bsd_header->d_partitions[i].p_offset));
+	  log_info(" -> ");
+	  log_CHS_from_LBA(disk_car,le32(bsd_header->d_partitions[i].p_offset)+le32(bsd_header->d_partitions[i].p_size)-1);
+	  log_info("\n");
 	}
       }
     }
@@ -120,14 +122,14 @@ int test_BSD(t_param_disk *disk_car, const struct disklabel*bsd_header,t_partiti
       partition->upart_type=UP_OPENBSD;
     if(dump_ind!=0)
     {
-      dump(stdscr,bsd_header,DEFAULT_SECTOR_SIZE);
+      dump_log(bsd_header,DEFAULT_SECTOR_SIZE);
     }
     return 0;
   }
   return 1;
 }
 
-int recover_BSD(t_param_disk *disk_car, const struct disklabel*bsd_header,t_partition *partition,const int debug, const int dump_ind)
+int recover_BSD(disk_t *disk_car, const struct disklabel*bsd_header,partition_t *partition,const int debug, const int dump_ind)
 {
   int i;
   int i_max_p_offset=-1;
