@@ -30,14 +30,24 @@
 #include "common.h"
 #include "lang.h"
 #include "intrf.h"
+#include "intrfn.h"
 #include "fnctdsk.h"
 #include "chgtype.h"
+#include "log.h"
 
-int change_part_type(const t_param_disk *disk_car,t_partition *partition, char **current_cmd)
+struct part_name_struct
+{
+  unsigned int index;
+  const char *name;
+};
+
+int change_part_type(const disk_t *disk_car,partition_t *partition, char **current_cmd)
 {
   char response[100];
-  int nbr=0;
+  int size=0;
   int i;
+  unsigned int last[3], done = 0, next = 0;
+  struct part_name_struct part_name[0x100];
   struct MenuItem menuType[]=
   {
     { 'P', "Previous",""},
@@ -45,29 +55,36 @@ int change_part_type(const t_param_disk *disk_car,t_partition *partition, char *
     { 'Q', "Proceed","Go set the partition type"},
     { 0, NULL, NULL }
   };
-  t_partition *new_partition=partition_new();
-  dup_t_partition(new_partition,partition);
-  aff_buffer(BUFFER_RESET,"Q");
-  aff_buffer(BUFFER_ADD,"List of partition type\n");
+  /* Create an index of all partition type except Intel extended */
+  partition_t *new_partition=partition_new();
+  dup_partition_t(new_partition,partition);
   for(i=0;i<=0xFF;i++)
   {
     if(disk_car->arch->set_part_type(new_partition,i)==0)
     {
-      const unsigned char *part_name;
-      part_name=disk_car->arch->get_partition_name(new_partition);
-      if(part_name!=NULL)
-      {
-	aff_buffer(BUFFER_ADD,"%02x %-20s ",i,part_name);
-	nbr++;
-	if(nbr==3)
-	{
-	  nbr=0;
-	  aff_buffer(BUFFER_ADD,"\n");
-	}
-      }
+      part_name[size].name=disk_car->arch->get_partition_name(new_partition);
+      if(part_name[size].name!=NULL)
+	part_name[size++].index=i;
     }
   }
   free(new_partition);
+
+  /* Display the list of partition type in 3 columns */
+  aff_buffer(BUFFER_RESET,"Q");
+  aff_buffer(BUFFER_ADD,"List of partition type\n");
+  for (i = 2; i >= 0; i--)
+    last[2 - i] = done += (size + i - done) / (i + 1);
+  i = done = 0;
+  do {
+    aff_buffer(BUFFER_ADD, "%02x %-20s%c",  part_name[next].index, part_name[next].name,(i==2 ? '\n' : ' '));
+    next = last[i++] + done;
+    if (i > 2 || next >= last[i]) {
+      i = 0;
+      next = ++done;
+    }
+  } while (done < last[0]);
+
+  /* Ask for the new partition type*/
   aff_copy(stdscr);
   wmove(stdscr,4,0);
   aff_part(stdscr,AFF_PART_ORDER,disk_car,partition);
@@ -93,8 +110,6 @@ int change_part_type(const t_param_disk *disk_car,t_partition *partition, char *
       disk_car->arch->set_part_type(partition,tmp_val);
     }
   }
-  aff_part_rapport(disk_car,partition);
+  log_partition(disk_car,partition);
   return 0;
 }
-
-
