@@ -20,6 +20,6 @@
 
  */
 
-void change_geometry(t_param_disk *disk_car, char **current_cmd);
-int change_part_type(const t_param_disk *disk_car,t_partition *partition, char **current_cmd);
+void change_geometry(disk_t *disk_car, char **current_cmd);
+int change_part_type(const disk_t *disk_car,partition_t *partition, char **current_cmd);
 
