@@ -40,6 +40,7 @@
 #include <sys/stat.h>
 #endif
 #include "intrf.h"
+#include "log.h"
 
 static unsigned int up2power_aux(const unsigned int number);
 
@@ -48,10 +49,10 @@ void *MALLOC(size_t size)
   void *res;
   if(size<=0)
   {
-    ecrit_rapport("Try to allocate 0 byte of memory\n");
+    log_critical("Try to allocate 0 byte of memory\n");
     exit(EXIT_FAILURE);
   }
-#ifdef HAVE_POSIX_MEMALIGN
+#if defined(HAVE_POSIX_MEMALIGN)
   if(size>=512)
   {
     /* Warning, memory leak checker must be posix_memalign aware, otherwise reports may look strange */
@@ -60,15 +61,11 @@ void *MALLOC(size_t size)
       memset(res,0,size);
       return res;
     }
-    /*
-    ecrit_rapport("posix_memalign failed\n");
-    exit(EXIT_FAILURE);
-    */
   }
 #endif
   if((res=malloc(size))==NULL)
   {
-    ecrit_rapport("\nCan't allocate %lu bytes of memory.\n", (long unsigned)size);
+    log_critical("\nCan't allocate %lu bytes of memory.\n", (long unsigned)size);
     exit(EXIT_FAILURE);
   }
   memset(res,0,size);
@@ -128,7 +125,7 @@ int strncasecmp(const char * s1, const char * s2, size_t len)
 
 unsigned int up2power(const unsigned int number)
 {
-  /* ecrit_rapport("up2power(%u)=>%u\n",number, (1<<up2power_aux(number-1))); */
+  /* log_trace("up2power(%u)=>%u\n",number, (1<<up2power_aux(number-1))); */
   if(number==0)
     return 1;
   return (1<<up2power_aux(number-1));
@@ -173,7 +170,7 @@ int check_volume_name(const char *name,const unsigned int max_size)
   return 0; /* Ok */
 }
 
-void set_part_name(t_partition *partition,const char *src,const int max_size)
+void set_part_name(partition_t *partition,const char *src,const int max_size)
 {
   int i;
   for(i=0;(i<max_size) && (src[i]!=(char)0);i++)
