@@ -2,7 +2,7 @@
 
     File: cramfs.c
 
-    Copyright (C) 1998-2006 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 1998-2007 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -34,11 +34,12 @@
 #include "common.h"
 #include "cramfs.h"
 #include "fnctdsk.h"
-#include "intrf.h"
-static int set_cramfs_info(const t_param_disk *disk_car, const struct cramfs_super *sb,t_partition *partition, const int debug, const int dump_ind);
-static int test_cramfs(const t_param_disk *disk_car, const struct cramfs_super *sb,t_partition *partition,const int debug, const int dump_ind);
+#include "log.h"
 
-int check_cramfs(t_param_disk *disk_car,t_partition *partition,const int debug)
+static int set_cramfs_info(const disk_t *disk_car, const struct cramfs_super *sb,partition_t *partition, const int debug, const int dump_ind);
+static int test_cramfs(const disk_t *disk_car, const struct cramfs_super *sb,partition_t *partition,const int debug, const int dump_ind);
+
+int check_cramfs(disk_t *disk_car,partition_t *partition,const int debug)
 {
   unsigned char *buffer=(unsigned char*)MALLOC(CRAMFS_SUPERBLOCK_SIZE);
   if(disk_car->read(disk_car,CRAMFS_SUPERBLOCK_SIZE, buffer, partition->part_offset+0x200)!=0)
@@ -56,7 +57,7 @@ int check_cramfs(t_param_disk *disk_car,t_partition *partition,const int debug)
   return 1;
 }
 
-static int test_cramfs(const t_param_disk *disk_car, const struct cramfs_super *sb,t_partition *partition,const int debug, const int dump_ind)
+static int test_cramfs(const disk_t *disk_car, const struct cramfs_super *sb,partition_t *partition,const int debug, const int dump_ind)
 {
   if (sb->magic==CRAMFS_MAGIC)
   {
@@ -65,20 +66,20 @@ static int test_cramfs(const t_param_disk *disk_car, const struct cramfs_super *
   else
     return 1;
   if(debug>0)
-    ecrit_rapport("\ncramfs Marker at %u/%u/%u\n", offset2cylinder(disk_car,partition->part_offset),offset2head(disk_car,partition->part_offset),offset2sector(disk_car,partition->part_offset));
+    log_info("\ncramfs Marker at %u/%u/%u\n", offset2cylinder(disk_car,partition->part_offset),offset2head(disk_car,partition->part_offset),offset2sector(disk_car,partition->part_offset));
   return 0;
 }
 
-int recover_cramfs(t_param_disk *disk_car, const struct cramfs_super *sb,t_partition *partition,const int debug, const int dump_ind)
+int recover_cramfs(disk_t *disk_car, const struct cramfs_super *sb,partition_t *partition,const int debug, const int dump_ind)
 {
   if(test_cramfs(disk_car,sb,partition,debug,dump_ind)!=0)
     return 1;
   if(debug>0 || dump_ind!=0)
   {
-    ecrit_rapport("\nrecover_cramfs\n");
+    log_trace("\nrecover_cramfs\n");
     if(dump_ind!=0)
     {
-      dump(stdscr,sb,DEFAULT_SECTOR_SIZE);
+      dump_log(sb,DEFAULT_SECTOR_SIZE);
     }
   }
   partition->part_size = sb->size;
@@ -89,7 +90,7 @@ int recover_cramfs(t_param_disk *disk_car, const struct cramfs_super *sb,t_parti
   return 0;
 }
 
-static int set_cramfs_info(const t_param_disk *disk_car,const struct cramfs_super *sb,t_partition *partition, const int debug, const int dump_ind)
+static int set_cramfs_info(const disk_t *disk_car,const struct cramfs_super *sb,partition_t *partition, const int debug, const int dump_ind)
 {
   set_part_name(partition,sb->name,16);
   switch(partition->upart_type)
