@@ -27,41 +27,41 @@
 #endif
 #define INTER_DIR 16
 #define DIR_NAME_LEN 255
-typedef struct dir_data t_dir_data;
-typedef struct file_data t_file_data;
+typedef struct dir_data dir_data_t;
+typedef struct file_data file_data_t;
 struct dir_data
 {
-  WINDOW *window;
+  void *display;
   char current_directory[DIR_NAME_LEN];
   unsigned long int current_inode;
   int debug;
-  t_file_data *(*get_dir)(t_param_disk *disk_car, const t_partition *partition, t_dir_data *dir_data, const unsigned long int first_inode);
-  int (*copy_file)(t_param_disk *disk_car, const t_partition *partition, t_dir_data *dir_data, const unsigned long int first_inode);
-  void (*close)(t_dir_data *dir_data);
+  file_data_t *(*get_dir)(disk_t *disk_car, const partition_t *partition, dir_data_t *dir_data, const unsigned long int first_inode);
+  int (*copy_file)(disk_t *disk_car, const partition_t *partition, dir_data_t *dir_data, const file_data_t *file);
+  void (*close)(dir_data_t *dir_data);
   char *local_dir;
   void *private_dir_data;
 };
 
 struct file_data
 {
-  t_file_data *prev;
-  t_file_data *next;
+  file_data_t *prev;
+  file_data_t *next;
   char	name[DIR_NAME_LEN];
   struct stat filestat;
 };
 
 struct file_info {
-  struct list_head list;
+  struct td_list_head list;
   char name[4096];
   struct stat stat;
 };
 
-int dir_aff_log(const t_param_disk *disk_car, const t_partition *partition, const t_dir_data *dir_data, const t_file_data*dir_list);
-void dir_aff_entry(WINDOW *window, struct file_info *dir_info);
-void delete_list_file(t_file_data *file_list);
-int dir_partition_aff(t_param_disk *disk_car, const t_partition *partition, t_dir_data *dir_data, const unsigned long int inode, char **current_cmd);
+int dir_aff_log(const disk_t *disk_car, const partition_t *partition, const dir_data_t *dir_data, const file_data_t*dir_list);
+void delete_list_file(file_data_t *file_list);
+int dir_partition_aff(disk_t *disk_car, const partition_t *partition, dir_data_t *dir_data, const unsigned long int inode, char **current_cmd);
 void mode_string (const unsigned int mode, char *str);
 FILE *create_file(const char *filename);
+int set_date(const char *pathname, time_t actime, time_t modtime);
 
 #define LINUX_S_IFMT  00170000
 #define LINUX_S_IFSOCK 0140000
