@@ -42,44 +42,61 @@
 #include "fnctdsk.h"
 #include "testdisk.h"
 #include "intrf.h"
+#include "intrfn.h"
 #include "dir.h"
 #include "ext2_dir.h"
 #include "fat_dir.h"
 #include "ntfs_dir.h"
 #include "rfs_dir.h"
 #include "dirpart.h"
+#include "ntfs.h"
+#include "adv.h"
+#include "log.h"
 
-int dir_partition(t_param_disk *disk_car, const t_partition *partition, const int debug, char **current_cmd)
+int dir_partition(disk_t *disk_car, const partition_t *partition, const int debug, char **current_cmd)
 {
-  t_dir_data dir_data;
+  dir_data_t dir_data;
   WINDOW *window;
   int res=-3;
-  switch(partition->upart_type)
+  if(is_part_fat(partition))
+    res=dir_partition_fat_init(disk_car,partition,&dir_data,debug);
+  else if(is_part_ntfs(partition))
+    res=dir_partition_ntfs_init(disk_car,partition,&dir_data,debug);
+  else if(is_part_linux(partition))
   {
-    case UP_FAT12:
-    case UP_FAT16:
-    case UP_FAT32:
-      res=dir_partition_fat_init(disk_car,partition,&dir_data,debug);
-      break;
-    case UP_EXT3:
-    case UP_EXT2:
-      res=dir_partition_ext2_init(disk_car,partition,&dir_data,debug);
-      break;
-    case UP_RFS:
-    case UP_RFS2:
-    case UP_RFS3:
+    res=dir_partition_ext2_init(disk_car,partition,&dir_data,debug);
+    if(res!=0)
       res=dir_partition_reiser_init(disk_car,partition,&dir_data,debug);
-      break;
-    case UP_NTFS:
-      res=dir_partition_ntfs_init(disk_car,partition,&dir_data,debug);
-      break;
-    default:
-      return res;
+  }
+  if(res!=0)
+  {
+    switch(partition->upart_type)
+    {
+      case UP_FAT12:
+      case UP_FAT16:
+      case UP_FAT32:
+	res=dir_partition_fat_init(disk_car,partition,&dir_data,debug);
+	break;
+      case UP_EXT3:
+      case UP_EXT2:
+	res=dir_partition_ext2_init(disk_car,partition,&dir_data,debug);
+	break;
+      case UP_RFS:
+      case UP_RFS2:
+      case UP_RFS3:
+	res=dir_partition_reiser_init(disk_car,partition,&dir_data,debug);
+	break;
+      case UP_NTFS:
+	res=dir_partition_ntfs_init(disk_car,partition,&dir_data,debug);
+	break;
+      default:
+	return res;
+    }
   }
   window=newwin(0,0,0,0);	/* full screen */
-  dir_data.window=window;
+  dir_data.display=window;
   aff_copy(window);
-  ecrit_rapport("\n");
+  log_info("\n");
   switch(res)
   {
     case -2:
@@ -87,7 +104,7 @@ int dir_partition(t_param_disk *disk_car, const t_partition *partition, const in
       aff_copy(window);
       wmove(window,4,0);
       aff_part(window,AFF_PART_ORDER,disk_car,partition);
-      aff_part_rapport(disk_car,partition);
+      log_partition(disk_car,partition);
       aff_buffer(BUFFER_ADD,"Support for this filesystem hasn't been enable during compilation.\n");
       if(*current_cmd!=NULL)
 	screen_buffer_to_log();
@@ -99,7 +116,7 @@ int dir_partition(t_param_disk *disk_car, const t_partition *partition, const in
       aff_copy(window);
       wmove(window,4,0);
       aff_part(window,AFF_PART_ORDER,disk_car,partition);
-      aff_part_rapport(disk_car,partition);
+      log_partition(disk_car,partition);
       aff_buffer(BUFFER_ADD,"Can't open filesystem. Filesystem seems damaged.\n");
       screen_buffer_display(window,"",NULL);
       break;
