@@ -19,5 +19,5 @@
     Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
  */
-int dir_partition(t_param_disk *disk_car, const t_partition *partition, const int debug, char **current_cmd);
+int dir_partition(disk_t *disk_car, const partition_t *partition, const int debug, char **current_cmd);
 
