@@ -34,18 +34,20 @@
 #include "common.h"
 #include "lang.h"
 #include "intrf.h"
+#include "intrfn.h"
 #include "fnctdsk.h"
 #include "edit.h"
+#include "log.h"
 
-static void interface_editor_position(const t_param_disk *disk_car, uint64_t *lba);
+static void interface_editor_position(const disk_t *disk_car, uint64_t *lba);
 static int dump_editor(const unsigned char *nom_dump,const unsigned int lng, const int menu_pos);
 
-void interface_editor(t_param_disk *disk_car)
+void interface_editor(disk_t *disk_car)
 {
   int done = FALSE;
   uint64_t hd_offset=0;
   unsigned char *buffer=MALLOC(disk_car->sector_size);
-  ecrit_rapport("%s\n",disk_car->description(disk_car));
+  log_info("%s\n",disk_car->description(disk_car));
   while (done==FALSE)
   {
     static struct MenuItem menuEditor[]=
@@ -110,9 +112,9 @@ void interface_editor(t_param_disk *disk_car)
   free(buffer);
 }
 
-static void interface_editor_position(const t_param_disk *disk_car,uint64_t *lba)
+static void interface_editor_position(const disk_t *disk_car,uint64_t *lba)
 {
-  t_CHS position;
+  CHS_t position;
   int done = FALSE;
   char def[LINE_LENGTH];
   char response[LINE_LENGTH];
@@ -196,27 +198,7 @@ static int dump_editor(const unsigned char *nom_dump,const unsigned int lng, con
 	{ 0, NULL, NULL }
   };
   /* write dump to log file*/
-  for (i=0; (i<lng/0x10); i++)
-  {
-	ecrit_rapport("%04X ",i*0x10);
-	for(j=0; j< 0x10;j++)
-	{
-	  car=*(nom_dump+i*0x10+j);
-	  ecrit_rapport("%02x", car);
-	  if(j%4==(4-1))
-		ecrit_rapport(" ");
-	}
-	ecrit_rapport("  ");
-	for(j=0; j< 0x10;j++)
-	{
-	  car=*(nom_dump+i*0x10+j);
-	  if ((car<32)||(car >= 127))
-		ecrit_rapport(".");
-	  else
-		ecrit_rapport("%c",  car);
-	}
-	ecrit_rapport("\n");
-  }
+  dump_log(nom_dump, lng);
   /* ncurses interface */
   pos=(menu_pos==KEY_DOWN?0:lng/0x10-DUMP_MAX_LINES);
   menu=(menu_pos==KEY_DOWN?1:0);
