@@ -19,5 +19,5 @@
     Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
  */
-void interface_editor(t_param_disk *disk_car);
+void interface_editor(disk_t *disk_car);
 
