@@ -20,7 +20,7 @@
 
  */
 #if defined(HAVE_LIBEWF_H) && defined(HAVE_LIBEWF)
-t_param_disk *fewf_init(const char *device, const int debug, const t_arch_fnct *arch, const int testdisk_mode);
+disk_t *fewf_init(const char *device, const int debug, const arch_fnct_t *arch, const int testdisk_mode);
 #endif
 const char*td_ewf_version(void);
 
