@@ -2,7 +2,7 @@
 
     File: ext2.c
 
-    Copyright (C) 1998-2006 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 1998-2007 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -32,14 +32,14 @@
 #include "types.h"
 #include "common.h"
 #include "ext2.h"
-#include "intrf.h"
 #include "fnctdsk.h"
+#include "log.h"
 
 #define EXT2_BLOCK_SIZE(s)      (EXT2_MIN_BLOCK_SIZE << (s)->s_log_block_size)
-static int test_EXT2(t_param_disk *disk_car, const struct ext2_super_block *sb,t_partition *partition,const int debug, const int dump_ind);
-static int set_EXT2_info(t_param_disk *disk_car, const struct ext2_super_block *sb,t_partition *partition,const int debug, const int dump_ind);
+static int test_EXT2(disk_t *disk_car, const struct ext2_super_block *sb,partition_t *partition,const int debug, const int dump_ind);
+static int set_EXT2_info(disk_t *disk_car, const struct ext2_super_block *sb,partition_t *partition,const int debug, const int dump_ind);
 
-int check_EXT2(t_param_disk *disk_car,t_partition *partition,const int debug)
+int check_EXT2(disk_t *disk_car,partition_t *partition,const int debug)
 {
   unsigned char *buffer=(unsigned char*)MALLOC(EXT2_SUPERBLOCK_SIZE);
   if(disk_car->read(disk_car,EXT2_SUPERBLOCK_SIZE, buffer, partition->part_offset+0x400)!=0)
@@ -57,7 +57,7 @@ int check_EXT2(t_param_disk *disk_car,t_partition *partition,const int debug)
   return 0;
 }
 
-static int set_EXT2_info(t_param_disk *disk_car, const struct ext2_super_block *sb,t_partition *partition,const int debug, const int dump_ind)
+static int set_EXT2_info(disk_t *disk_car, const struct ext2_super_block *sb,partition_t *partition,const int debug, const int dump_ind)
 {
   set_part_name(partition,sb->s_volume_name,16);
   /* sb->s_last_mounted seems to be unemployed in kernel 2.2.16 */
@@ -78,7 +78,7 @@ static int set_EXT2_info(t_param_disk *disk_car, const struct ext2_super_block *
     strcat(partition->info," Backup superblock");
     if(debug>0)
     {
-      ecrit_rapport("\nblock_group_nr %u\n",le16(sb->s_block_group_nr));
+      log_warning("\nblock_group_nr %u\n",le16(sb->s_block_group_nr));
     }
   }
   /* last mounted => date */
@@ -89,7 +89,7 @@ static int set_EXT2_info(t_param_disk *disk_car, const struct ext2_super_block *
 Primary superblock is at 1024 (SUPERBLOCK_OFFSET)
 Group 0 begin at s_first_data_block
 */
-int recover_EXT2(t_param_disk *disk_car, const struct ext2_super_block *sb,t_partition *partition,const int debug, const int dump_ind)
+int recover_EXT2(disk_t *disk_car, const struct ext2_super_block *sb,partition_t *partition,const int debug, const int dump_ind)
 {
   if(test_EXT2(disk_car,sb,partition,debug,dump_ind)!=0)
     return 1;
@@ -103,19 +103,20 @@ int recover_EXT2(t_param_disk *disk_car, const struct ext2_super_block *sb,t_par
   partition->blocksize=EXT2_MIN_BLOCK_SIZE<<le32(sb->s_log_block_size);
   if(debug>0)
   {
-    ecrit_rapport("\n");
+    log_info("\n");
   }
   if(le16(sb->s_block_group_nr)>0)
   {
     unsigned long int boot_sector=(le32(sb->s_first_data_block)+le16(sb->s_block_group_nr)*le32(sb->s_blocks_per_group));
     if(partition->part_offset<(uint64_t)boot_sector*((EXT2_MIN_BLOCK_SIZE/disk_car->sector_size)<<le32(sb->s_log_block_size))*disk_car->sector_size)
     {
-      ecrit_rapport("recover_EXT2: part_offset problem\n");
+      log_error("recover_EXT2: part_offset problem\n");
       return 1;
     }
     partition->boot_sector=boot_sector;
     partition->part_offset-=(uint64_t)boot_sector*((EXT2_MIN_BLOCK_SIZE/disk_car->sector_size)<<le32(sb->s_log_block_size))*disk_car->sector_size;
-    ecrit_rapport("recover_EXT2: \"e2fsck -b %lu -B %lu device\" may be needed\n",partition->boot_sector,partition->blocksize);
+    log_warning("recover_EXT2: \"e2fsck -b %lu -B %lu device\" may be needed\n",
+	partition->boot_sector,partition->blocksize);
   }
   else
   {
@@ -123,16 +124,16 @@ int recover_EXT2(t_param_disk *disk_car, const struct ext2_super_block *sb,t_par
   }
   if(debug>0)
   {
-    ecrit_rapport("recover_EXT2: s_block_group_nr=%u/%u, s_mnt_count=%u/%u, s_blocks_per_group=%u\n",
+    log_info("recover_EXT2: s_block_group_nr=%u/%u, s_mnt_count=%u/%u, s_blocks_per_group=%u\n",
     le16(sb->s_block_group_nr), (unsigned int)(le32(sb->s_blocks_count)/le32(sb->s_blocks_per_group)), le16(sb->s_mnt_count),le16(sb->s_max_mnt_count),(unsigned int)le32(sb->s_blocks_per_group));
-    ecrit_rapport("recover_EXT2: boot_sector=%lu, s_blocksize=%lu\n",partition->boot_sector,partition->blocksize);
-    ecrit_rapport("recover_EXT2: s_blocks_count %u\n",(unsigned int)le32(sb->s_blocks_count));
-    ecrit_rapport("recover_EXT2: part_size %lu\n",(long unsigned)(partition->part_size/disk_car->sector_size));
+    log_info("recover_EXT2: boot_sector=%lu, s_blocksize=%lu\n",partition->boot_sector,partition->blocksize);
+    log_info("recover_EXT2: s_blocks_count %u\n",(unsigned int)le32(sb->s_blocks_count));
+    log_info("recover_EXT2: part_size %lu\n",(long unsigned)(partition->part_size/disk_car->sector_size));
   }
   return 0;
 }
 
-static int test_EXT2(t_param_disk *disk_car, const struct ext2_super_block *sb,t_partition *partition,const int debug, const int dump_ind)
+static int test_EXT2(disk_t *disk_car, const struct ext2_super_block *sb,partition_t *partition,const int debug, const int dump_ind)
 {
     /* There is a little offset ... */
   if(le16(sb->s_magic)!=EXT2_SUPER_MAGIC)
@@ -140,9 +141,9 @@ static int test_EXT2(t_param_disk *disk_car, const struct ext2_super_block *sb,t
   if(dump_ind!=0)
   {
     if(partition!=NULL && disk_car!=NULL)
-      ecrit_rapport("\nEXT2/EXT3 magic value at %u/%u/%u\n", offset2cylinder(disk_car,partition->part_offset),offset2head(disk_car,partition->part_offset),offset2sector(disk_car,partition->part_offset));
+      log_info("\nEXT2/EXT3 magic value at %u/%u/%u\n", offset2cylinder(disk_car,partition->part_offset),offset2head(disk_car,partition->part_offset),offset2sector(disk_car,partition->part_offset));
     /* There is a little offset ... */
-    dump(stdscr,sb,DEFAULT_SECTOR_SIZE);
+    dump_log(sb,DEFAULT_SECTOR_SIZE);
   }
   if (le32(sb->s_free_blocks_count) >= le32(sb->s_blocks_count)) return 2;
   if (le32(sb->s_free_inodes_count) >= le32(sb->s_inodes_count)) return 3;
