@@ -138,5 +138,5 @@ struct ext2_super_block {
 	uint16_t	s_padding1;
 	uint32_t	s_reserved[204];	/* Padding to the end of the block */
 };
-int check_EXT2(t_param_disk *disk_car,t_partition *partition,const int debug);
-int recover_EXT2(t_param_disk *disk_car, const struct ext2_super_block *sb,t_partition *partition,const int debug, const int dump_ind);
+int check_EXT2(disk_t *disk_car,partition_t *partition,const int debug);
+int recover_EXT2(disk_t *disk_car, const struct ext2_super_block *sb,partition_t *partition,const int debug, const int dump_ind);
