@@ -2,7 +2,7 @@
 
     File: ext2_dir.c
 
-    Copyright (C) 1998-2006 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 1998-2007 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,13 +22,11 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
- 
+
+#include <stdio.h>
 #ifdef HAVE_STRING_H
 #include <string.h>
 #endif
-#ifdef HAVE_STDLIB_H
-#include <stdlib.h>
-#endif
 #ifdef HAVE_SYS_STAT_H
 #include <sys/stat.h>
 #endif
@@ -43,6 +41,7 @@
 #include "intrf.h"
 #include "dir.h"
 #include "ext2_dir.h"
+#include "log.h"
 
 #ifdef HAVE_LIBEXT2FS
 #define DIRENT_DELETED_FILE	4
@@ -52,9 +51,9 @@
 
 #define LONG_OPT	0x0001
 
-struct list_dir_struct {
-	t_file_data *dir_list;
-	t_file_data *current_file;
+struct ext2_dir_struct {
+	file_data_t *dir_list;
+	file_data_t *current_file;
 	ext2_filsys current_fs;
 	int flags;
 };
@@ -70,8 +69,8 @@ static errcode_t my_read_blk(io_channel channel, unsigned long block, int count,
 static errcode_t my_write_blk(io_channel channel, unsigned long block, int count, const void *buf);
 static errcode_t my_flush(io_channel channel);
 
-static io_channel alloc_io_channel(t_param_disk *disk_car,t_my_data *my_data);
-static void dir_partition_ext2_close(t_dir_data *dir_data);
+static io_channel alloc_io_channel(disk_t *disk_car,my_data_t *my_data);
+static void dir_partition_ext2_close(dir_data_t *dir_data);
 
 static struct struct_io_manager my_struct_manager = {
         magic: EXT2_ET_MAGIC_IO_MANAGER,
@@ -87,7 +86,7 @@ static struct struct_io_manager my_struct_manager = {
 	set_option: NULL
 #endif
 };
-static t_file_data *ext2_dir(t_param_disk *disk_car, const t_partition *partition, t_dir_data *dir_data, const unsigned long int cluster);
+static file_data_t *ext2_dir(disk_t *disk_car, const partition_t *partition, dir_data_t *dir_data, const unsigned long int cluster);
 
 io_channel *shared_ioch=NULL;
 io_manager my_io_manager = &my_struct_manager;
@@ -102,11 +101,11 @@ io_manager my_io_manager = &my_struct_manager;
 /*
  * Allocate libext2fs structures associated with I/O manager
  */
-static io_channel alloc_io_channel(t_param_disk *disk_car,t_my_data *my_data)
+static io_channel alloc_io_channel(disk_t *disk_car,my_data_t *my_data)
 {
   io_channel     ioch;
 #ifdef DEBUG
-  ecrit_rapport("alloc_io_channel start\n");
+  log_trace("alloc_io_channel start\n");
 #endif
   ioch = (io_channel)MALLOC(sizeof(struct struct_io_channel));
   if (ioch==NULL)
@@ -125,7 +124,7 @@ static io_channel alloc_io_channel(t_param_disk *disk_car,t_my_data *my_data)
   ioch->read_error = 0;
   ioch->write_error = 0;
 #ifdef DEBUG
-  ecrit_rapport("alloc_io_channel end\n");
+  log_trace("alloc_io_channel end\n");
 #endif
   return ioch;
 }
@@ -134,7 +133,7 @@ static errcode_t my_open(const char *dev, int flags, io_channel *channel)
 {
   *channel = *shared_ioch;
 #ifdef DEBUG
-  ecrit_rapport("my_open %s done\n",dev);
+  log_trace("my_open %s done\n",dev);
 #endif
   return 0;
 }
@@ -145,7 +144,7 @@ static errcode_t my_close(io_channel channel)
   free(channel->name);
   free(channel);
 #ifdef DEBUG
-  ecrit_rapport("my_close done\n");
+  log_trace("my_close done\n");
 #endif
   return 0;
 }
@@ -154,7 +153,7 @@ static errcode_t my_set_blksize(io_channel channel, int blksize)
 {
   channel->block_size = blksize;
 #ifdef DEBUG
-  ecrit_rapport("my_set_blksize done\n");
+  log_trace("my_set_blksize done\n");
 #endif
   return 0;
 }
@@ -162,24 +161,24 @@ static errcode_t my_set_blksize(io_channel channel, int blksize)
 static errcode_t my_read_blk(io_channel channel, unsigned long block, int count, void *buf)
 {
   size_t size;
-  t_my_data *my_data=(t_my_data*)channel->private_data;
+  my_data_t *my_data=(my_data_t*)channel->private_data;
   EXT2_CHECK_MAGIC(channel, EXT2_ET_MAGIC_IO_CHANNEL);
 
   size = (count < 0) ? -count : count * channel->block_size;
 #ifdef DEBUG
-  ecrit_rapport("my_read_blk start size=%lu, offset=%lu name=%s\n",(long unsigned)size,(unsigned long)(block*channel->block_size),my_data->partition->name);
+  log_trace("my_read_blk start size=%lu, offset=%lu name=%s\n",(long unsigned)size,(unsigned long)(block*channel->block_size),my_data->partition->name);
 #endif
   if(my_data->disk_car->read(my_data->disk_car,size,buf,my_data->partition->part_offset+(uint64_t)block*channel->block_size)!=0)
     return 1;
 #ifdef DEBUG
-  ecrit_rapport("my_read_blk done\n");
+  log_trace("my_read_blk done\n");
 #endif
   return 0;
 }
 
 static errcode_t my_write_blk(io_channel channel, unsigned long block, int count, const void *buf)
 {
-  t_my_data *my_data=(t_my_data*)channel;
+  my_data_t *my_data=(my_data_t*)channel;
   EXT2_CHECK_MAGIC(channel, EXT2_ET_MAGIC_IO_CHANNEL);
 /* if(my_data->disk_car->write(my_data->disk_car,count*channel->block_size,buf,my_data->partition->part_offset+(uint64_t)block*channel->block_size))!=0) */
     return 1;
@@ -202,8 +201,8 @@ static int list_dir_proc2(ext2_ino_t dir,
   struct ext2_inode	inode;
   ext2_ino_t		ino;
   unsigned int		thislen;
-  struct list_dir_struct *ls = (struct list_dir_struct *) private;
-  t_file_data *new_file=MALLOC(sizeof(*new_file));
+  struct ext2_dir_struct *ls = (struct ext2_dir_struct *) private;
+  file_data_t *new_file=MALLOC(sizeof(*new_file));
   new_file->prev=ls->current_file;
   new_file->next=NULL;
 
@@ -216,15 +215,11 @@ static int list_dir_proc2(ext2_ino_t dir,
   ino = dirent->inode;
   if (ino) {
     errcode_t retval;
-//    ecrit_rapport("ext2fs_read_inode(ino=%u)\n",ino);
+//    log_trace("ext2fs_read_inode(ino=%u)\n",ino);
     if ((retval=ext2fs_read_inode(ls->current_fs,ino, &inode))!=0)
     {
-      ecrit_rapport("ext2fs_read_inode(ino=%u) failed with error %ld.\n",(unsigned)ino, (long)retval);
+      log_error("ext2fs_read_inode(ino=%u) failed with error %ld.\n",(unsigned)ino, (long)retval);
       memset(&inode, 0, sizeof(struct ext2_inode));
-      /*
-      free(new_file);
-      return 0;
-      */
     }
   } else {
     memset(&inode, 0, sizeof(struct ext2_inode));
@@ -253,34 +248,34 @@ static int list_dir_proc2(ext2_ino_t dir,
   return 0;
 }
 
-static t_file_data *ext2_dir(t_param_disk *disk_car, const t_partition *partition, t_dir_data *dir_data, const unsigned long int cluster)
+static file_data_t *ext2_dir(disk_t *disk_car, const partition_t *partition, dir_data_t *dir_data, const unsigned long int cluster)
 {
   errcode_t       retval;
-  struct list_dir_struct *ls=(struct list_dir_struct*)dir_data->private_dir_data;
+  struct ext2_dir_struct *ls=(struct ext2_dir_struct*)dir_data->private_dir_data;
   ls->dir_list=NULL;
   ls->current_file=NULL;
   if((retval=ext2fs_dir_iterate2(ls->current_fs, cluster, ls->flags, 0, list_dir_proc2, ls))!=0)
   {
-    ecrit_rapport("ext2fs_dir_iterate failed with error %ld.\n",(long)retval);
+    log_error("ext2fs_dir_iterate failed with error %ld.\n",(long)retval);
   }
   return ls->dir_list;
 }
 
-static void dir_partition_ext2_close(t_dir_data *dir_data)
+static void dir_partition_ext2_close(dir_data_t *dir_data)
 {
-  struct list_dir_struct *ls=(struct list_dir_struct *)dir_data->private_dir_data;
+  struct ext2_dir_struct *ls=(struct ext2_dir_struct *)dir_data->private_dir_data;
   ext2fs_close (ls->current_fs);
   /* ext2fs_close call the close function that freed my_data */
   free(ls);
 }
 #endif
 
-int dir_partition_ext2_init(t_param_disk *disk_car, const t_partition *partition, t_dir_data *dir_data, const int debug)
+int dir_partition_ext2_init(disk_t *disk_car, const partition_t *partition, dir_data_t *dir_data, const int debug)
 {
 #ifdef HAVE_LIBEXT2FS
-  struct list_dir_struct *ls=(struct list_dir_struct *)MALLOC(sizeof(*ls));
+  struct ext2_dir_struct *ls=(struct ext2_dir_struct *)MALLOC(sizeof(*ls));
   io_channel ioch;
-  t_my_data *my_data;
+  my_data_t *my_data;
   ls->dir_list=NULL;
   ls->current_file=NULL;
   /*  ls->flags = DIRENT_FLAG_INCLUDE_EMPTY; */
