@@ -2,7 +2,7 @@
 
     File: fat.h
 
-    Copyright (C) 1998-2004 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 1998-2004,2007 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -99,30 +99,33 @@ struct msdos_dir_slot {
 };
 
 
-int comp_FAT(t_param_disk *disk_car,const t_partition *partition, const unsigned long int taille, const unsigned long int sect_res);
-int dump_2fat_rapport(const struct fat_boot_sector*fh1, const struct fat_boot_sector*fh2, const upart_type_t upart_type, const unsigned int sector_size);
+int comp_FAT(disk_t *disk_car,const partition_t *partition, const unsigned long int taille, const unsigned long int sect_res);
+int log_fat2_dump(const struct fat_boot_sector*fh1, const struct fat_boot_sector*fh2, const upart_type_t upart_type, const unsigned int sector_size);
 
-unsigned int get_next_cluster(t_param_disk *disk_car,const t_partition *partition, const upart_type_t upart_type,const int offset, const unsigned int cluster);
-unsigned int get_prev_cluster(t_param_disk *disk_car,const t_partition *partition, const upart_type_t upart_type,const int offset, const unsigned int cluster, const unsigned int no_of_cluster);
-int set_next_cluster(t_param_disk *disk_car,const t_partition *partition, const upart_type_t upart_type,const int offset, const unsigned int cluster, const unsigned int next_cluster);
+unsigned int get_next_cluster(disk_t *disk_car,const partition_t *partition, const upart_type_t upart_type,const int offset, const unsigned int cluster);
+unsigned int get_prev_cluster(disk_t *disk_car,const partition_t *partition, const upart_type_t upart_type,const int offset, const unsigned int cluster, const unsigned int no_of_cluster);
+int set_next_cluster(disk_t *disk_car,const partition_t *partition, const upart_type_t upart_type,const int offset, const unsigned int cluster, const unsigned int next_cluster);
 
-int is_fat(const t_partition *partition);
-int is_fat12(const t_partition *partition);
-int is_fat16(const t_partition *partition);
-int is_fat32(const t_partition *partition);
+int is_fat(const partition_t *partition);
+int is_fat12(const partition_t *partition);
+int is_fat16(const partition_t *partition);
+int is_fat32(const partition_t *partition);
+int is_part_fat(const partition_t *partition);
+int is_part_fat12(const partition_t *partition);
+int is_part_fat16(const partition_t *partition);
+int is_part_fat32(const partition_t *partition);
 unsigned int get_dir_entries(const struct fat_boot_sector *fat_header);
 int dump_fat_info(const struct fat_boot_sector*fh1, const upart_type_t upart_type, const unsigned int sector_size);
 int dump_2fat_info(const struct fat_boot_sector*fh1, const struct fat_boot_sector*fh2, const upart_type_t upart_type, const unsigned int sector_size);
-int dump_fat_info_rapport(const struct fat_boot_sector*fh1, const upart_type_t upart_type, const unsigned int sector_size);
-int fat32_set_part_name(t_param_disk *disk_car, t_partition *partition, const struct fat_boot_sector*fat_header);
+int fat32_set_part_name(disk_t *disk_car, partition_t *partition, const struct fat_boot_sector*fat_header);
 unsigned int fat_sector_size(const struct fat_boot_sector *fat_header);
 unsigned int sectors(const struct fat_boot_sector *fat_header);
-unsigned int fat32_get_prev_cluster(t_param_disk *disk_car,const t_partition *partition, const unsigned int fat_offset, const unsigned int cluster, const unsigned int no_of_cluster);
-int fat32_free_info(t_param_disk *disk_car,const t_partition *partition, const unsigned int fat_offset, const unsigned int no_of_cluster, unsigned int *next_free, unsigned int*free_count);
+unsigned int fat32_get_prev_cluster(disk_t *disk_car,const partition_t *partition, const unsigned int fat_offset, const unsigned int cluster, const unsigned int no_of_cluster);
+int fat32_free_info(disk_t *disk_car,const partition_t *partition, const unsigned int fat_offset, const unsigned int no_of_cluster, unsigned int *next_free, unsigned int*free_count);
 unsigned long int fat32_get_free_count(const unsigned char *boot_fat32, const unsigned int sector_size);
 unsigned long int fat32_get_next_free(const unsigned char *boot_fat32, const unsigned int sector_size);
-int repair_FAT_table(t_param_disk *disk_car, t_partition *partition, const int debug);
-int FAT_init_rootdir(t_param_disk *disk_car, t_partition *partition, const int debug);
+int repair_FAT_table(disk_t *disk_car, partition_t *partition, const int debug);
+int FAT_init_rootdir(disk_t *disk_car, partition_t *partition, const int debug);
 
 #define DELETED_FLAG 0xe5 /* marks file as deleted when in name[0] */
 #define IS_FREE(n) (!*(n) || *(const unsigned char *) (n) == DELETED_FLAG)
@@ -139,19 +142,22 @@ int FAT_init_rootdir(t_param_disk *disk_car, t_partition *partition, const int d
 #define ATTR_EXT     (ATTR_RO | ATTR_HIDDEN | ATTR_SYS | ATTR_VOLUME)
 #define ATTR_EXT_MASK     (ATTR_RO | ATTR_HIDDEN | ATTR_SYS | ATTR_VOLUME | ATTR_DIR | ATTR_ARCH)
 	/* bits that are used by the Windows 95/Windows NT extended FAT */
+#define FAT12_BAD	0x0FF7
 #define FAT12_EOC	0x0FF8
+#define FAT16_BAD	0xFFF7
 #define FAT16_EOC	0xFFF8
+#define FAT32_BAD	0x0FFFFFF7
 #define FAT32_EOC	0x0FFFFFF8
 #endif
 #define FAT1x_BOOT_SECTOR_SIZE 0x200
 
-int recover_FAT(t_param_disk *disk_car,const struct fat_boot_sector*fat_header, t_partition *partition, const int debug, const int dump_ind, const int backup);
-int check_FAT(t_param_disk *disk_car,t_partition *partition, const int debug);
-int test_FAT(t_param_disk *disk_car,const struct fat_boot_sector *fat_header, t_partition *partition,const int debug, const int dump_ind);
-int recover_HPFS(t_param_disk *disk_car, const struct fat_boot_sector*fat_header, t_partition *partition, const int debug, const int dump_ind);
-int check_HPFS(t_param_disk *disk_car,t_partition *partition, const int debug);
-int test_HPFS(t_param_disk *disk_car,const struct fat_boot_sector *fat_header, t_partition *partition,const int debug, const int dump_ind);
-int recover_OS2MB(t_param_disk *disk_car, const struct fat_boot_sector*fat_header, t_partition *partition, const int debug, const int dump_ind);
-int check_OS2MB(t_param_disk *disk_car,t_partition *partition, const int debug);
-int test_OS2MB(t_param_disk *disk_car,const struct fat_boot_sector *fat_header, t_partition *partition,const int debug, const int dump_ind);
+int recover_FAT(disk_t *disk_car,const struct fat_boot_sector*fat_header, partition_t *partition, const int debug, const int dump_ind, const int backup);
+int check_FAT(disk_t *disk_car,partition_t *partition, const int debug);
+int test_FAT(disk_t *disk_car,const struct fat_boot_sector *fat_header, partition_t *partition,const int debug, const int dump_ind);
+int recover_HPFS(disk_t *disk_car, const struct fat_boot_sector*fat_header, partition_t *partition, const int debug, const int dump_ind);
+int check_HPFS(disk_t *disk_car,partition_t *partition, const int debug);
+int test_HPFS(disk_t *disk_car,const struct fat_boot_sector *fat_header, partition_t *partition,const int debug, const int dump_ind);
+int recover_OS2MB(disk_t *disk_car, const struct fat_boot_sector*fat_header, partition_t *partition, const int debug, const int dump_ind);
+int check_OS2MB(disk_t *disk_car,partition_t *partition, const int debug);
+int test_OS2MB(disk_t *disk_car,const struct fat_boot_sector *fat_header, partition_t *partition,const int debug, const int dump_ind);
 
