@@ -2,7 +2,7 @@
 
     File: dir_fat.c
 
-    Copyright (C) 1998-2006 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 1998-2007 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
- 
+#include <stdio.h>
 #include <ctype.h>
 #ifdef HAVE_STRING_H
 #include <string.h>
@@ -46,21 +46,22 @@
 #include "intrf.h"
 #include "dir.h"
 #include "fat_dir.h"
+#include "log.h"
 
 #define MSDOS_MKMODE(a,m) ((m & (a & ATTR_RO ? LINUX_S_IRUGO|LINUX_S_IXUGO : LINUX_S_IRWXUGO)) | (a & ATTR_DIR ? LINUX_S_IFDIR : LINUX_S_IFREG))
-struct list_dir_struct
+struct fat_dir_struct
 {
   struct fat_boot_sector*boot_sector;
 };
 
 
 static int date_dos2unix(const unsigned short f_time,const unsigned short f_date);
-static t_file_data *fat1x_rootdir(t_param_disk *disk_car, const t_partition *partition, const int debug, const struct fat_boot_sector*fat_header);
-static t_file_data *fat12_dir(t_param_disk *disk_car, const t_partition *partition, t_dir_data *dir_data, const unsigned long int first_cluster);
-static t_file_data *fat16_dir(t_param_disk *disk_car, const t_partition *partition, t_dir_data *dir_data, const unsigned long int first_cluster);
-static t_file_data *fat32_dir(t_param_disk *disk_car, const t_partition *partition, t_dir_data *dir_data, const unsigned long int first_cluster);
+static file_data_t *fat1x_rootdir(disk_t *disk_car, const partition_t *partition, const int debug, const struct fat_boot_sector*fat_header);
+static file_data_t *fat12_dir(disk_t *disk_car, const partition_t *partition, dir_data_t *dir_data, const unsigned long int first_cluster);
+static file_data_t *fat16_dir(disk_t *disk_car, const partition_t *partition, dir_data_t *dir_data, const unsigned long int first_cluster);
+static file_data_t *fat32_dir(disk_t *disk_car, const partition_t *partition, dir_data_t *dir_data, const unsigned long int first_cluster);
 static inline void fat16_towchar(wchar_t *dst, const uint8_t *src, size_t len);
-static void dir_partition_fat_close(t_dir_data *dir_data);
+static void dir_partition_fat_close(dir_data_t *dir_data);
 
 static int32_t secwest;
 
@@ -72,13 +73,13 @@ static inline void fat16_towchar(wchar_t *dst, const uint8_t *src, size_t len)
 	}
 }
 
-t_file_data *dir_fat_aux(const unsigned char*buffer, const unsigned int size, const unsigned int cluster_size)
+file_data_t *dir_fat_aux(const unsigned char*buffer, const unsigned int size, const unsigned int cluster_size)
 {
   const struct msdos_dir_entry *de=(const struct msdos_dir_entry*)buffer;
   wchar_t unicode[1000];
   unsigned char long_slots;
-  t_file_data *dir_list=NULL;
-  t_file_data *current_file=NULL;
+  file_data_t *dir_list=NULL;
+  file_data_t *current_file=NULL;
 GetNew:
   long_slots = 0;
   unicode[0]=0;
@@ -163,7 +164,7 @@ RecEnd:
     if(unicode[0]!=0)
     {
       unsigned int i;
-      t_file_data *new_file=MALLOC(sizeof(*new_file));
+      file_data_t *new_file=MALLOC(sizeof(*new_file));
       for(i=0;(unicode[i]!=0)&&(i<sizeof(new_file->name)-1);i++)
 	new_file->name[i]=(char) unicode[i];
       new_file->name[i]=0;
@@ -187,8 +188,7 @@ RecEnd:
       new_file->filestat.st_atime=new_file->filestat.st_ctime=new_file->filestat.st_mtime=date_dos2unix(le16(de->time),le16(de->date));
       new_file->prev=current_file;
       new_file->next=NULL;
-      /* ecrit_rapport("fat: new file %s de=%p size=%u\n",new_file->name,de,de->size); */
-      /*    fat_write_rapport(new_fat_element); */
+      /* log_trace("fat: new file %s de=%p size=%u\n",new_file->name,de,de->size); */
       if(current_file!=NULL)
 	current_file->next=new_file;
       else
@@ -227,24 +227,24 @@ static int date_dos2unix(const unsigned short f_time, const unsigned short f_dat
 	return secs+secwest;
 }
 
-static t_file_data *fat12_dir(t_param_disk *disk_car, const t_partition *partition, t_dir_data *dir_data, const unsigned long int first_cluster)
+static file_data_t *fat12_dir(disk_t *disk_car, const partition_t *partition, dir_data_t *dir_data, const unsigned long int first_cluster)
 {
-  const struct list_dir_struct *ls=(const struct list_dir_struct*)dir_data->private_dir_data;
+  const struct fat_dir_struct *ls=(const struct fat_dir_struct*)dir_data->private_dir_data;
   const struct fat_boot_sector*fat_header=ls->boot_sector;
   if(fat_header->cluster_size<1)
   {
-    ecrit_rapport("FAT12: Can't list files, bad cluster size\n");
+    log_error("FAT12: Can't list files, bad cluster size\n");
     return NULL;
   }
   if(fat_sector_size(fat_header)==0)
   {
-    ecrit_rapport("FAT12: Can't list files, bad sector size\n");
+    log_error("FAT12: Can't list files, bad sector size\n");
     return NULL;
   }
   if(first_cluster==0)
     return fat1x_rootdir(disk_car,partition,dir_data->debug,fat_header);
   {
-    t_file_data *dir_list;
+    file_data_t *dir_list;
     unsigned int cluster_size=fat_header->cluster_size;
     unsigned char *buffer_dir=MALLOC(fat_sector_size(fat_header)*cluster_size*10);
     unsigned int cluster;
@@ -258,11 +258,11 @@ static t_file_data *fat12_dir(t_param_disk *disk_car, const t_partition *partiti
       uint64_t start=partition->part_offset+(uint64_t)(le16(fat_header->reserved)+fat_header->fats*le16(fat_header->fat_length)+(get_dir_entries(fat_header)*32+fat_sector_size(fat_header)-1)/fat_sector_size(fat_header)+(cluster-2)*cluster_size)*fat_sector_size(fat_header);
       if(dir_data->debug>0)
       {
-	ecrit_rapport("FAT12: cluster=%u(0x%x), pos=%lu\n",cluster,cluster,(long unsigned)(start/fat_sector_size(fat_header)));
+	log_trace("FAT12: cluster=%u(0x%x), pos=%lu\n",cluster,cluster,(long unsigned)(start/fat_sector_size(fat_header)));
       }
       if(disk_car->read(disk_car, cluster_size*fat_sector_size(fat_header), buffer_dir+(uint64_t)fat_sector_size(fat_header)*cluster_size*nbr_cluster, start))
       {
-	ecrit_rapport("FAT12: Can't read directory cluster\n");
+	log_error("FAT12: Can't read directory cluster\n");
 	stop=1;
       }
     }
@@ -272,24 +272,24 @@ static t_file_data *fat12_dir(t_param_disk *disk_car, const t_partition *partiti
   }
 }
 
-static t_file_data *fat16_dir(t_param_disk *disk_car, const t_partition *partition, t_dir_data *dir_data, const unsigned long int first_cluster)
+static file_data_t *fat16_dir(disk_t *disk_car, const partition_t *partition, dir_data_t *dir_data, const unsigned long int first_cluster)
 {
-  const struct list_dir_struct *ls=(const struct list_dir_struct*)dir_data->private_dir_data;
+  const struct fat_dir_struct *ls=(const struct fat_dir_struct*)dir_data->private_dir_data;
   const struct fat_boot_sector*fat_header=ls->boot_sector;
   if(fat_header->cluster_size<1)
   {
-    ecrit_rapport("FAT16: Can't list files, bad cluster size.\n");
+    log_error("FAT16: Can't list files, bad cluster size.\n");
     return NULL;
   }
   if(fat_sector_size(fat_header)==0)
   {
-    ecrit_rapport("FAT16: Can't list files, bad sector size\n");
+    log_error("FAT16: Can't list files, bad sector size\n");
     return NULL;
   }
   if(first_cluster==0)
     return fat1x_rootdir(disk_car,partition,dir_data->debug,fat_header);
   {
-    t_file_data *dir_list=NULL;
+    file_data_t *dir_list=NULL;
     unsigned int cluster_size=fat_header->cluster_size;
     unsigned char *buffer_dir=MALLOC(disk_car->sector_size*cluster_size*10);
     unsigned int cluster;
@@ -304,11 +304,11 @@ static t_file_data *fat16_dir(t_param_disk *disk_car, const t_partition *partiti
       uint64_t start=partition->part_offset+(uint64_t)(le16(fat_header->reserved)+fat_header->fats*le16(fat_header->fat_length)+(get_dir_entries(fat_header)*32+disk_car->sector_size-1)/disk_car->sector_size+(cluster-2)*cluster_size)*disk_car->sector_size;
       if(dir_data->debug>0)
       {
-	ecrit_rapport("FAT16 cluster=%u(0x%x), pos=%lu\n",cluster,cluster,(long unsigned)(start/disk_car->sector_size));
+	log_trace("FAT16 cluster=%u(0x%x), pos=%lu\n",cluster,cluster,(long unsigned)(start/disk_car->sector_size));
       }
       if(disk_car->read(disk_car, cluster_size*disk_car->sector_size, buffer_dir+(uint64_t)disk_car->sector_size*cluster_size*nbr_cluster, start))
       {
-	ecrit_rapport("FAT16: Can't read directory cluster\n");
+	log_error("FAT16: Can't read directory cluster\n");
 	stop=1;
       }
     }
@@ -318,27 +318,27 @@ static t_file_data *fat16_dir(t_param_disk *disk_car, const t_partition *partiti
   }
 }
 
-static t_file_data *fat32_dir(t_param_disk *disk_car, const t_partition *partition, t_dir_data *dir_data, const unsigned long int first_cluster)
+static file_data_t *fat32_dir(disk_t *disk_car, const partition_t *partition, dir_data_t *dir_data, const unsigned long int first_cluster)
 {
-  const struct list_dir_struct *ls=(const struct list_dir_struct*)dir_data->private_dir_data;
+  const struct fat_dir_struct *ls=(const struct fat_dir_struct*)dir_data->private_dir_data;
   const struct fat_boot_sector*fat_header=ls->boot_sector;
   if(fat_header->cluster_size==0)
   {
-    ecrit_rapport("FAT32: Can't list files, bad cluster size.\n");
+    log_error("FAT32: Can't list files, bad cluster size.\n");
     return NULL;
   }
   if(le32(fat_header->root_cluster)==0)
   {
-    ecrit_rapport("FAT32: Can't list files, bad root cluster.\n");
+    log_error("FAT32: Can't list files, bad root cluster.\n");
     return NULL;
   }
   if(fat_sector_size(fat_header)==0)
   {
-    ecrit_rapport("FAT32: Can't list files, bad sector size.\n");
+    log_error("FAT32: Can't list files, bad sector size.\n");
     return NULL;
   }
   {
-    t_file_data *dir_list;
+    file_data_t *dir_list;
     unsigned int cluster_size=fat_header->cluster_size;
     unsigned char *buffer_dir=MALLOC(fat_sector_size(fat_header)*cluster_size*10);
     unsigned int cluster;
@@ -353,16 +353,16 @@ static t_file_data *fat32_dir(t_param_disk *disk_car, const t_partition *partiti
       uint64_t start=partition->part_offset+(uint64_t)(le16(fat_header->reserved)+fat_header->fats*le32(fat_header->fat32_length)+(cluster-2)*cluster_size)*fat_sector_size(fat_header);
       if(dir_data->debug>0)
       {
-	ecrit_rapport("FAT32 cluster=%u(0x%x), pos=%lu\n",cluster,cluster,(long unsigned)(start/fat_sector_size(fat_header)));
+	log_trace("FAT32 cluster=%u(0x%x), pos=%lu\n",cluster,cluster,(long unsigned)(start/fat_sector_size(fat_header)));
       }
       if(disk_car->read(disk_car, cluster_size*fat_sector_size(fat_header), buffer_dir+(uint64_t)fat_sector_size(fat_header)*cluster_size*nbr_cluster, start))
       {
-	ecrit_rapport("FAT32: Can't read directory cluster\n");
+	log_error("FAT32: Can't read directory cluster\n");
 	stop=1;
       }
-//      ecrit_rapport("read cluster %u\n",cluster);
+//      log_trace("read cluster %u\n",cluster);
     }
-//    ecrit_rapport("nbr_cluster=%u\n",nbr_cluster);
+//    log_trace("nbr_cluster=%u\n",nbr_cluster);
     dir_list=dir_fat_aux(buffer_dir,fat_sector_size(fat_header)*cluster_size*nbr_cluster,cluster_size);
     free(buffer_dir);
     return dir_list;
@@ -370,22 +370,22 @@ static t_file_data *fat32_dir(t_param_disk *disk_car, const t_partition *partiti
 }
 
 
-static t_file_data *fat1x_rootdir(t_param_disk *disk_car, const t_partition *partition, const int debug, const struct fat_boot_sector*fat_header)
+static file_data_t *fat1x_rootdir(disk_t *disk_car, const partition_t *partition, const int debug, const struct fat_boot_sector*fat_header)
 {
   unsigned int root_size=(get_dir_entries(fat_header)*32+disk_car->sector_size-1)/disk_car->sector_size*disk_car->sector_size;
   if(debug>1)
   {
-    ecrit_rapport("fat1x_rootdir root_size=%u sectors\n",root_size/disk_car->sector_size);
+    log_trace("fat1x_rootdir root_size=%u sectors\n",root_size/disk_car->sector_size);
   }
   {
-    t_file_data *res=NULL;
+    file_data_t *res=NULL;
     uint64_t start;
     unsigned char *buffer_dir;
     buffer_dir=(unsigned char*)MALLOC(root_size);
     start=partition->part_offset+(uint64_t)((le16(fat_header->reserved)+fat_header->fats*le16(fat_header->fat_length))*disk_car->sector_size);
     if(disk_car->read(disk_car, root_size, buffer_dir, start))
     {
-      ecrit_rapport("FAT 1x: Can't read root directory\n");
+      log_error("FAT 1x: Can't read root directory\n");
       free(buffer_dir);
       return NULL;
     }
@@ -419,10 +419,10 @@ static void set_secwest(void)
 #endif
 }
 
-int dir_partition_fat_init(t_param_disk *disk_car, const t_partition *partition, t_dir_data *dir_data, const int debug)
+int dir_partition_fat_init(disk_t *disk_car, const partition_t *partition, dir_data_t *dir_data, const int debug)
 {
   static unsigned char *buffer;
-  static struct list_dir_struct *ls;
+  static struct fat_dir_struct *ls;
   buffer=(unsigned char*)MALLOC(0x200);
   if(disk_car->read(disk_car,0x200, buffer, partition->part_offset+(uint64_t)partition->boot_sector*disk_car->sector_size))
   {
@@ -430,7 +430,7 @@ int dir_partition_fat_init(t_param_disk *disk_car, const t_partition *partition,
     return -1;
   }
   set_secwest();
-  ls=(struct list_dir_struct *)MALLOC(sizeof(*ls));
+  ls=(struct fat_dir_struct *)MALLOC(sizeof(*ls));
   ls->boot_sector=(struct fat_boot_sector*)buffer;
   strncpy(dir_data->current_directory,"/",sizeof(dir_data->current_directory));
   dir_data->current_inode=0;
@@ -451,7 +451,7 @@ int dir_partition_fat_init(t_param_disk *disk_car, const t_partition *partition,
       dir_data->get_dir=fat32_dir;
       break;
     default:
-      ecrit_rapport("Not a valid FAT type (upart_type=%u)\n",partition->upart_type);
+      log_critical("Not a valid FAT type (upart_type=%u)\n",partition->upart_type);
       free(ls->boot_sector);
       free(ls);
       dir_data->private_dir_data=NULL;
@@ -460,9 +460,9 @@ int dir_partition_fat_init(t_param_disk *disk_car, const t_partition *partition,
   return 0;
 }
 
-static void dir_partition_fat_close(t_dir_data *dir_data)
+static void dir_partition_fat_close(dir_data_t *dir_data)
 {
-  struct list_dir_struct *ls=(struct list_dir_struct*)dir_data->private_dir_data;
+  struct fat_dir_struct *ls=(struct fat_dir_struct*)dir_data->private_dir_data;
   free(ls->boot_sector);
   free(ls);
 }
