@@ -19,6 +19,6 @@
     Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
  */
-t_file_data *dir_fat_aux(const unsigned char*buffer, const unsigned int size, const unsigned int cluster_size);
-int dir_partition_fat_init(t_param_disk *disk_car, const t_partition *partition, t_dir_data *dir_data, const int debug);
+file_data_t *dir_fat_aux(const unsigned char*buffer, const unsigned int size, const unsigned int cluster_size);
+int dir_partition_fat_init(disk_t *disk_car, const partition_t *partition, dir_data_t *dir_data, const int debug);
 
