@@ -29,10 +29,10 @@
 #include "types.h"
 #include "common.h"
 #include "fatx.h"
-static void set_FATX_info(t_param_disk *disk_car, const struct disk_fatx *fatx_block,t_partition *partition);
-static int test_fatx(t_param_disk *disk_car, const struct disk_fatx *fatx_block,t_partition *partition,const int debug, const int dump_ind);
+static void set_FATX_info(disk_t *disk_car, const struct disk_fatx *fatx_block,partition_t *partition);
+static int test_fatx(disk_t *disk_car, const struct disk_fatx *fatx_block,partition_t *partition,const int debug, const int dump_ind);
 
-static int test_fatx(t_param_disk *disk_car, const struct disk_fatx *fatx_block,t_partition *partition,const int debug, const int dump_ind)
+static int test_fatx(disk_t *disk_car, const struct disk_fatx *fatx_block,partition_t *partition,const int debug, const int dump_ind)
 {
   if(memcmp(fatx_block->magic,"FATX",4)==0)
   {
@@ -42,7 +42,7 @@ static int test_fatx(t_param_disk *disk_car, const struct disk_fatx *fatx_block,
   return 1;
 }
 
-int check_FATX(t_param_disk *disk_car,t_partition *partition,const int debug)
+int check_FATX(disk_t *disk_car,partition_t *partition,const int debug)
 {
   unsigned char buffer[8*DEFAULT_SECTOR_SIZE];
   if(disk_car->read(disk_car,sizeof(buffer), &buffer, partition->part_offset)!=0)
@@ -53,7 +53,7 @@ int check_FATX(t_param_disk *disk_car,t_partition *partition,const int debug)
   return 0;
 }
 
-int recover_FATX(t_param_disk *disk_car, const struct disk_fatx *fatx_block,t_partition *partition, const int debug, const int dump_ind)
+int recover_FATX(disk_t *disk_car, const struct disk_fatx *fatx_block,partition_t *partition, const int debug, const int dump_ind)
 {
   if(test_fatx(disk_car,fatx_block,partition,0,0)!=0)
     return 1;
@@ -64,7 +64,7 @@ int recover_FATX(t_param_disk *disk_car, const struct disk_fatx *fatx_block,t_pa
   return 0;
 }
 
-static void set_FATX_info(t_param_disk *disk_car, const struct disk_fatx *fatx_block,t_partition *partition)
+static void set_FATX_info(disk_t *disk_car, const struct disk_fatx *fatx_block,partition_t *partition)
 {
   partition->name[0]='\0';
   strncpy(partition->info,"FATX",sizeof(partition->info));
