@@ -2,7 +2,7 @@
 
     File: file_au.c
 
-    Copyright (C) 1998-2005 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 1998-2005,2007 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,26 +28,36 @@
 #endif
 #include <stdio.h>
 #include "types.h"
-#include "photorec.h"
+#include "filegen.h"
 
-static const char *header_check_au(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery);
-const t_file_hint file_hint_au= {
+static void register_header_check_au(file_stat_t *file_stat);
+static int header_check_au(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  const file_recovery_t *file_recovery, file_recovery_t *file_recovery_new);
+
+const file_hint_t file_hint_au= {
   .extension="au",
   .description="Sun/NeXT audio data",
   .min_header_distance=0,
-  .min_filesize=111,
   .max_filesize=PHOTOREC_MAX_FILE_SIZE,
   .recover=1,
   .header_check=&header_check_au,
-  .data_check=NULL,
-  .file_check=NULL
+  .register_header_check=&register_header_check_au
 };
-static const char *header_check_au(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery)
+
+static const unsigned char au_header[4]= {'.','s','n','d'};
+
+static void register_header_check_au(file_stat_t *file_stat)
 {
-  const unsigned char au_header[4]= {'.','s','n','d'};
-  if(memcmp(buffer,au_header,sizeof(au_header))==0)
-    return file_hint_au.extension;
-  return NULL;
+  register_header_check(0, au_header,sizeof(au_header), &header_check_au, file_stat);
 }
 
-
+static int header_check_au(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only, const file_recovery_t *file_recovery, file_recovery_t *file_recovery_new)
+{
+  if(memcmp(buffer,au_header,sizeof(au_header))==0)
+  {
+    reset_file_recovery(file_recovery_new);
+    file_recovery_new->min_filesize=111;
+    file_recovery_new->extension=file_hint_au.extension;
+    return 1;
+  }
+  return 0;
+}
