@@ -2,7 +2,7 @@
 
     File: file_ctg.c
 
-    Copyright (C) 1998-2005 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 1998-2005,2007 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,25 +28,37 @@
 #endif
 #include <stdio.h>
 #include "types.h"
-#include "photorec.h"
+#include "filegen.h"
 
-static const char* header_check_ctg(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery);
-const t_file_hint file_hint_ctg= {
+static void register_header_check_ctg(file_stat_t *file_stat);
+static int header_check_ctg(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only, const file_recovery_t *file_recovery, file_recovery_t *file_recovery_new);
+
+const file_hint_t file_hint_ctg= {
   .extension="ctg",
   .description="Canon catalog",
   .min_header_distance=0,
-  .min_filesize=0,
   .max_filesize=4634,
   .recover=0,
   .header_check=&header_check_ctg,
-  .data_check=NULL,
-  .file_check=NULL
+  .register_header_check=&register_header_check_ctg
 };
-static const char* header_check_ctg(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery)
+
+static const unsigned char ctg_header[7]= {':','\\','D','C','I','M','\\'};
+
+static void register_header_check_ctg(file_stat_t *file_stat)
 {
-  if(memcmp(&buffer[1],":\\DCIM\\",7)==0)
-    return file_hint_ctg.extension;
-  return NULL;
+  register_header_check(1, ctg_header,sizeof(ctg_header), &header_check_ctg, file_stat);
+}
+
+static int header_check_ctg(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only, const file_recovery_t *file_recovery, file_recovery_t *file_recovery_new)
+{
+  if(memcmp(buffer+1, ctg_header,sizeof(ctg_header))==0)
+  {
+    reset_file_recovery(file_recovery_new);
+    file_recovery_new->extension=file_hint_ctg.extension;
+    return 1;
+  }
+  return 0;
 }
 
 
