@@ -2,7 +2,7 @@
 
     File: file_dbf.c
 
-    Copyright (C) 2006 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 2006-2007 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,27 +28,36 @@
 #endif
 #include <stdio.h>
 #include "types.h"
-#include "photorec.h"
+#include "filegen.h"
 
-static const char* header_check_dbf(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery);
-const t_file_hint file_hint_dbf= {
+static void register_header_check_dbf(file_stat_t *file_stat);
+static int header_check_dbf(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only, const file_recovery_t *file_recovery, file_recovery_t *file_recovery_new);
+
+const file_hint_t file_hint_dbf= {
   .extension="dbf",
   .description="DBase 3, prone to false positive",
   .min_header_distance=0,
-  .min_filesize=0,
   .max_filesize=PHOTOREC_MAX_FILE_SIZE,
   .recover=1,
   .header_check=&header_check_dbf,
-  .data_check=NULL,
-  .file_check=NULL
+  .register_header_check=&register_header_check_dbf
 };
 
-static const char* header_check_dbf(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery)
+static const unsigned char dbf_header[1]= {0x3};
+
+static void register_header_check_dbf(file_stat_t *file_stat)
+{
+  register_header_check(0, dbf_header,sizeof(dbf_header), &header_check_dbf, file_stat);
+}
+
+static int header_check_dbf(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only, const file_recovery_t *file_recovery, file_recovery_t *file_recovery_new)
 {
   /* 0x03 YY MM DD */
   if(buffer[0]==0x3 && (buffer[1]>80 || buffer[1]<20) && (buffer[2]>=1 && buffer[2]<=12) && (buffer[3]>=1 && buffer[3]<=31))
   {
-    return file_hint_dbf.extension;
+    reset_file_recovery(file_recovery_new);
+    file_recovery_new->extension=file_hint_dbf.extension;
+    return 1;
   }
-  return NULL;
+  return 0;
 }
