@@ -2,7 +2,7 @@
 
     File: file_dv.c
 
-    Copyright (C) 2006 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 2006-2007 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,29 +28,39 @@
 #endif
 #include <stdio.h>
 #include "types.h"
-#include "photorec.h"
+#include "filegen.h"
 
-static const char* header_check_dv(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery);
-const t_file_hint file_hint_dv= {
+static void register_header_check_dv(file_stat_t *file_stat);
+static int header_check_dv(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only, const file_recovery_t *file_recovery, file_recovery_t *file_recovery_new);
+
+const file_hint_t file_hint_dv= {
   .extension="dv",
   .description="DIF Digital Video",
   .min_header_distance=0,
-  .min_filesize=0,
   .max_filesize=PHOTOREC_MAX_FILE_SIZE,
   .recover=1,
   .header_check=&header_check_dv,
-  .data_check=NULL,
-  .file_check=NULL
+  .register_header_check=&register_header_check_dv
 };
+static const unsigned char dv_header[3]= {0x1f, 0x07, 0x00};
 
-static const char* header_check_dv(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery)
+static void register_header_check_dv(file_stat_t *file_stat)
+{
+  register_header_check(0, dv_header,sizeof(dv_header), &header_check_dv, file_stat);
+}
+
+static int header_check_dv(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only, const file_recovery_t *file_recovery, file_recovery_t *file_recovery_new)
 {
   if(file_recovery!=NULL && file_recovery->file_stat!=NULL && file_recovery->file_stat->file_hint==&file_hint_dv)
-    return NULL;
+    return 0;
   /* The header may be only 3 bytes */
   if(buffer[0]==0x1f && buffer[1]==0x07 && buffer[2]==0x00 && buffer[5]==0x78 && buffer[6]==0x78 && buffer[7]==0x78)
-    return file_hint_dv.extension;
-  return NULL;
+  {
+    reset_file_recovery(file_recovery_new);
+    file_recovery_new->extension=file_hint_dv.extension;
+    return 1;
+  }
+  return 0;
 }
 
 
