@@ -2,7 +2,7 @@
 
     File: file_gz.c
 
-    Copyright (C) 1998-2006 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 1998-2007 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,22 +28,29 @@
 #endif
 #include <stdio.h>
 #include "types.h"
-#include "photorec.h"
+#include "filegen.h"
 
-static const char* header_check_gz(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery);
-const t_file_hint file_hint_gz= {
+static void register_header_check_gz(file_stat_t *file_stat);
+static int header_check_gz(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only, const file_recovery_t *file_recovery, file_recovery_t *file_recovery_new);
+
+const file_hint_t file_hint_gz= {
   .extension="gz",
   .description="gzip compressed data",
   .min_header_distance=0,
-  .min_filesize=22,
   .max_filesize=PHOTOREC_MAX_FILE_SIZE,
   .recover=1,
   .header_check=&header_check_gz,
-  .data_check=NULL,
-  .file_check=NULL
+  .register_header_check=&register_header_check_gz
 };
 
-static const char* header_check_gz(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery)
+static const unsigned char gz_header[3]= {0x1F, 0x8B, 0x08};
+
+static void register_header_check_gz(file_stat_t *file_stat)
+{
+  register_header_check(0, gz_header,sizeof(gz_header), &header_check_gz, file_stat);
+}
+
+static int header_check_gz(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only, const file_recovery_t *file_recovery, file_recovery_t *file_recovery_new)
 {
   /* gzip file format:
    * a 10-byte header, containing a magic number, a version number and a timestamp
@@ -53,7 +60,12 @@ static const char* header_check_gz(const unsigned char *buffer, const unsigned i
    * the length (32 bits) of the original uncompressed data
    */
   /* gzip, deflate */
-  if(buffer[0]==0x1F && buffer[1]==0x8B && buffer[2]==0x08 && (buffer[3]==0 || buffer[3]==0x08))
-    return file_hint_gz.extension;
-  return NULL;
+  if(buffer[0]==0x1F && buffer[1]==0x8B && buffer[2]==0x08 && (buffer[3]&0xe0)==0)
+  {
+    reset_file_recovery(file_recovery_new);
+    file_recovery_new->extension=file_hint_gz.extension;
+    file_recovery_new->min_filesize=22;
+    return 1;
+  }
+  return 0;
 }
