@@ -2,7 +2,7 @@
 
     File: file_mid.c
 
-    Copyright (C) 1998-2006 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 1998-2007 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,35 +28,44 @@
 #endif
 #include <stdio.h>
 #include "types.h"
-#include "photorec.h"
-
-static const char* header_check_mid(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery);
-static void file_check_mid(t_file_recovery *file_recovery);
+#include "filegen.h"
 
 
-const t_file_hint file_hint_mid= {
+static void register_header_check_mid(file_stat_t *file_stat);
+static int header_check_mid(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only, const file_recovery_t *file_recovery, file_recovery_t *file_recovery_new);
+static void file_check_mid(file_recovery_t *file_recovery);
+
+const file_hint_t file_hint_mid= {
   .extension="mid",
   .description="MIDI Musical Instrument Digital Interface",
   .min_header_distance=0,
-  .min_filesize=21,
   .max_filesize=50*1024*1024,
   .recover=1,
   .header_check=&header_check_mid,
-  .data_check=NULL,
-  .file_check=&file_check_mid
+  .register_header_check=&register_header_check_mid
 };
 
-static const char* header_check_mid(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery)
+static const unsigned char mid_header[4]  = { 'M','T','h','d'};
+
+static void register_header_check_mid(file_stat_t *file_stat)
 {
-  const unsigned char mid_header[4]  = { 'M','T','h','d'};
-  if(memcmp(buffer,mid_header,sizeof(mid_header))==0)
-  {
-    return file_hint_mid.extension;
-  }
-  return NULL;
+  register_header_check(0, mid_header,sizeof(mid_header), &header_check_mid, file_stat);
 }
 
-static void file_check_mid(t_file_recovery *file_recovery)
+static int header_check_mid(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only, const file_recovery_t *file_recovery, file_recovery_t *file_recovery_new)
+{
+  if(memcmp(buffer,mid_header,sizeof(mid_header))==0)
+  {
+    reset_file_recovery(file_recovery_new);
+    file_recovery_new->extension=file_hint_mid.extension;
+    file_recovery_new->min_filesize=21;
+    file_recovery_new->file_check=&file_check_mid;
+    return 1;
+  }
+  return 0;
+}
+
+static void file_check_mid(file_recovery_t *file_recovery)
 {
   const unsigned char mid_footer[3]= {0xff, 0x2f, 0x00};
   file_search_footer(file_recovery, mid_footer,sizeof(mid_footer));
