@@ -2,7 +2,7 @@
 
     File: file_mpg.c
 
-    Copyright (C) 1998-2005 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 1998-2005,2007 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,29 +28,42 @@
 #endif
 #include <stdio.h>
 #include "types.h"
-#include "photorec.h"
+#include "filegen.h"
 
-static const char* header_check_mpg(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery);
-const t_file_hint file_hint_mpg= {
+
+static void register_header_check_mpg(file_stat_t *file_stat);
+static int header_check_mpg(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only, const file_recovery_t *file_recovery, file_recovery_t *file_recovery_new);
+
+const file_hint_t file_hint_mpg= {
   .extension="mpg",
   .description="Moving Picture Experts Group video",
   .min_header_distance=0,
-  .min_filesize=0,
   .max_filesize=PHOTOREC_MAX_FILE_SIZE,
   .recover=1,
   .header_check=&header_check_mpg,
-  .data_check=NULL,
-  .file_check=NULL
+  .register_header_check=&register_header_check_mpg
 };
-static const char* header_check_mpg(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery)
+
+static const unsigned char mpg_header[3]= {0x00, 0x00, 0x01};
+
+static void register_header_check_mpg(file_stat_t *file_stat)
+{
+  register_header_check(0, mpg_header,sizeof(mpg_header), &header_check_mpg, file_stat);
+}
+
+static int header_check_mpg(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only, const file_recovery_t *file_recovery, file_recovery_t *file_recovery_new)
 {
   if(file_recovery!=NULL && file_recovery->file_stat!=NULL && file_recovery->file_stat->file_hint==&file_hint_mpg)
-    return NULL;
+    return 0;
   /* 0xBA is the must common value */
   if(buffer[0]==0x00 && buffer[1]==0x00 && buffer[2]==0x01 &&
       (buffer[3]==0xB0 || buffer[3]==0xB3 || buffer[3]==0xB5 || buffer[3]==0xBA || buffer[3]==0xBB))
-    return file_hint_mpg.extension;
-  return NULL;
+  {
+    reset_file_recovery(file_recovery_new);
+    file_recovery_new->extension=file_hint_mpg.extension;
+    return 1;
+  }
+  return 0;
 }
 
 
