@@ -2,7 +2,7 @@
 
     File: file_prc.c
 
-    Copyright (C) 2006 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 2006-2007 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,26 +28,35 @@
 #endif
 #include <stdio.h>
 #include "types.h"
-#include "photorec.h"
+#include "filegen.h"
 
-static const char* header_check_prc(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery);
+static void register_header_check_prc(file_stat_t *file_stat);
+static int header_check_prc(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only, const file_recovery_t *file_recovery, file_recovery_t *file_recovery_new);
 
-const t_file_hint file_hint_prc= {
+const file_hint_t file_hint_prc= {
   .extension="prc",
   .description="PalmOS application",
   .min_header_distance=0,
-  .min_filesize=16,
   .max_filesize=PHOTOREC_MAX_FILE_SIZE,
   .recover=1,
   .header_check=&header_check_prc,
-  .data_check=NULL,
-  .file_check=NULL
+  .register_header_check=&register_header_check_prc
 };
 
-static const char* header_check_prc(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery)
+static const unsigned char prc_header[16]= {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,'a','p','p','l'};
+
+static void register_header_check_prc(file_stat_t *file_stat)
 {
-  const unsigned char prc_header[16]= {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,'a','p','p','l'};
+  register_header_check(0x30, prc_header,sizeof(prc_header), &header_check_prc, file_stat);
+}
+
+static int header_check_prc(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only, const file_recovery_t *file_recovery, file_recovery_t *file_recovery_new)
+{
   if(memcmp(&buffer[0x30],prc_header,sizeof(prc_header))==0)
-    return file_hint_prc.extension;
-  return NULL;
+  {
+    reset_file_recovery(file_recovery_new);
+    file_recovery_new->extension=file_hint_prc.extension;
+    return 1;
+  }
+  return 0;
 }
