@@ -28,27 +28,36 @@
 #endif
 #include <stdio.h>
 #include "types.h"
-#include "photorec.h"
+#include "filegen.h"
 
-static const char* header_check_qdf(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery);
-const t_file_hint file_hint_qdf= {
+
+static void register_header_check_qdf(file_stat_t *file_stat);
+static int header_check_qdf(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only, const file_recovery_t *file_recovery, file_recovery_t *file_recovery_new);
+
+const file_hint_t file_hint_qdf= {
   .extension="qdf",
   .description="Quicken",
   .min_header_distance=0,
-  .min_filesize=0,
   .max_filesize=PHOTOREC_MAX_FILE_SIZE,
   .recover=1,
   .header_check=&header_check_qdf,
-  .data_check=NULL,
-  .file_check=NULL
+	.register_header_check=&register_header_check_qdf
 };
 
-static const char* header_check_qdf(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery)
+static const unsigned char qdf_header[6]  = { 0xAC, 0x9E, 0xBD, 0x8F, 0x00, 0x00};
+
+static void register_header_check_qdf(file_stat_t *file_stat)
 {
- const unsigned char qdf_header[6]  = { 0xAC, 0x9E, 0xBD, 0x8F, 0x00, 0x00};
-  if(memcmp(buffer,qdf_header,sizeof(qdf_header))==0)
-    return file_hint_qdf.extension;
-  return NULL;
+  register_header_check(0, qdf_header,sizeof(qdf_header), &header_check_qdf, file_stat);
 }
 
-
+static int header_check_qdf(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only, const file_recovery_t *file_recovery, file_recovery_t *file_recovery_new)
+{
+  if(memcmp(buffer,qdf_header,sizeof(qdf_header))==0)
+  {
+    reset_file_recovery(file_recovery_new);
+    file_recovery_new->extension=file_hint_qdf.extension;
+    return 1;
+  }
+  return 0;
+}
