@@ -2,7 +2,7 @@
 
     File: file_rdc.c
 
-    Copyright (C) 1998-2005 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 1998-2005,2007 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,26 +28,39 @@
 #endif
 #include <stdio.h>
 #include "types.h"
-#include "photorec.h"
+#include "filegen.h"
 
-static const char* header_check_rdc(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery);
-const t_file_hint file_hint_rdc= {
+
+static void register_header_check_rdc(file_stat_t *file_stat);
+static int header_check_rdc(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only, const file_recovery_t *file_recovery, file_recovery_t *file_recovery_new);
+
+const file_hint_t file_hint_rdc= {
   .extension="rdc",
   .description="Rollei picture",
   .min_header_distance=0,
-  .min_filesize=0,
   .max_filesize=PHOTOREC_MAX_FILE_SIZE,
   .recover=1,
   .header_check=&header_check_rdc,
-  .data_check=NULL,
-  .file_check=NULL
+  .register_header_check=&register_header_check_rdc
 };
-static const char* header_check_rdc(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery)
+
+static const unsigned char rdc_header[9]= {'D','S','C','-','I','m','a','g','e'};
+
+static void register_header_check_rdc(file_stat_t *file_stat)
+{
+  register_header_check(0, rdc_header,sizeof(rdc_header), &header_check_rdc, file_stat);
+}
+
+static int header_check_rdc(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only, const file_recovery_t *file_recovery, file_recovery_t *file_recovery_new)
 {
   /* Rollei */
-  if(memcmp (buffer, "DSC-Image", 9)==0)
-    return file_hint_rdc.extension;
-  return NULL;
+  if(memcmp(buffer, rdc_header, sizeof(rdc_header))==0)
+  {
+    reset_file_recovery(file_recovery_new);
+    file_recovery_new->extension=file_hint_rdc.extension;
+    return 1;
+  }
+  return 0;
 }
 
 
