@@ -2,7 +2,7 @@
 
     File: file_rm.c
 
-    Copyright (C) 2006 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 2007 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,27 +28,36 @@
 #endif
 #include <stdio.h>
 #include "types.h"
-#include "photorec.h"
+#include "filegen.h"
 
-static const char* header_check_rm(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery);
-const t_file_hint file_hint_rm= {
+
+static void register_header_check_rm(file_stat_t *file_stat);
+static int header_check_rm(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only, const file_recovery_t *file_recovery, file_recovery_t *file_recovery_new);
+
+const file_hint_t file_hint_rm= {
   .extension="rm",
   .description="Real Audio",
   .min_header_distance=0,
-  .min_filesize=0,
   .max_filesize=PHOTOREC_MAX_FILE_SIZE,
   .recover=1,
   .header_check=&header_check_rm,
-  .data_check=NULL,
-  .file_check=NULL
+  .register_header_check=&register_header_check_rm
 };
 
-static const char* header_check_rm(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery)
+static const unsigned char rm_header[9]  = { '.', 'R', 'M', 'F', 0x00, 0x00, 0x00, 0x12, 0x00};
+
+static void register_header_check_rm(file_stat_t *file_stat)
 {
-  const unsigned char rm_header[9]  = { 0x2e, 0x52, 0x4d, 0x46, 0x00, 0x00, 0x00, 0x12, 0x00};
-  if(memcmp(buffer,rm_header,sizeof(rm_header))==0)
-    return file_hint_rm.extension;
-  return NULL;
+  register_header_check(0, rm_header,sizeof(rm_header), &header_check_rm, file_stat);
 }
 
-
+static int header_check_rm(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only, const file_recovery_t *file_recovery, file_recovery_t *file_recovery_new)
+{
+  if(memcmp(buffer,rm_header,sizeof(rm_header))==0)
+  {
+    reset_file_recovery(file_recovery_new);
+    file_recovery_new->extension=file_hint_rm.extension;
+    return 1;
+  }
+  return 0;
+}
