@@ -2,7 +2,7 @@
 
     File: file_txt.c
 
-    Copyright (C) 2005-2006 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 2005-2007 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -33,30 +33,81 @@
 #include <stdio.h>
 #include "types.h"
 #include "common.h"
-#include "photorec.h"
-extern const t_file_hint file_hint_doc;
-extern const t_file_hint file_hint_jpg;
-extern const t_file_hint file_hint_zip;
+#include "filegen.h"
+#include "log.h"
+
+/* Allow a small memory leak */
+#define OPT_MALLOC
+
+extern const file_hint_t file_hint_doc;
+extern const file_hint_t file_hint_jpg;
+extern const file_hint_t file_hint_pdf;
+extern const file_hint_t file_hint_zip;
 
 static inline int filtre(unsigned char car);
-static const char* header_check_txt(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery);
-static int data_check_txt(const unsigned char *buffer, const unsigned int buffer_size, t_file_recovery *file_recovery);
+
+static void register_header_check_txt(file_stat_t *file_stat);
+static int header_check_txt(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only, const file_recovery_t *file_recovery, file_recovery_t *file_recovery_new);
+static void register_header_check_fasttxt(file_stat_t *file_stat);
+static int header_check_fasttxt(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only, const file_recovery_t *file_recovery, file_recovery_t *file_recovery_new);
+
+static int data_check_txt(const unsigned char *buffer, const unsigned int buffer_size, file_recovery_t *file_recovery);
 static inline const unsigned char *find_in_mem(const unsigned char *haystack, const unsigned char * haystack_end,
     const unsigned char *needle, const unsigned int needle_length);
-static void file_check_txt(t_file_recovery *file_recovery);
+static void file_check_html(file_recovery_t *file_recovery);
+static void file_check_emlx(file_recovery_t *file_recovery);
 
-t_file_hint file_hint_txt= {
+file_hint_t file_hint_fasttxt= {
+  .extension="tx?",
+  .description="Text files with header: rtf,xml,xhtml,imm,pm,reg,sh,slk,ram",
+  .min_header_distance=0,
+  .max_filesize=PHOTOREC_MAX_FILE_SIZE,
+  .recover=1,
+  .header_check=&header_check_fasttxt,
+  .register_header_check=&register_header_check_fasttxt
+};
+
+file_hint_t file_hint_txt= {
   .extension="txt",
-  .description="Text file including asp,bat,C,jsp,perl,php,py,slk... scripts",
+  .description="Other text files: txt,html,asp,bat,C,jsp,perl,php,py... scripts",
   .min_header_distance=0,
-  .min_filesize=0,
   .max_filesize=PHOTOREC_MAX_FILE_SIZE,
   .recover=1,
   .header_check=&header_check_txt,
-  .data_check=&data_check_txt,
-  .file_check=&file_check_txt
+  .register_header_check=&register_header_check_txt
 };
 
+static const unsigned char header_imm[13]	= {'M','I','M','E','-','V','e','r','s','i','o','n',':'};
+static const unsigned char header_imm2[13]	= {'R','e','t','u','r','n','-','P','a','t','h',':',' '};
+static const unsigned char header_mail[5]	= {'F','r','o','m',' '};
+static const unsigned char header_perlm[7] 	= "package";
+static const unsigned char header_rtf[5]	= { '{','\\','r','t','f'};
+static const unsigned char header_reg[8]  	= "REGEDIT4";
+static const unsigned char header_sh[9]  	= "#!/bin/sh";
+static const unsigned char header_slk[10]  	= "ID;PSCALC3";
+static const unsigned char header_ram[7]	= "rtsp://";
+static const unsigned char header_xml[14]	= "<?xml version=";
+static const char sign_html[]	= "<html";
+
+static void register_header_check_txt(file_stat_t *file_stat)
+{
+  register_header_check(0, NULL,0, &header_check_txt, file_stat);
+}
+
+static void register_header_check_fasttxt(file_stat_t *file_stat)
+{
+  register_header_check(0, header_imm,sizeof(header_imm), &header_check_fasttxt, file_stat);
+  register_header_check(0, header_imm2,sizeof(header_imm2), &header_check_fasttxt, file_stat);
+  register_header_check(0, header_mail,sizeof(header_mail), &header_check_fasttxt, file_stat);
+  register_header_check(0, header_perlm,sizeof(header_perlm), &header_check_fasttxt, file_stat);
+  register_header_check(0, header_rtf,sizeof(header_rtf), &header_check_fasttxt, file_stat);
+  register_header_check(0, header_reg,sizeof(header_reg), &header_check_fasttxt, file_stat);
+  register_header_check(0, header_sh,sizeof(header_sh), &header_check_fasttxt, file_stat);
+  register_header_check(0, header_slk,sizeof(header_slk), &header_check_fasttxt, file_stat);
+  register_header_check(0, header_ram,sizeof(header_ram), &header_check_fasttxt, file_stat);
+  register_header_check(0, header_xml,sizeof(header_xml), &header_check_fasttxt, file_stat);
+}
+
 // #define DEBUG_FILETXT
 
 /* return 1 if char can be found in text file */
@@ -243,7 +294,7 @@ static int UTF2Lat(unsigned char *buffer_lower, const unsigned char *buffer, int
 	else
 	{
 #ifdef DEBUG_FILETXT
-	  ecrit_rapport("UTF2Lat: UTF character [%s] absent in Latin1 - dropped (%c, 0x%x)\n", bufU,*q,*q);
+	  log_trace("UTF2Lat: UTF character [%s] absent in Latin1 - dropped (%c, 0x%x)\n", bufU,*q,*q);
 #endif
 	  /* There is already a null but don't care */
 	  *q = '\0';
@@ -261,7 +312,7 @@ static int UTF2Lat(unsigned char *buffer_lower, const unsigned char *buffer, int
 	else
 	{
 #ifdef DEBUG_FILETXT
-	  ecrit_rapport( "UTF2Lat: non-UTF character [%s](0x%x) - dropped\n", bufU,bufU[0]);
+	  log_trace( "UTF2Lat: non-UTF character [%s](0x%x) - dropped\n", bufU,bufU[0]);
 #endif
 	  *q = '\0';
 	  return(p_org-buffer);
@@ -273,7 +324,7 @@ static int UTF2Lat(unsigned char *buffer_lower, const unsigned char *buffer, int
 /*
   if (*p)
   {
-    ecrit_rapport("UTF2Lat: buffer too small - string had to be truncated\n");
+    log_trace("UTF2Lat: buffer too small - string had to be truncated\n");
   }
 */
   return(p-buffer);
@@ -297,96 +348,162 @@ static inline const unsigned char *find_in_mem(const unsigned char *haystack, co
   return NULL;
 }
 
-static const char* header_check_txt(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery)
+static int header_check_fasttxt(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only, const file_recovery_t *file_recovery, file_recovery_t *file_recovery_new)
 {
-  char *buffer_lower;
-  unsigned int i;
-  const unsigned char header_bat[9]  	= "@echo off";
-  const unsigned char header_sh[9]  	= "#!/bin/sh";
-  const unsigned char header_slk[10]  	= "ID;PSCALC3";
-  const unsigned char header_rtf[5]= { '{','\\','r','t','f'};
-  const unsigned char header_imm[13]= {'M','I','M','E','-','V','e','r','s','i','o','n',':'};
-  const unsigned char header_imm2[13]={'R','e','t','u','r','n','-','P','a','t','h',':',' '};
-  const unsigned char header_mail[5]={'F','r','o','m',' '};
-  const unsigned char header_asp[22]=	"<%@ language=\"vbscript";
-  const unsigned char header_vcf[11]=	"begin:vcard";
-  const unsigned char header_ram[7]	= "rtsp://";
-  const unsigned char header_xml[14]	= "<?xml version=";
-  const unsigned char header_sig_perl[4] = "perl";
-  const unsigned char header_sig_python[6] = "python";
-  const unsigned char header_sig_ruby[4] = "ruby";
-  const char sign_c[]		= "#include";
-  const char sign_php[]	= "<?php";
-  const char sign_jsp[]	= "<%@";
-  const char sign_jsp2[]	= "<%=";
-  const char sign_asp[]	= "<% ";
-  const char sign_grisbi[]	= "Version_grisbi";
-  const char sign_html[]	= "<html";
-  const char sign_h[]		= "/*";
-  const unsigned char *haystack_end;
+  const char sign_grisbi[]		= "Version_grisbi";
   /* Incredimail has .imm extension but this extension isn't frequent */
   if(memcmp(buffer,header_imm,sizeof(header_imm))==0 ||
       memcmp(buffer,header_imm2,sizeof(header_imm2))==0 ||
       memcmp(buffer,header_mail,sizeof(header_mail))==0)
   {
     if(file_recovery!=NULL && file_recovery->file_stat!=NULL &&
-	file_recovery->file_stat->file_hint==&file_hint_txt &&
-	strstr(file_recovery->filename,"imm")!=NULL)
+	file_recovery->file_stat->file_hint==&file_hint_fasttxt &&
+	strcmp(file_recovery->extension,"imm")==0)
     {
-      return NULL;
+      return 0;
     }
-    file_hint_txt.data_check=NULL;
-    return "imm";
+    reset_file_recovery(file_recovery_new);
+    file_recovery_new->data_check=NULL;
+    file_recovery_new->extension="imm";
+    return 1;
+  }
+  if(memcmp(buffer,header_perlm,sizeof(header_perlm))==0 &&
+      (buffer[sizeof(header_perlm)]==' ' || buffer[sizeof(header_perlm)]=='\t'))
+  {
+    reset_file_recovery(file_recovery_new);
+    file_recovery_new->data_check=&data_check_txt;
+    file_recovery_new->file_check=&file_check_size;
+    file_recovery_new->extension="pm";
+    return 1;
   }
   if(memcmp(buffer,header_rtf,sizeof(header_rtf))==0)
   {
-    file_hint_txt.data_check=&data_check_txt;
-    return "rtf";
+    reset_file_recovery(file_recovery_new);
+    file_recovery_new->data_check=&data_check_txt;
+    file_recovery_new->file_check=&file_check_size;
+    file_recovery_new->extension="rtf";
+    return 1;
+  }
+  if(memcmp(buffer,header_reg,sizeof(header_reg))==0)
+  {
+    reset_file_recovery(file_recovery_new);
+    file_recovery_new->data_check=&data_check_txt;
+    file_recovery_new->file_check=&file_check_size;
+    file_recovery_new->extension="reg";
+    return 1;
   }
   if(memcmp(buffer,header_sh,sizeof(header_sh))==0)
   {
-    file_hint_txt.data_check=&data_check_txt;
-    return "sh";
+    reset_file_recovery(file_recovery_new);
+    file_recovery_new->data_check=&data_check_txt;
+    file_recovery_new->file_check=&file_check_size;
+    file_recovery_new->extension="sh";
+    return 1;
   }
   if(memcmp(buffer,header_slk,sizeof(header_slk))==0)
   {
-    file_hint_txt.data_check=&data_check_txt;
-    return "slk";
+    reset_file_recovery(file_recovery_new);
+    file_recovery_new->data_check=&data_check_txt;
+    file_recovery_new->file_check=&file_check_size;
+    file_recovery_new->extension="slk";
+    return 1;
   }
   if(memcmp(buffer,header_ram,sizeof(header_ram))==0)
   {
-    file_hint_txt.data_check=&data_check_txt;
-    return "ram";
+    reset_file_recovery(file_recovery_new);
+    file_recovery_new->data_check=&data_check_txt;
+    file_recovery_new->file_check=&file_check_size;
+    file_recovery_new->extension="ram";
+    return 1;
   }
   if(memcmp(buffer,header_xml,sizeof(header_xml))==0)
   {
-    file_hint_txt.data_check=&data_check_txt;
+    reset_file_recovery(file_recovery_new);
+    file_recovery_new->data_check=&data_check_txt;
     if(strstr(buffer,sign_grisbi)!=NULL)
-      return "gsb";
-    if(strstr(buffer,sign_html)!=NULL)
-      return "html";
-    return "xml";
+      file_recovery_new->extension="gsb";
+    else if(strstr(buffer,sign_html)!=NULL)
+    {
+      file_recovery_new->extension="html";
+      file_recovery_new->file_check=&file_check_html;
+    }
+    else
+      file_recovery_new->extension="xml";
+    file_recovery_new->file_check=&file_check_size;
+    return 1;
+  }
+  return 0;
+}
+
+static int header_check_txt(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only, const file_recovery_t *file_recovery, file_recovery_t *file_recovery_new)
+{
+  static char *buffer_lower=NULL;
+  static unsigned int buffer_lower_size=0;
+  unsigned int i;
+  const unsigned char header_asp[22]	= "<%@ language=\"vbscript";
+  const unsigned char header_bat[9]  	= "@echo off";
+  const unsigned char header_vcf[11]	= "begin:vcard";
+  const unsigned char header_sig_perl[4] = "perl";
+  const unsigned char header_sig_python[6] = "python";
+  const unsigned char header_sig_ruby[4] = "ruby";
+  const char sign_asp[]			= "<% ";
+  const char sign_c[]			= "#include";
+  const char sign_h[]			= "/*";
+  const char sign_jsp[]			= "<%@";
+  const char sign_jsp2[]		= "<%=";
+  const char sign_php[]			= "<?php";
+  const char sign_tex[]			= "\\begin{";
+  const unsigned char *haystack_end;
+  {
+    unsigned int tmp=0;
+    for(i=0;i<10 && isdigit(buffer[i]);i++)
+      tmp=tmp*10+buffer[i]-'0';
+    if(buffer[i]==0x0a && memcmp(buffer+i+1, header_imm2, sizeof(header_imm2))==0)
+    {
+      reset_file_recovery(file_recovery_new);
+      file_recovery_new->calculated_file_size=tmp+i+1;
+      file_recovery_new->data_check=NULL;
+      file_recovery_new->file_check=&file_check_emlx;
+      file_recovery_new->extension="emlx";
+      return 1;
+    }
+  }
+  /* Don't malloc/free memory every time, small memory leak */
+  if(buffer_lower_size<buffer_size+16)
+  {
+    free(buffer_lower);
+    buffer_lower=NULL;
+  }
+  if(buffer_lower==NULL)
+  {
+    buffer_lower_size=buffer_size+16;
+    buffer_lower=MALLOC(buffer_lower_size);
   }
-  buffer_lower=MALLOC(buffer_size+16);
   haystack_end=buffer_lower+buffer_size;
   i=UTF2Lat(buffer_lower,buffer,buffer_size);
   if(memcmp(buffer_lower,header_bat,sizeof(header_bat))==0)
   {
-    free(buffer_lower);
-    file_hint_txt.data_check=&data_check_txt;
-    return "bat";
+    reset_file_recovery(file_recovery_new);
+    file_recovery_new->data_check=&data_check_txt;
+    file_recovery_new->file_check=&file_check_size;
+    file_recovery_new->extension="bat";
+    return 1;
   }
   if(memcmp(buffer_lower,header_asp,sizeof(header_asp))==0)
   {
-    free(buffer_lower);
-    file_hint_txt.data_check=&data_check_txt;
-    return "asp";
+    reset_file_recovery(file_recovery_new);
+    file_recovery_new->data_check=&data_check_txt;
+    file_recovery_new->file_check=&file_check_size;
+    file_recovery_new->extension="asp";
+    return 1;
   }
   if(memcmp(buffer_lower,header_vcf,sizeof(header_vcf))==0)
   {
-    free(buffer_lower);
-    file_hint_txt.data_check=&data_check_txt;
-    return "vcf";
+    reset_file_recovery(file_recovery_new);
+    file_recovery_new->data_check=&data_check_txt;
+    file_recovery_new->file_check=&file_check_size;
+    file_recovery_new->extension="vcf";
+    return 1;
   }
   if(buffer[0]=='#' && buffer[1]=='!')
   {
@@ -399,31 +516,45 @@ static const char* header_check_txt(const unsigned char *buffer, const unsigned
       haystack_end=res;
     if(find_in_mem(haystack,haystack_end,header_sig_perl,sizeof(header_sig_perl)) != NULL)
     {
-      free(buffer_lower);
-      file_hint_txt.data_check=&data_check_txt;
-      return "pl";
+      reset_file_recovery(file_recovery_new);
+      file_recovery_new->data_check=&data_check_txt;
+    file_recovery_new->file_check=&file_check_size;
+      file_recovery_new->extension="pl";
+      return 1;
     }
     if(find_in_mem(haystack,haystack_end,header_sig_python,sizeof(header_sig_python)) != NULL)
     {
-      free(buffer_lower);
-      file_hint_txt.data_check=&data_check_txt;
-      return "py";
+      reset_file_recovery(file_recovery_new);
+      file_recovery_new->data_check=&data_check_txt;
+      file_recovery_new->file_check=&file_check_size;
+      file_recovery_new->extension="py";
+      return 1;
     }
-    if(find_in_mem(haystack,haystack_end,header_sig_python,sizeof(header_sig_ruby)) != NULL)
+    if(find_in_mem(haystack,haystack_end,header_sig_ruby,sizeof(header_sig_ruby)) != NULL)
     {
-      free(buffer_lower);
-      file_hint_txt.data_check=&data_check_txt;
-      return "rb";
+      reset_file_recovery(file_recovery_new);
+      file_recovery_new->data_check=&data_check_txt;
+      file_recovery_new->file_check=&file_check_size;
+      file_recovery_new->extension="rb";
+      return 1;
     }
   }
   if(safe_header_only!=0)
   {
-    free(buffer_lower);
-    return NULL;
+    return 0;
+  }
+  /* Don't search text in the beginning of JPG or inside pdf */
+  if(file_recovery!=NULL && file_recovery->file_stat!=NULL &&
+      ((file_recovery->file_stat->file_hint==&file_hint_jpg && file_recovery->file_size < file_recovery->min_filesize) ||
+       file_recovery->file_stat->file_hint==&file_hint_pdf))
+  {
+    return 0;
   }
   {
     const char *ext=NULL;
-    if(strstr(buffer_lower, sign_c)!=NULL)
+    if(strstr(buffer_lower, sign_tex)!=NULL)
+      ext="tex";
+    else if(strstr(buffer_lower, sign_c)!=NULL)
       ext="c";
     else if(strstr(buffer_lower, sign_php)!=NULL)
       ext="php";
@@ -469,22 +600,9 @@ static const char* header_check_txt(const unsigned char *buffer, const unsigned
 	  file_recovery->file_stat->file_hint==&file_hint_txt &&
 	  strstr(file_recovery->filename,"")!=NULL)
       {
-	free(buffer_lower);
-	return NULL;
+	return 0;
       }
 
-      if(file_recovery->file_stat->file_hint==&file_hint_jpg &&
-	  file_recovery->file_size < file_hint_jpg.min_filesize)
-      {
-	/* Don't search text, should be in JPEG Exif part */
-	/*
-	ecrit_rapport("jpg %lu < %lu\n",
-	    (unsigned long) file_recovery->file_size,
-	    (unsigned long) file_hint_jpg.min_filesize);
-	*/
-	free(buffer_lower);
-	return NULL;
-      }
       /* Special case: doc, texte files
 	Unix: \n (0xA)
 	Dos: \r\n (0xD 0xA)
@@ -498,18 +616,19 @@ static const char* header_check_txt(const unsigned char *buffer, const unsigned
 	for(j=0;j<i-1;j++)
 	  if(buffer_lower[j]=='\r' && buffer_lower[j+1]!='\n')
 	  {
-	    free(buffer_lower);
-	    return NULL;
+	    return 0;
 	  }
 	for(j=0;j<i && j<512;j++)
 	  if(buffer[j]=='\n')
 	    txt_nl=1;
 	if(txt_nl==1)
 	{
-	  //ecrit_rapport(">%s<\ndoc => %s\n",buffer_lower,ext);
-	  free(buffer_lower);
-	  file_hint_txt.data_check=&data_check_txt;
-	  return ext;
+	  /* log_trace(">%s<\ndoc => %s\n",buffer_lower,ext); */
+	  reset_file_recovery(file_recovery_new);
+	  file_recovery_new->data_check=&data_check_txt;
+	  file_recovery_new->file_check=&file_check_size;
+	  file_recovery_new->extension=ext;
+	  return 1;
 	}
       }
       buffer_lower[511]='\0';
@@ -524,22 +643,28 @@ static const char* header_check_txt(const unsigned char *buffer, const unsigned
 	  /* Text should not be found in zip because of compression */
 	  (file_recovery->file_stat->file_hint==&file_hint_zip && find_in_mem(buffer,buffer+buffer_size,zip_header,4)==NULL))
       {
-	free(buffer_lower);
-	file_hint_txt.data_check=&data_check_txt;
-	return ext;
+	reset_file_recovery(file_recovery_new);
+	file_recovery_new->data_check=&data_check_txt;
+	file_recovery_new->file_check=&file_check_size;
+	file_recovery_new->extension=ext;
+	return 1;
       }
-      free(buffer_lower);
-      return NULL;
+      return 0;
     }
-//    ecrit_rapport("ext=%s\n",ext);
-    free(buffer_lower);
+/*    log_trace("ext=%s\n",ext); */
     if(ext!=NULL)
-      file_hint_txt.data_check=&data_check_txt;
-    return ext;
+    {
+      reset_file_recovery(file_recovery_new);
+      file_recovery_new->extension=ext;
+      file_recovery_new->data_check=&data_check_txt;
+      file_recovery_new->file_check=&file_check_size;
+      return 1;
+    }
   }
+  return 0;
 }
 
-static int data_check_txt(const unsigned char *buffer, const unsigned int buffer_size, t_file_recovery *file_recovery)
+static int data_check_txt(const unsigned char *buffer, const unsigned int buffer_size, file_recovery_t *file_recovery)
 {
   unsigned int i;
   char *buffer_lower=MALLOC(buffer_size+16);
@@ -551,52 +676,60 @@ static int data_check_txt(const unsigned char *buffer, const unsigned int buffer
     pos=strstr(buffer_lower,sign_html_end);
     if(strstr(file_recovery->filename,".html")!=NULL && pos!=NULL && i<((pos-buffer_lower)+sizeof(sign_html_end))-1+10)
     {
-      file_recovery->file_size+=(pos-buffer_lower)+sizeof(sign_html_end)-1;
+      file_recovery->calculated_file_size+=(pos-buffer_lower)+sizeof(sign_html_end)-1;
     }
     else if(i>=10)
-      file_recovery->file_size+=i;
+      file_recovery->calculated_file_size=file_recovery->file_size+i;
     free(buffer_lower);
     return 2;
   }
   free(buffer_lower);
+  file_recovery->calculated_file_size=file_recovery->file_size+(buffer_size/2);
   return 1;
 }
 
-static void file_check_txt(t_file_recovery *file_recovery)
+static void file_check_html(file_recovery_t *file_recovery)
 {
-  if(strstr(file_recovery->filename,".html")!=NULL)
+  const unsigned char html_footer[7]= {'<', '/', 'h', 't', 'm', 'l', '>'};
+  file_search_lc_footer(file_recovery, html_footer,sizeof(html_footer));
+  if(file_recovery->file_size==0)
+    log_warning("%s: no footer\n",file_recovery->filename);
+  else
   {
-    const unsigned char html_footer[7]= {'<', '/', 'h', 't', 'm', 'l', '>'};
-    file_search_lc_footer(file_recovery, html_footer,sizeof(html_footer));
-    if(file_recovery->file_size==0)
-      ecrit_rapport("%s: no footer\n",file_recovery->filename);
-    else
+    const int read_size=1024;
+    int taille;
+    char *buffer;
+    int i;
+    if(fseek(file_recovery->handle,0,SEEK_SET)<0)
+      return;
+    buffer=MALLOC(read_size);
+    taille=fread(buffer,1,read_size,file_recovery->handle);
+    if(taille<0)
     {
-      const char sign_html[]	= "<html";
-      const int read_size=1024;
-      int taille;
-      char *buffer;
-      int i;
-      if(fseek(file_recovery->handle,0,SEEK_SET)<0)
-	return;
-      buffer=MALLOC(read_size);
-      taille=fread(buffer,1,read_size,file_recovery->handle);
-      if(taille<0)
-      {
-	free(buffer);
-	return;
-      }
-      for(i=0;i<taille;i++)
-	buffer[i]=tolower(buffer[i]);
-      buffer[taille<read_size?taille:read_size-1]='\0';
-      if(strstr(buffer, sign_html)==NULL)
-      {
-	ecrit_rapport("%s: no header\n",file_recovery->filename);
-	file_recovery->file_size=0;
-      }
       free(buffer);
+      return;
     }
+    for(i=0;i<taille;i++)
+      buffer[i]=tolower(buffer[i]);
+    buffer[taille<read_size?taille:read_size-1]='\0';
+    if(strstr(buffer, sign_html)==NULL)
+    {
+      log_warning("%s: no header\n",file_recovery->filename);
+      file_recovery->file_size=0;
+    }
+    free(buffer);
+  }
+}
+
+static void file_check_emlx(file_recovery_t *file_recovery)
+{
+  const unsigned char emlx_footer[9]= {'<', '/', 'p', 'l', 'i', 's', 't', '>', 0x0a};
+  if(file_recovery->file_size < file_recovery->calculated_file_size)
+    file_recovery->file_size=0;
+  else
+  {
+    if(file_recovery->file_size > file_recovery->calculated_file_size+2048)
+      file_recovery->file_size=file_recovery->calculated_file_size+2048;
+    file_search_footer(file_recovery, emlx_footer,sizeof(emlx_footer));
   }
-  else if(strstr(file_recovery->filename,".htm")!=NULL)
-    file_recovery->file_size=0;
 }
