@@ -2,7 +2,7 @@
 
     File: file_x3f.c
 
-    Copyright (C) 1998-2005 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 1998-2005,2007 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,26 +28,35 @@
 #endif
 #include <stdio.h>
 #include "types.h"
-#include "photorec.h"
+#include "filegen.h"
 
-static const char* header_check_x3f(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery);
-const t_file_hint file_hint_x3f= {
+static void register_header_check_x3f(file_stat_t *file_stat);
+static int header_check_x3f(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only, const file_recovery_t *file_recovery, file_recovery_t *file_recovery_new);
+
+const file_hint_t file_hint_x3f= {
   .extension="x3f",
   .description="Sigma/Foveon X3 raw picture",
   .min_header_distance=0,
-  .min_filesize=0,
   .max_filesize=PHOTOREC_MAX_FILE_SIZE,
   .recover=1,
   .header_check=&header_check_x3f,
-  .data_check=NULL,
-  .file_check=NULL
+  .register_header_check=&register_header_check_x3f
 };
 
-static const char* header_check_x3f(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery)
-{ /* http://www.x3f.info/technotes/FileDocs/X3F_Format.pdf */
-  if(memcmp(buffer,"FOVb",4)==0)
-    return file_hint_x3f.extension;
-  return NULL;
+static const unsigned char x3f_header[4]= {'F','O','V','b'};
+
+static void register_header_check_x3f(file_stat_t *file_stat)
+{
+  register_header_check(0, x3f_header,sizeof(x3f_header), &header_check_x3f, file_stat);
 }
 
-
+static int header_check_x3f(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only, const file_recovery_t *file_recovery, file_recovery_t *file_recovery_new)
+{ /* http://www.x3f.info/technotes/FileDocs/X3F_Format.pdf */
+  if(memcmp(buffer,x3f_header,sizeof(x3f_header))==0)
+  {
+    reset_file_recovery(file_recovery_new);
+    file_recovery_new->extension=file_hint_x3f.extension;
+    return 1;
+  }
+  return 0;
+}
