@@ -2,7 +2,7 @@
 
     File: hfs.c
 
-    Copyright (C) 1998-2005 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 1998-2007 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
- 
+#include <stdio.h>
 #ifdef HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
@@ -32,11 +32,12 @@
 #include "types.h"
 #include "common.h"
 #include "hfs.h"
-#include "intrf.h"
 #include "fnctdsk.h"
-static int set_HFS_info(t_partition *partition, const hfs_mdb_t *hfs_mdb);
+#include "log.h"
 
-int check_HFS(t_param_disk *disk_car,t_partition *partition,const int debug)
+static int set_HFS_info(partition_t *partition, const hfs_mdb_t *hfs_mdb);
+
+int check_HFS(disk_t *disk_car,partition_t *partition,const int debug)
 {
   unsigned char *buffer=(unsigned char*)MALLOC(HFS_SUPERBLOCK_SIZE);
   if(disk_car->read(disk_car,HFS_SUPERBLOCK_SIZE, buffer, partition->part_offset+0x400)!=0)
@@ -54,7 +55,7 @@ int check_HFS(t_param_disk *disk_car,t_partition *partition,const int debug)
   return 0;
 }
 
-int recover_HFS(t_param_disk *disk_car, const hfs_mdb_t *hfs_mdb,t_partition *partition,const int debug, const int dump_ind, const int backup)
+int recover_HFS(disk_t *disk_car, const hfs_mdb_t *hfs_mdb,partition_t *partition,const int debug, const int dump_ind, const int backup)
 {
   uint64_t part_size;
   if(test_HFS(disk_car,hfs_mdb,partition,debug,dump_ind)!=0)
@@ -74,39 +75,46 @@ int recover_HFS(t_param_disk *disk_car, const hfs_mdb_t *hfs_mdb,t_partition *pa
   partition->part_type_mac=PMAC_HFS;
   if(debug>0)
   {
-    ecrit_rapport("part_size %lu\n",(long unsigned)(partition->part_size/disk_car->sector_size));
+    log_info("part_size %lu\n",(long unsigned)(partition->part_size/disk_car->sector_size));
   }
   return 0;
 }
 
-int test_HFS(t_param_disk *disk_car, const hfs_mdb_t *hfs_mdb,t_partition *partition,const int debug, const int dump_ind)
+int test_HFS(disk_t *disk_car, const hfs_mdb_t *hfs_mdb,partition_t *partition,const int debug, const int dump_ind)
 {
-  if (hfs_mdb->drSigWord==be16(HFS_SUPER_MAGIC) && be32(hfs_mdb->drAlBlkSiz)%512==0 && be32(hfs_mdb->drAlBlkSiz)!=0
-    && be16(hfs_mdb->drFreeBks) <= be16(hfs_mdb->drNmAlBlks))
+  /* Check for HFS signature */
+  if (hfs_mdb->drSigWord!=be16(HFS_SUPER_MAGIC))
+    return 1;
+  /* Check for valid blocksize */
+  if(be32(hfs_mdb->drAlBlkSiz)%512!=0 || be32(hfs_mdb->drAlBlkSiz)==0)
+    return 1;
+  /* Check for coherent block numbers */
+  if(be16(hfs_mdb->drFreeBks) > be16(hfs_mdb->drNmAlBlks))
+    return 1;
+  /* Size must be less than 2TB (tolerate a little bit more)*/
+  if((uint64_t)be16(hfs_mdb->drNmAlBlks)*be32(hfs_mdb->drAlBlkSiz)+be16(hfs_mdb->drAlBlSt)*512+0x400 > (uint64_t)2049*1024*1024*1024)
+    return 1;
+  if(debug>0 || dump_ind!=0)
   {
-    if(debug>0 || dump_ind!=0)
-    {
-      ecrit_rapport("\nHFS magic value at %u/%u/%u\n", offset2cylinder(disk_car,partition->part_offset),offset2head(disk_car,partition->part_offset),offset2sector(disk_car,partition->part_offset));
-    }
-    if(dump_ind!=0)
-    {
-      /* There is a little offset ... */
-      dump(stdscr,hfs_mdb,DEFAULT_SECTOR_SIZE);
-    }
-    if(debug>1)
-    {
-      ecrit_rapport("drNmAlBlks %u\n",(unsigned) be16(hfs_mdb->drNmAlBlks));
-      ecrit_rapport("drAlBlkSiz %u\n",(unsigned) be32(hfs_mdb->drAlBlkSiz));
-      ecrit_rapport("drAlBlSt %u\n",(unsigned) be16(hfs_mdb->drAlBlSt));
-      ecrit_rapport("drFreeBks %u\n",(unsigned) be16(hfs_mdb->drFreeBks));
-    }
-    partition->upart_type=UP_HFS;
-    return 0;
+    log_info("\nHFS magic value at %u/%u/%u\n", offset2cylinder(disk_car,partition->part_offset),offset2head(disk_car,partition->part_offset),offset2sector(disk_car,partition->part_offset));
   }
-  return 1;
+  if(dump_ind!=0)
+  {
+    /* There is a little offset ... */
+    dump_log(hfs_mdb,DEFAULT_SECTOR_SIZE);
+  }
+  if(debug>1)
+  {
+    log_info("drNmAlBlks %u\n",(unsigned) be16(hfs_mdb->drNmAlBlks));
+    log_info("drAlBlkSiz %u\n",(unsigned) be32(hfs_mdb->drAlBlkSiz));
+    log_info("drAlBlSt %u\n",(unsigned) be16(hfs_mdb->drAlBlSt));
+    log_info("drFreeBks %u\n",(unsigned) be16(hfs_mdb->drFreeBks));
+  }
+  partition->upart_type=UP_HFS;
+  return 0;
 }
 
-static int set_HFS_info(t_partition *partition, const hfs_mdb_t *hfs_mdb)
+static int set_HFS_info(partition_t *partition, const hfs_mdb_t *hfs_mdb)
 {
   unsigned int name_size=sizeof(hfs_mdb->drVN)-1;
   snprintf(partition->info,sizeof(partition->info),"HFS");
