@@ -2,7 +2,7 @@
 
     File: hfsp.c
 
-    Copyright (C) 1998-2006 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 1998-2007 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -32,11 +32,12 @@
 #include "types.h"
 #include "common.h"
 #include "hfsp.h"
-#include "intrf.h"
 #include "fnctdsk.h"
-static int set_HFSP_info(t_partition *partition, const struct hfsp_vh *vh);
+#include "log.h"
 
-int check_HFSP(t_param_disk *disk_car,t_partition *partition,const int debug)
+static int set_HFSP_info(partition_t *partition, const struct hfsp_vh *vh);
+
+int check_HFSP(disk_t *disk_car,partition_t *partition,const int debug)
 {
   unsigned char *buffer=(unsigned char*)MALLOC(HFSP_BOOT_SECTOR_SIZE);
   if(disk_car->read(disk_car,HFSP_BOOT_SECTOR_SIZE, buffer, partition->part_offset+0x400)!=0)
@@ -54,7 +55,7 @@ int check_HFSP(t_param_disk *disk_car,t_partition *partition,const int debug)
   return 0;
 }
 
-int recover_HFSP(t_param_disk *disk_car, const struct hfsp_vh *vh,t_partition *partition,const int debug, const int dump_ind, const int backup)
+int recover_HFSP(disk_t *disk_car, const struct hfsp_vh *vh,partition_t *partition,const int debug, const int dump_ind, const int backup)
 {
   uint64_t part_size;
   if(test_HFSP(disk_car,vh,partition,debug,dump_ind)!=0)
@@ -74,29 +75,29 @@ int recover_HFSP(t_param_disk *disk_car, const struct hfsp_vh *vh,t_partition *p
   partition->part_type_mac=PMAC_HFS;
   if(debug>0)
   {
-    ecrit_rapport("part_size %lu\n",(long unsigned)(partition->part_size/disk_car->sector_size));
+    log_info("part_size %lu\n",(long unsigned)(partition->part_size/disk_car->sector_size));
   }
   return 0;
 }
 
-int test_HFSP(t_param_disk *disk_car, const struct hfsp_vh *vh,t_partition *partition,const int debug, const int dump_ind)
+int test_HFSP(disk_t *disk_car, const struct hfsp_vh *vh,partition_t *partition,const int debug, const int dump_ind)
 {
   if (vh->signature==be16(HFSP_VOLHEAD_SIG) && be32(vh->blocksize)%512==0 && be32(vh->blocksize)!=0 && be32(vh->free_blocks)<=be32(vh->total_blocks))
   {
     if(debug>0 || dump_ind!=0)
     {
-      ecrit_rapport("\nHFS+ magic value at %u/%u/%u\n", offset2cylinder(disk_car,partition->part_offset),offset2head(disk_car,partition->part_offset),offset2sector(disk_car,partition->part_offset));
+      log_info("\nHFS+ magic value at %u/%u/%u\n", offset2cylinder(disk_car,partition->part_offset),offset2head(disk_car,partition->part_offset),offset2sector(disk_car,partition->part_offset));
     }
     if(dump_ind!=0)
     {
       /* There is a little offset ... */
-      dump(stdscr,vh,DEFAULT_SECTOR_SIZE);
+      dump_log(vh,DEFAULT_SECTOR_SIZE);
     }
     if(debug>1)
     {
-      ecrit_rapport("blocksize %u\n",(unsigned) be32(vh->blocksize));
-      ecrit_rapport("total_blocks %u\n",(unsigned) be32(vh->total_blocks));
-      ecrit_rapport("free_blocks  %u\n",(unsigned) be32(vh->free_blocks));
+      log_info("blocksize %u\n",(unsigned) be32(vh->blocksize));
+      log_info("total_blocks %u\n",(unsigned) be32(vh->total_blocks));
+      log_info("free_blocks  %u\n",(unsigned) be32(vh->free_blocks));
     }
     partition->upart_type=UP_HFSP;
     return 0;
@@ -104,10 +105,10 @@ int test_HFSP(t_param_disk *disk_car, const struct hfsp_vh *vh,t_partition *part
   return 1;
 }
 
-static int set_HFSP_info(t_partition *partition, const struct hfsp_vh *vh)
+static int set_HFSP_info(partition_t *partition, const struct hfsp_vh *vh)
 {
   partition->name[0]='\0';
-  snprintf(partition->info,sizeof(partition->info),"HFS+");
+  strncpy(partition->info,"HFS+",sizeof(partition->info));
   return 0;
 }
 
