@@ -140,8 +140,8 @@ typedef struct hfsp_vh {
 #define HFSPLUS_VOL_RESERVED3 0xFFFF0000
 
 
-int check_HFSP(t_param_disk *disk_car,t_partition *partition,const int debug);
-int test_HFSP(t_param_disk *disk_car, const struct hfsp_vh *vh,t_partition *partition,const int debug, const int dump_ind);
-int recover_HFSP(t_param_disk *disk_car, const struct hfsp_vh *vh,t_partition *partition,const int debug, const int dump_ind, const int backup);
+int check_HFSP(disk_t *disk_car,partition_t *partition,const int debug);
+int test_HFSP(disk_t *disk_car, const struct hfsp_vh *vh,partition_t *partition,const int debug, const int dump_ind);
+int recover_HFSP(disk_t *disk_car, const struct hfsp_vh *vh,partition_t *partition,const int debug, const int dump_ind, const int backup);
 
 #endif
