@@ -2,7 +2,7 @@
 
     File: intrface.c
 
-    Copyright (C) 1998-2006 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 1998-2007 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -47,6 +47,7 @@
 #include "common.h"
 #include "lang.h"
 #include "intrf.h"
+#include "intrfn.h"
 #include "intrface.h"
 #include "godmode.h"
 #include "fnctdsk.h"
@@ -58,23 +59,27 @@
 #include "savehdr.h"
 #include "dirpart.h"
 #include "fat.h"
+#include "partauto.h"
+#include "log.h"
 
 #define INTER_DISK_X	0
 #define INTER_DISK_Y	7
+extern const arch_fnct_t arch_i386;
 
 static void interface_options(int *dump_ind, int *align, int *allow_partial_last_cylinder, unsigned int *expert, char**current_cmd);
-static t_list_part *interface_load(t_param_disk *disk_car,t_list_part *list_part, const int debug);
-static t_list_part *backup_merge(t_list_part *list_part,t_list_part *backup_part, const int debug);
-static int write_MBR_code(t_param_disk *disk_car, char **current_cmd);
-static int write_clean_table(t_param_disk *disk_car, char **current_cmd);
-static int interface_check_disk_capacity(t_param_disk *disk_car);
-static t_list_part *interface_analyse(t_param_disk *disk_car, const int debug, const int saveheader, char**current_cmd);
+static list_part_t *interface_load(disk_t *disk_car,list_part_t *list_part, const int debug);
+static list_part_t *backup_merge(list_part_t *list_part,list_part_t *backup_part, const int debug);
+static int write_MBR_code(disk_t *disk_car, char **current_cmd);
+static int write_clean_table(disk_t *disk_car, char **current_cmd);
+static int interface_check_disk_capacity(disk_t *disk_car);
+static list_part_t *interface_analyse(disk_t *disk_car, const int debug, const int saveheader, char**current_cmd);
+static int menu_disk(disk_t *disk_car, const int debug,int dump_ind, const int saveheader, char **current_cmd);
 
-void interface_list(t_param_disk *disk_car, const int debug,const int test_recovery, const int saveheader, const int backup)
+void interface_list(disk_t *disk_car, const int debug,const int test_recovery, const int saveheader, const int backup)
 {
-  t_list_part *list_part;
-  ecrit_rapport("\nAnalyse ");
-  ecrit_rapport("%s\n",disk_car->description(disk_car));
+  list_part_t *list_part;
+  log_info("\nAnalyse ");
+  log_info("%s\n",disk_car->description(disk_car));
   printf("%s\n",disk_car->description(disk_car));
   printf(msg_PART_HEADER_LONG);
   list_part=disk_car->arch->read_part(disk_car,debug,saveheader);
@@ -85,13 +90,13 @@ void interface_list(t_param_disk *disk_car, const int debug,const int test_recov
   }
   if(test_recovery>0)
   {
-    t_list_part *element;
-    ecrit_rapport("rebuild_FAT_BS()\n");
+    list_part_t *element;
+    log_info("rebuild_FAT_BS()\n");
     for(element=list_part;element!=NULL;element=element->next)
     {
       if(is_fat(element->part))
       {
-	aff_part_rapport(disk_car,element->part);
+	log_partition(disk_car,element->part);
 	rebuild_FAT_BS(disk_car,element->part,debug,0,0,0,NULL);	/* dump_ind */
       }
       /* TODO ntfs */
@@ -100,7 +105,7 @@ void interface_list(t_param_disk *disk_car, const int debug,const int test_recov
   delete_list_part(list_part);
 }
 
-static int write_MBR_code(t_param_disk *disk_car, char **current_cmd)
+static int write_MBR_code(disk_t *disk_car, char **current_cmd)
 {
   aff_copy(stdscr);
   wmove(stdscr,5,0);
@@ -125,7 +130,7 @@ static int write_MBR_code(t_param_disk *disk_car, char **current_cmd)
   return 0;
 }
 
-int write_clean_table(t_param_disk *disk_car, char**current_cmd)
+int write_clean_table(disk_t *disk_car, char**current_cmd)
 {
   aff_copy(stdscr);
   wmove(stdscr,5,0);
@@ -150,7 +155,7 @@ int write_clean_table(t_param_disk *disk_car, char**current_cmd)
   return 0;
 }
 
-static int menu_disk(t_param_disk *disk_car, int debug,int dump_ind, const int saveheader, char **current_cmd)
+static int menu_disk(disk_t *disk_car, const int debug,int dump_ind, const int saveheader, char **current_cmd)
 {
   int align=2;
   int allow_partial_last_cylinder=0;
@@ -235,9 +240,45 @@ static int menu_disk(t_param_disk *disk_car, int debug,int dump_ind, const int s
       case 'a':
       case 'A':
 	{
-	  t_list_part *list_part;
+	  int search_vista_part=0;
+	  list_part_t *list_part;
 	  list_part=interface_analyse(disk_car, debug, saveheader, current_cmd);
-	  interface_recovery(disk_car, list_part, debug, dump_ind, align, ask_part_order, expert, current_cmd);
+	  if(disk_car->arch==&arch_i386)
+	  {
+	    const int old_allow_partial_last_cylinder=allow_partial_last_cylinder;
+	    const list_part_t *element;
+	    for(element=list_part;element!=NULL;element=element->next)
+	    {
+	      if(element->part->part_offset%(2048*512)==0 && element->part->part_size%(2048*512)==0)
+		search_vista_part=1;
+	    }
+	    if(search_vista_part==0)
+	    {
+	      if(*current_cmd!=NULL)
+	      {
+		while(*current_cmd[0]==',')
+		  (*current_cmd)++;
+		if(strncmp(*current_cmd,"mode_vista",10)==0)
+		{
+		  (*current_cmd)+=10;
+		  search_vista_part=1;
+		}
+	      }
+	      else
+	      {
+		log_info("Ask the user for vista mode\n");
+		if(ask_confirmation("Should TestDisk search for partition created under Vista ? [Y/N] (answer Yes if unsure)")!=0)
+		  search_vista_part=1;
+	      }
+	    }
+	    if(search_vista_part==1)
+	      allow_partial_last_cylinder=1;
+	    if(old_allow_partial_last_cylinder!=allow_partial_last_cylinder)
+	      hd_update_geometry(disk_car,allow_partial_last_cylinder,debug);
+	    log_info("Allow partial last cylinder : %s\n", allow_partial_last_cylinder>0?"Yes":"No");
+	    log_info("search_vista_part: %d\n", search_vista_part);
+	  }
+	  interface_recovery(disk_car, list_part, debug, dump_ind, align, ask_part_order, expert, search_vista_part, current_cmd);
 	  delete_list_part(list_part);
 	}
 	break;
@@ -256,7 +297,7 @@ static int menu_disk(t_param_disk *disk_car, int debug,int dump_ind, const int s
       case 'o':
       case 'O':
 	{
-	  int old_allow_partial_last_cylinder=allow_partial_last_cylinder;
+	  const int old_allow_partial_last_cylinder=allow_partial_last_cylinder;
 	  interface_options(&dump_ind, &align,&allow_partial_last_cylinder,&expert,current_cmd);
 	  if(old_allow_partial_last_cylinder!=allow_partial_last_cylinder)
 	    hd_update_geometry(disk_car,allow_partial_last_cylinder,debug);
@@ -279,7 +320,7 @@ static int menu_disk(t_param_disk *disk_car, int debug,int dump_ind, const int s
   return 0;
 }
 
-int do_curses_testdisk(int debug,int dump_ind, const t_list_disk *list_disk, const int saveheader, const char *cmd_device, char **current_cmd)
+int do_curses_testdisk(int debug,int dump_ind, const list_disk_t *list_disk, const int saveheader, const char *cmd_device, char **current_cmd)
 {
   int command='Q';
   int allow_partial_last_cylinder=0;
@@ -287,8 +328,8 @@ int do_curses_testdisk(int debug,int dump_ind, const t_list_disk *list_disk, con
   unsigned int menu=0;
   int offset=0;
   int pos_num=0;
-  const t_list_disk *element_disk;
-  const t_list_disk *current_disk=NULL;
+  const list_disk_t *element_disk;
+  const list_disk_t *current_disk=NULL;
   static struct MenuItem menuMain[]=
   {
     { 'P', "Previous",""},
@@ -333,9 +374,9 @@ int do_curses_testdisk(int debug,int dump_ind, const t_list_disk *list_disk, con
 	wdoprintf(stdscr,"%s\n",element_disk->disk->description_short(element_disk->disk));
       else
       {
-	wattrset(stdscr,A_STANDOUT);
+	wattrset(stdscr, A_REVERSE);
 	wdoprintf(stdscr,"%s\n",element_disk->disk->description_short(element_disk->disk));
-	wattroff(stdscr,A_STANDOUT);
+	wattroff(stdscr, A_REVERSE);
       }
     }
     if(i<=10 && element_disk==NULL)
@@ -410,13 +451,35 @@ int do_curses_testdisk(int debug,int dump_ind, const t_list_disk *list_disk, con
 	if(pos_num>=offset+10)
 	  offset++;
 	break;
+      case KEY_PPAGE:
+	for(i=0;i<INTER_STRUCTURE && current_disk->prev!=NULL;i++)
+	{
+	  current_disk=current_disk->prev;
+	  pos_num--;
+	  if(pos_num<offset)
+	    offset--;
+	}
+	break;
+      case KEY_NPAGE:
+	for(i=0;i<INTER_STRUCTURE && current_disk->next!=NULL;i++)
+	{
+	  current_disk=current_disk->next;
+	  pos_num++;
+	  if(pos_num>=offset+10)
+	    offset++;
+	}
+	break;
       case 'o':
       case 'O':
-        if(interface_check_disk_capacity(current_disk->disk)==0 &&
-	    interface_partition_type(current_disk->disk, allow_partial_last_cylinder, debug, current_cmd)==0)
 	{
-	  if(menu_disk(current_disk->disk, debug, dump_ind, saveheader, current_cmd))
-	    done=1;
+	  disk_t *disk=current_disk->disk;
+	  autodetect_arch(disk);
+	  if(interface_check_disk_capacity(disk)==0 &&
+	      interface_partition_type(disk, allow_partial_last_cylinder, debug, current_cmd)==0)
+	  {
+	    if(menu_disk(disk, debug, dump_ind, saveheader, current_cmd))
+	      done=1;
+	  }
 	}
 	break;
       case 'q':
@@ -428,7 +491,7 @@ int do_curses_testdisk(int debug,int dump_ind, const t_list_disk *list_disk, con
   return 0;
 }
 
-static int interface_check_disk_capacity(t_param_disk *disk_car)
+static int interface_check_disk_capacity(disk_t *disk_car)
 {
   /* Test for LBA28 limitation */
   if(disk_car->CHS.sector>0 && (disk_car->CHS.cylinder+1) == (((1<<28)-1) / (disk_car->CHS.head+1) / disk_car->CHS.sector))
@@ -441,7 +504,7 @@ static int interface_check_disk_capacity(t_param_disk *disk_car)
     };
     unsigned int menu=1;
     int car;
-    ecrit_rapport("LBA28 limitation\n");
+    log_warning("LBA28 limitation\n");
     aff_copy(stdscr);
     if(disk_car->arch->msg_part_type!=NULL)
       mvwaddstr(stdscr,22,0,disk_car->arch->msg_part_type);
@@ -466,9 +529,9 @@ static int interface_check_disk_capacity(t_param_disk *disk_car)
   return 0;
 }
 
-static t_list_part *interface_analyse(t_param_disk *disk_car, const int debug, const int saveheader, char**current_cmd)
+static list_part_t *interface_analyse(disk_t *disk_car, const int debug, const int saveheader, char**current_cmd)
 {
-  t_list_part *list_part;
+  list_part_t *list_part;
   int command;
   struct MenuItem menuAnalyse[]=
   {
@@ -478,8 +541,8 @@ static t_list_part *interface_analyse(t_param_disk *disk_car, const int debug, c
     { 'B', "Backup","Save current partition list to backup.log file and proceed"},
     { 0, NULL, NULL }
   };
-  ecrit_rapport("\nAnalyse ");
-  ecrit_rapport("%s\n",disk_car->description(disk_car));
+  log_info("\nAnalyse ");
+  log_info("%s\n",disk_car->description(disk_car));
   aff_buffer(BUFFER_RESET,"Q");
   /* ncurses interface */
   aff_copy(stdscr);
@@ -495,7 +558,7 @@ static t_list_part *interface_analyse(t_param_disk *disk_car, const int debug, c
   wmove(stdscr,5,0);
   wclrtoeol(stdscr);	/* before addstr for BSD compatibility */
   waddstr(stdscr,"Current partition structure:");
-  ecrit_rapport("Current partition structure:\n");
+  log_info("Current partition structure:\n");
   if(*current_cmd!=NULL)
   {
     command='Q';
@@ -513,7 +576,7 @@ static t_list_part *interface_analyse(t_param_disk *disk_car, const int debug, c
     command=screen_buffer_display(stdscr,(list_part!=NULL?"QB":"Q"),menuAnalyse);
   if(command=='B')
   {
-    ecrit_rapport("Backup partition structure\n");
+    log_info("Backup partition structure\n");
     if(partition_save(disk_car,list_part,debug)<0)
     {
       display_message("Can't create backup.log.\n");
@@ -522,9 +585,9 @@ static t_list_part *interface_analyse(t_param_disk *disk_car, const int debug, c
   return list_part;
 }
 
-int interface_write(t_param_disk *disk_car,t_list_part *list_part,const int can_search_deeper, const int can_ask_minmax_ext, char **current_cmd, unsigned int *menu)
+int interface_write(disk_t *disk_car,list_part_t *list_part,const int can_search_deeper, const int can_ask_minmax_ext, int *no_confirm, char **current_cmd, unsigned int *menu)
 {
-  t_list_part *parts;
+  list_part_t *parts;
   struct MenuItem menuWrite[]=
   {
     { 'P', "Previous",""},
@@ -536,7 +599,7 @@ int interface_write(t_param_disk *disk_car,t_list_part *list_part,const int can_
     { 0, NULL, NULL }
   };
   int command;
-  ecrit_rapport("\ninterface_write()\n");
+  log_info("\ninterface_write()\n");
   aff_buffer(BUFFER_RESET,"Q");
   aff_copy(stdscr);
   wmove(stdscr,4,0);
@@ -572,21 +635,30 @@ int interface_write(t_param_disk *disk_car,t_list_part *list_part,const int can_
   {
     if(*current_cmd!=NULL)
     {
-      while(*current_cmd[0]==',')
-	(*current_cmd)++;
-      command='Q';
-      if(strncmp(*current_cmd,"search",6)==0)
+      do
       {
-	(*current_cmd)+=6;
-	if(can_search_deeper)
-	  command='S';
-      }
-      else if(strncmp(*current_cmd,"write",5)==0)
-      {
-	(*current_cmd)+=5;
-	if(disk_car->arch->write_part!=NULL)
-	  command='W';
-      }
+	while(*current_cmd[0]==',')
+	  (*current_cmd)++;
+	command='Q';
+	if(strncmp(*current_cmd,"search",6)==0)
+	{
+	  (*current_cmd)+=6;
+	  if(can_search_deeper)
+	    command='S';
+	}
+	else if(strncmp(*current_cmd,"noconfirm",9)==0)
+	{
+	  command=0;	/* do nothing */
+	  (*no_confirm)=1;
+	  (*current_cmd)+=9;
+	}
+	else if(strncmp(*current_cmd,"write",5)==0)
+	{
+	  (*current_cmd)+=5;
+	  if(disk_car->arch->write_part!=NULL)
+	    command='W';
+	}
+      } while(command==0);
       screen_buffer_to_log();
     }
     else
@@ -689,37 +761,37 @@ static void interface_options(int *dump_ind, int *align, int *allow_partial_last
     }
   }
   /* write new options to log file */
-  ecrit_rapport("New options :\n Dump : %s\n ",
+  log_info("New options :\n Dump : %s\n ",
       *dump_ind?"Yes":"No");
   switch(*align)
   {
     case 0:
-      ecrit_rapport("Cylinder boundary : No");
+      log_info("Cylinder boundary : No");
       break;
     case 1:
-      ecrit_rapport("Cylinder boundary : Head boundary only");
+      log_info("Cylinder boundary : Head boundary only");
       break;
     case 2:
-      ecrit_rapport("Cylinder boundary : Yes");
+      log_info("Cylinder boundary : Yes");
       break;
   }
-  ecrit_rapport("\n Allow partial last cylinder : %s\n Expert mode : %s\n",
+  log_info("\n Allow partial last cylinder : %s\n Expert mode : %s\n",
       *allow_partial_last_cylinder?"Yes":"No",
       *expert?"Yes":"No");
 }
 
-t_list_part *ask_structure(t_param_disk *disk_car,t_list_part *list_part, const int debug, char **current_cmd)
+list_part_t *ask_structure(disk_t *disk_car,list_part_t *list_part, const int debug, char **current_cmd)
 {
   int quit=0;
   int offset=0;
   int pos_num=0;
-  t_list_part *pos=list_part;
+  list_part_t *pos=list_part;
   int rewrite=1;
   do
   {
     int i;
     int command;
-    t_list_part *parts;
+    list_part_t *parts;
     int structure_status;
     if(rewrite)
     {
@@ -737,7 +809,7 @@ t_list_part *ask_structure(t_param_disk *disk_car,t_list_part *list_part, const
       wclrtoeol(stdscr);	/* before addstr for BSD compatibility */
       if(parts==pos)
       {
-	wattrset(stdscr,A_STANDOUT);
+	wattrset(stdscr, A_REVERSE);
       }
       if(structure_status==0 && parts->part->status!=STATUS_DELETED && has_colors())
 	wbkgdset(stdscr,' ' | COLOR_PAIR(2));
@@ -747,7 +819,7 @@ t_list_part *ask_structure(t_param_disk *disk_car,t_list_part *list_part, const
       if(parts==pos)
       {
 	char buffer_part_size[100];
-	wattroff(stdscr,A_STANDOUT);
+	wattroff(stdscr, A_REVERSE);
 	wmove(stdscr,24,0);
 	wclrtoeol(stdscr);	/* before addstr for BSD compatibility */
 	if(parts->part->info[0]!='\0')
@@ -987,39 +1059,39 @@ t_list_part *ask_structure(t_param_disk *disk_car,t_list_part *list_part, const
 	pos=list_part;
         break;
       default:
-/*	ecrit_rapport("ask_structure command=%x\n",command); */
+/*	log_trace("ask_structure command=%x\n",command); */
 	break;
     }
   } while(quit==0);
   return list_part;
 }
 
-static t_list_part *backup_merge(t_list_part *list_part,t_list_part *backup_part, const int debug)
+static list_part_t *backup_merge(list_part_t *list_part,list_part_t *backup_part, const int debug)
 {
-  t_list_part *partition;
+  list_part_t *partition;
   for(partition=backup_part;partition!=NULL;partition=partition->next)
   {
-    t_partition *new_partition=partition_new();
-    dup_t_partition(new_partition,partition->part);
+    partition_t *new_partition=partition_new();
+    dup_partition_t(new_partition,partition->part);
     list_part=insert_new_partition(list_part, new_partition);
   }
   return list_part;
 }
 
-static t_list_part *interface_load(t_param_disk *disk_car,t_list_part *list_part, const int debug)
+static list_part_t *interface_load(disk_t *disk_car,list_part_t *list_part, const int debug)
 {
-  struct list_head *backup_walker=NULL;
-  t_backup_disk *backup_list=partition_load(disk_car,debug);
+  struct td_list_head *backup_walker=NULL;
+  backup_disk_t *backup_list=partition_load(disk_car,debug);
   {
-    ecrit_rapport("interface_load\n");
-    list_for_each(backup_walker,&backup_list->list)
+    log_info("interface_load\n");
+    td_list_for_each(backup_walker,&backup_list->list)
     {
-      t_list_part *element;
-      t_backup_disk *backup;
-      backup=list_entry(backup_walker, t_backup_disk, list);
-      ecrit_rapport("%s %s",backup->description,ctime(&backup->my_time));
+      list_part_t *element;
+      backup_disk_t *backup;
+      backup=td_list_entry(backup_walker, backup_disk_t, list);
+      log_info("%s %s",backup->description,ctime(&backup->my_time));
       for(element=backup->list_part;element!=NULL;element=element->next)
-	aff_part_rapport(disk_car,element->part);
+	log_partition(disk_car,element->part);
     }
   }
   {
@@ -1028,7 +1100,7 @@ static t_list_part *interface_load(t_param_disk *disk_car,t_list_part *list_part
     int backup_current_num=0;
     int rewrite=1;
     unsigned int menu=3;   /* default : quit */
-    struct list_head *backup_current=backup_list->list.next;
+    struct td_list_head *backup_current=backup_list->list.next;
     struct MenuItem menuLoadBackup[]=
     {
       { 'P', "Previous",""},
@@ -1058,18 +1130,18 @@ static t_list_part *interface_load(t_param_disk *disk_car,t_list_part *list_part
       }
       if(backup_list!=NULL)
       {
-	t_backup_disk *backup=NULL;
+	backup_disk_t *backup=NULL;
 	for(i=0,backup_walker=backup_list->list.next;(backup_walker!=&backup_list->list) && (i<offset);backup_walker=backup_walker->next,i++);
 	for(i=offset;(backup_walker!=&backup_list->list) &&((i-offset)<INTER_STRUCTURE);i++,backup_walker=backup_walker->next)
 	{
-	  backup=list_entry(backup_walker, t_backup_disk, list);
+	  backup=td_list_entry(backup_walker, backup_disk_t, list);
 	  wmove(stdscr,8+i-offset,0);
 	  wclrtoeol(stdscr);	/* before addstr for BSD compatibility */
 	  if(backup_walker==backup_current)
 	  {
-	    wattrset(stdscr,A_STANDOUT);
+	    wattrset(stdscr, A_REVERSE);
 	    wdoprintf(stdscr,"%s %s",backup->description,ctime(&backup->my_time));
-	    wattroff(stdscr,A_STANDOUT);
+	    wattroff(stdscr, A_REVERSE);
 	  } else
 	  {
 	    wdoprintf(stdscr,"%s %s",backup->description,ctime(&backup->my_time));
@@ -1142,15 +1214,15 @@ static t_list_part *interface_load(t_param_disk *disk_car,t_list_part *list_part
 	  }
 	  break;
 	default:
-	  /*	ecrit_rapport("ask_structure car=%x\n",car); */
+	  /*	log_trace("ask_structure car=%x\n",car); */
 	  break;
       }
     } while(quit==0);
     if(backup_current!=NULL && quit==2)
     {
-      t_list_part *partition;
-      t_backup_disk *backup;
-      backup=list_entry(backup_walker, t_backup_disk, list);
+      list_part_t *partition;
+      backup_disk_t *backup;
+      backup=td_list_entry(backup_current, backup_disk_t, list);
       for(partition=backup->list_part;partition!=NULL;partition=partition->next)
       {
 	/* Check partition and load partition name */
@@ -1160,11 +1232,11 @@ static t_list_part *interface_load(t_param_disk *disk_car,t_list_part *list_part
     }
   }
   { /* Cleanup */
-    struct list_head *backup_walker_next = NULL;
-    list_for_each_safe(backup_walker,backup_walker_next,&backup_list->list)
+    struct td_list_head *backup_walker_next = NULL;
+    td_list_for_each_safe(backup_walker,backup_walker_next,&backup_list->list)
     {
-      t_backup_disk *backup;
-      backup=list_entry(backup_walker, t_backup_disk, list);
+      backup_disk_t *backup;
+      backup=td_list_entry(backup_walker, backup_disk_t, list);
       delete_list_part(backup->list_part);
       free(backup);
     }
@@ -1173,10 +1245,10 @@ static t_list_part *interface_load(t_param_disk *disk_car,t_list_part *list_part
   return list_part;
 }
 
-int interface_superblock(t_param_disk *disk_car,t_list_part *list_part, char**current_cmd)
+int interface_superblock(disk_t *disk_car,list_part_t *list_part, char**current_cmd)
 {
-  t_list_part *parts;
-  t_partition *old_part=NULL;
+  list_part_t *parts;
+  partition_t *old_part=NULL;
   struct MenuItem menuSuperblock[]=
   {
     { 'P', "Previous",""},
