@@ -2,7 +2,7 @@
 
     File: io_redir.c
 
-    Copyright (C) 1998-2006 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 1998-2007 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -34,37 +34,38 @@
 #include "common.h"
 #include "fnctdsk.h"
 #include "io_redir.h"
+#include "log.h"
 
 //#define DEBUG_IO_REDIR 1
 
-typedef struct struct_list_redir t_list_redir;
-struct struct_list_redir
+typedef struct struclist_redir_t list_redir_t;
+struct struclist_redir_t
 {
   uint64_t org_offset;
   uint64_t new_offset;
   unsigned int size;
   const void *mem;
-  t_list_redir *prev;
-  t_list_redir *next;
+  list_redir_t *prev;
+  list_redir_t *next;
 };
 
 struct info_io_redir
 {
-  t_param_disk *disk_car;
-  t_list_redir *list_redir;
+  disk_t *disk_car;
+  list_redir_t *list_redir;
 };
 
-static int io_redir_read(t_param_disk *disk_car,const unsigned int count, void *nom_buffer, const uint64_t offset);
-static int io_redir_clean(t_param_disk *clean);
+static int io_redir_read(disk_t *disk_car,const unsigned int count, void *nom_buffer, const uint64_t offset);
+static int io_redir_clean(disk_t *clean);
 
-int io_redir_add_redir(t_param_disk *disk_car, const uint64_t org_offset, const unsigned int size, const uint64_t new_offset, const void *mem)
+int io_redir_add_redir(disk_t *disk_car, const uint64_t org_offset, const unsigned int size, const uint64_t new_offset, const void *mem)
 {
   if(disk_car->read!=io_redir_read)
   {
     struct info_io_redir*data=MALLOC(sizeof(*data));
-    t_param_disk *old_disk_car=MALLOC(sizeof(*old_disk_car));
+    disk_t *old_disk_car=MALLOC(sizeof(*old_disk_car));
 #ifdef DEBUG_IO_REDIR
-    ecrit_rapport("io_redir_add_redir: install functions\n");
+    log_trace("io_redir_add_redir: install functions\n");
 #endif
     memcpy(old_disk_car,disk_car,sizeof(*old_disk_car));
     data->disk_car=old_disk_car;
@@ -78,21 +79,21 @@ int io_redir_add_redir(t_param_disk *disk_car, const uint64_t org_offset, const
   }
   {
     struct info_io_redir *data=disk_car->data;
-    t_list_redir *prev_redir=NULL;
-    t_list_redir *current_redir;
+    list_redir_t *prev_redir=NULL;
+    list_redir_t *current_redir;
     for(current_redir=data->list_redir;(current_redir!=NULL) && org_offset<current_redir->org_offset+current_redir->size;current_redir=current_redir->next)
       prev_redir=current_redir;
     if(current_redir!=NULL && org_offset>=current_redir->org_offset)
     {
-      ecrit_rapport("io_redir_add_redir failed: already redirected\n");
+      log_critical("io_redir_add_redir failed: already redirected\n");
       return 1;
     }
     {
-      t_list_redir *new_redir;
+      list_redir_t *new_redir;
 #ifdef DEBUG_IO_REDIR
-      ecrit_rapport("io_redir_add_redir: add redirection\n");
+      log_trace("io_redir_add_redir: add redirection\n");
 #endif
-      new_redir=(t_list_redir*)MALLOC(sizeof(*new_redir));
+      new_redir=(list_redir_t*)MALLOC(sizeof(*new_redir));
       new_redir->org_offset=org_offset;
       new_redir->size=size;
       new_redir->new_offset=new_offset;
@@ -107,21 +108,21 @@ int io_redir_add_redir(t_param_disk *disk_car, const uint64_t org_offset, const
   return 0;
 }
 
-int io_redir_del_redir(t_param_disk *disk_car, uint64_t org_offset)
+int io_redir_del_redir(disk_t *disk_car, uint64_t org_offset)
 {
   if(disk_car->read!=io_redir_read)
   {
-    ecrit_rapport("io_redir_del_redir: BUG, no redirection present.\n");
+    log_critical("io_redir_del_redir: BUG, no redirection present.\n");
     return 1;
   }
   {
     struct info_io_redir *data=disk_car->data;
-    t_list_redir *current_redir;
+    list_redir_t *current_redir;
     for(current_redir=data->list_redir;(current_redir!=NULL) && org_offset!=current_redir->org_offset;current_redir=current_redir->next);
     if(current_redir!=NULL)
     {
 #ifdef DEBUG_IO_REDIR
-      ecrit_rapport("io_redir_del_redir: remove redirection\n");
+      log_trace("io_redir_del_redir: remove redirection\n");
 #endif
       if(current_redir->prev!=NULL)
 	current_redir->prev->next=current_redir->next;
@@ -133,7 +134,7 @@ int io_redir_del_redir(t_param_disk *disk_car, uint64_t org_offset)
       if(data->list_redir==NULL)
       {
 #ifdef DEBUG_IO_REDIR
-	ecrit_rapport("io_redir_del_redir: uninstall functions\n");
+	log_trace("io_redir_del_redir: uninstall functions\n");
 #endif
 	memcpy(disk_car,data->disk_car,sizeof(*disk_car));
 	free(data->disk_car);
@@ -141,20 +142,20 @@ int io_redir_del_redir(t_param_disk *disk_car, uint64_t org_offset)
       }
       return 0;
     }
-    ecrit_rapport("io_redir_del_redir: redirection not found\n");
+    log_trace("io_redir_del_redir: redirection not found\n");
     return 1;
   }
 }
 
-static int io_redir_read(t_param_disk *disk_car,const unsigned int count, void *buffer, const uint64_t offset)
+static int io_redir_read(disk_t *disk_car,const unsigned int count, void *buffer, const uint64_t offset)
 {
   struct info_io_redir *data=disk_car->data;
   uint64_t current_offset=offset;
   unsigned int current_count=count;
   int res=0;
-  t_list_redir *current_redir;
+  list_redir_t *current_redir;
 #ifdef DEBUG_IO_REDIR
-  ecrit_rapport("io_redir_read: offset=%llu count=%u\n",(long long unsigned) offset, count);
+  log_trace("io_redir_read: offset=%llu count=%u\n",(long long unsigned) offset, count);
 #endif
   while(current_count!=0)
   {
@@ -169,7 +170,7 @@ static int io_redir_read(t_param_disk *disk_car,const unsigned int count, void *
 	/* Read data before redirection */
 	read_size=current_redir->org_offset-current_offset;
 #ifdef DEBUG_IO_REDIR
-	ecrit_rapport("io_redir_read: read %u bytes before redirection\n",read_size);
+	log_trace("io_redir_read: read %u bytes before redirection\n",read_size);
 #endif
 	res|=data->disk_car->read(data->disk_car,read_size,buffer,current_offset);
 	current_count-=read_size;
@@ -181,14 +182,14 @@ static int io_redir_read(t_param_disk *disk_car,const unsigned int count, void *
       if(current_redir->mem!=NULL)
       {
 #ifdef DEBUG_IO_REDIR
-	ecrit_rapport("io_redir_read: copy %u bytes from memory\n",read_size);
+	log_trace("io_redir_read: copy %u bytes from memory\n",read_size);
 #endif
 	memcpy(buffer, (const unsigned char*)current_redir->mem + current_offset - current_redir->org_offset, read_size);
       }
       else
       {
 #ifdef DEBUG_IO_REDIR
-	ecrit_rapport("io_redir_read: read %u from another position\n",read_size);
+	log_trace("io_redir_read: read %u from another position\n",read_size);
 #endif
 	res|=data->disk_car->read(data->disk_car, read_size, buffer,
 	    current_redir->new_offset + current_offset - current_redir->org_offset);
@@ -198,7 +199,7 @@ static int io_redir_read(t_param_disk *disk_car,const unsigned int count, void *
     {
       read_size=current_count;
 #ifdef DEBUG_IO_REDIR
-      ecrit_rapport("io_redir_read: normal read of %u bytes\n",read_size);
+      log_trace("io_redir_read: normal read of %u bytes\n",read_size);
 #endif
       res|=data->disk_car->read(data->disk_car,read_size,buffer,current_offset);
     }
@@ -211,7 +212,7 @@ static int io_redir_read(t_param_disk *disk_car,const unsigned int count, void *
   return 0;
 }
 
-static int io_redir_clean(t_param_disk *disk_car)
+static int io_redir_clean(disk_t *disk_car)
 {
   if(disk_car->data)
   {
