@@ -2,7 +2,7 @@
 
     File: jfs.c
 
-    Copyright (C) 2004-2006 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 2004-2007 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
- 
+#include <stdio.h>
 #ifdef HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
@@ -33,12 +33,12 @@
 #include "common.h"
 #include "jfs_superblock.h"
 #include "jfs.h"
-#include "intrf.h"
 #include "fnctdsk.h"
+#include "log.h"
 
-static int test_JFS(t_param_disk *disk_car, const struct jfs_superblock *sb,t_partition *partition,const int debug, const int dump_ind);
+static int test_JFS(disk_t *disk_car, const struct jfs_superblock *sb,partition_t *partition,const int debug, const int dump_ind);
 
-int check_JFS(t_param_disk *disk_car,t_partition *partition,const int debug)
+int check_JFS(disk_t *disk_car,partition_t *partition,const int debug)
 {
   unsigned char *buffer=(unsigned char*)MALLOC(JFS_SUPERBLOCK_SIZE);
   if(disk_car->read(disk_car,JFS_SUPERBLOCK_SIZE, buffer, partition->part_offset+64*512)!=0)
@@ -56,7 +56,7 @@ int check_JFS(t_param_disk *disk_car,t_partition *partition,const int debug)
   return 0;
 }
 
-int set_JFS_info(t_param_disk *disk_car, const struct jfs_superblock *sb,t_partition *partition,const int debug, const int dump_ind)
+int set_JFS_info(disk_t *disk_car, const struct jfs_superblock *sb,partition_t *partition,const int debug, const int dump_ind)
 {
   snprintf(partition->info,sizeof(partition->info),"JFS %u",(unsigned int)sb->s_version);
   partition->name[0]='\0';
@@ -70,7 +70,7 @@ int set_JFS_info(t_param_disk *disk_car, const struct jfs_superblock *sb,t_parti
 /*
 Primary superblock is at 0x8000
 */
-int recover_JFS(t_param_disk *disk_car, const struct jfs_superblock *sb,t_partition *partition,const int debug, const int dump_ind)
+int recover_JFS(disk_t *disk_car, const struct jfs_superblock *sb,partition_t *partition,const int debug, const int dump_ind)
 {
   if(test_JFS(disk_car,sb,partition,debug,dump_ind)!=0)
     return 1;
@@ -84,25 +84,25 @@ int recover_JFS(t_param_disk *disk_car, const struct jfs_superblock *sb,t_partit
   partition->blocksize=le32(sb->s_bsize);
   if(debug>0)
   {
-    ecrit_rapport("\n");
-    ecrit_rapport("recover_JFS: s_blocksize=%lu\n",partition->blocksize);
-    ecrit_rapport("recover_JFS: s_size %lu\n",(long unsigned int)le64(sb->s_size));
-    ecrit_rapport("recover_JFS: s_fsckpxd.len:%d\n", (int)le24(sb->s_fsckpxd.len));
-    ecrit_rapport("recover_JFS: s_logpxd.len:%d\n", (int)le24(sb->s_logpxd.len));
-    ecrit_rapport("recover_JFS: part_size %lu\n",(long unsigned)(partition->part_size/disk_car->sector_size));
+    log_info("\n");
+    log_info("recover_JFS: s_blocksize=%lu\n",partition->blocksize);
+    log_info("recover_JFS: s_size %lu\n",(long unsigned int)le64(sb->s_size));
+    log_info("recover_JFS: s_fsckpxd.len:%d\n", (int)le24(sb->s_fsckpxd.len));
+    log_info("recover_JFS: s_logpxd.len:%d\n", (int)le24(sb->s_logpxd.len));
+    log_info("recover_JFS: part_size %lu\n",(long unsigned)(partition->part_size/disk_car->sector_size));
   }
   return 0;
 }
 
-static int test_JFS(t_param_disk *disk_car, const struct jfs_superblock *sb,t_partition *partition,const int debug, const int dump_ind)
+static int test_JFS(disk_t *disk_car, const struct jfs_superblock *sb,partition_t *partition,const int debug, const int dump_ind)
 {
   if(memcmp(sb->s_magic,"JFS1",4)!=0)
     return 1;
   if(dump_ind!=0)
   {
-    ecrit_rapport("\nJFS magic value at %u/%u/%u\n", offset2cylinder(disk_car,partition->part_offset),offset2head(disk_car,partition->part_offset),offset2sector(disk_car,partition->part_offset));
+    log_info("\nJFS magic value at %u/%u/%u\n", offset2cylinder(disk_car,partition->part_offset),offset2head(disk_car,partition->part_offset),offset2sector(disk_car,partition->part_offset));
     /* There is a little offset ... */
-    dump(stdscr,sb,DEFAULT_SECTOR_SIZE);
+    dump_log(sb,DEFAULT_SECTOR_SIZE);
   }
   /*
   if( sb->s_agsize >= (1 << L2BPERDMAP) ) {
