@@ -2,7 +2,7 @@
 
     File: lvm.c
 
-    Copyright (C) 2003-2006 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 2003-2007 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,7 +22,8 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
- 
+
+#include <stdio.h>
 #ifdef HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
@@ -32,12 +33,13 @@
 #include "types.h"
 #include "common.h"
 #include "lvm.h"
-#include "intrf.h"
 #include "fnctdsk.h"
-static int set_LVM_info(t_partition *partition, const pv_disk_t *pv);
-static int set_LVM2_info(t_partition*partition, const unsigned char *buf);
+#include "log.h"
 
-int check_LVM(t_param_disk *disk_car,t_partition *partition,const int debug)
+static int set_LVM_info(partition_t *partition, const pv_disk_t *pv);
+static int set_LVM2_info(partition_t*partition, const unsigned char *buf);
+
+int check_LVM(disk_t *disk_car,partition_t *partition,const int debug)
 {
   unsigned char *buffer=(unsigned char*)MALLOC(LVM_PV_DISK_SIZE);
   if(disk_car->read(disk_car,LVM_PV_DISK_SIZE, buffer, partition->part_offset)!=0)
@@ -55,7 +57,7 @@ int check_LVM(t_param_disk *disk_car,t_partition *partition,const int debug)
   return 0;
 }
 
-int recover_LVM(t_param_disk *disk_car, const pv_disk_t *pv,t_partition *partition,const int debug, const int dump_ind)
+int recover_LVM(disk_t *disk_car, const pv_disk_t *pv,partition_t *partition,const int debug, const int dump_ind)
 {
   if(test_LVM(disk_car,pv,partition,debug,dump_ind)!=0)
     return 1;
@@ -65,24 +67,24 @@ int recover_LVM(t_param_disk *disk_car, const pv_disk_t *pv,t_partition *partiti
   partition->part_size=(uint64_t)pv->pv_size*disk_car->sector_size;
   if(debug>0)
   {
-    ecrit_rapport("part_size %lu\n",(long unsigned)(partition->part_size/disk_car->sector_size));
+    log_info("part_size %lu\n",(long unsigned)(partition->part_size/disk_car->sector_size));
   }
   return 0;
 }
 
-int test_LVM(t_param_disk *disk_car, const pv_disk_t *pv,t_partition *partition,const int debug, const int dump_ind)
+int test_LVM(disk_t *disk_car, const pv_disk_t *pv,partition_t *partition,const int debug, const int dump_ind)
 {
   if ((memcmp((const char *)pv->id,LVM_ID,sizeof(pv->id)) == 0) && ((pv->version == 1) || (pv->version == 2)))
   {
     uint32_t size;
     if(debug>0 || dump_ind!=0)
     {
-      ecrit_rapport("\nLVM magic value at %u/%u/%u\n", offset2cylinder(disk_car,partition->part_offset),offset2head(disk_car,partition->part_offset),offset2sector(disk_car,partition->part_offset));
+      log_info("\nLVM magic value at %u/%u/%u\n", offset2cylinder(disk_car,partition->part_offset),offset2head(disk_car,partition->part_offset),offset2sector(disk_car,partition->part_offset));
     }
     if(dump_ind!=0)
     {
       /* There is a little offset ... */
-      dump(stdscr,pv,DEFAULT_SECTOR_SIZE);
+      dump_log(pv,DEFAULT_SECTOR_SIZE);
     }
     if (pv->pv_size > LVM_MAX_SIZE)
       return (1);
@@ -110,7 +112,7 @@ int test_LVM(t_param_disk *disk_car, const pv_disk_t *pv,t_partition *partition,
   return 1;
 }
 
-static int set_LVM_info(t_partition *partition, const pv_disk_t *pv)
+static int set_LVM_info(partition_t *partition, const pv_disk_t *pv)
 {
   partition->name[0]='\0';
   partition->info[0]='\0';
@@ -118,7 +120,7 @@ static int set_LVM_info(t_partition *partition, const pv_disk_t *pv)
   return 0;
 }
 
-int check_LVM2(t_param_disk *disk_car,t_partition *partition,const int debug)
+int check_LVM2(disk_t *disk_car,partition_t *partition,const int debug)
 {
   unsigned char *buffer=MALLOC(DEFAULT_SECTOR_SIZE);
   if(disk_car->read(disk_car,DEFAULT_SECTOR_SIZE, buffer, partition->part_offset+0x200)!=0)
@@ -136,7 +138,7 @@ int check_LVM2(t_param_disk *disk_car,t_partition *partition,const int debug)
   return 0;
 }
 
-int recover_LVM2(t_param_disk *disk_car, const unsigned char *buf,t_partition *partition,const int debug, const int dump_ind)
+int recover_LVM2(disk_t *disk_car, const unsigned char *buf,partition_t *partition,const int debug, const int dump_ind)
 {
   const struct lvm2_label_header *lh=(const struct lvm2_label_header *)buf;
   if(test_LVM2(disk_car,lh,partition,debug,dump_ind)!=0)
@@ -151,25 +153,25 @@ int recover_LVM2(t_param_disk *disk_car, const unsigned char *buf,t_partition *p
   }
   if(debug>0)
   {
-    ecrit_rapport("part_size %lu\n",(long unsigned)(partition->part_size/disk_car->sector_size));
+    log_info("part_size %lu\n",(long unsigned)(partition->part_size/disk_car->sector_size));
   }
   return 0;
 }
 
-int test_LVM2(t_param_disk *disk_car, const struct lvm2_label_header *lh,t_partition *partition,const int debug, const int dump_ind)
+int test_LVM2(disk_t *disk_car, const struct lvm2_label_header *lh,partition_t *partition,const int debug, const int dump_ind)
 {
   if (memcmp((const char *)lh->type,LVM2_LABEL,sizeof(lh->type)) == 0)
   {
     if(debug>0 || dump_ind!=0)
     {
-      ecrit_rapport("\nLVM2 magic value at %u/%u/%u\n", offset2cylinder(disk_car,partition->part_offset),offset2head(disk_car,partition->part_offset),offset2sector(disk_car,partition->part_offset));
+      log_info("\nLVM2 magic value at %u/%u/%u\n", offset2cylinder(disk_car,partition->part_offset),offset2head(disk_car,partition->part_offset),offset2sector(disk_car,partition->part_offset));
     }
     if(le32(lh->offset_xl)>400)
       return 1;
     if(dump_ind!=0)
     {
       /* There is a little offset ... */
-      dump(stdscr,lh,DEFAULT_SECTOR_SIZE);
+      dump_log(lh,DEFAULT_SECTOR_SIZE);
     }
     partition->upart_type=UP_LVM2;
     return 0;
@@ -177,7 +179,7 @@ int test_LVM2(t_param_disk *disk_car, const struct lvm2_label_header *lh,t_parti
   return 1;
 }
 
-static int set_LVM2_info(t_partition*partition, const unsigned char *buf)
+static int set_LVM2_info(partition_t*partition, const unsigned char *buf)
 {
   partition->name[0]='\0';
   partition->info[0]='\0';
