@@ -2,7 +2,7 @@
 
     File: md.c
 
-    Copyright (C) 1998-2005 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 1998-2007 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 #include <config.h>
 #endif
  
+#include <stdio.h>
 #ifdef HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
@@ -32,16 +33,16 @@
 #include "types.h"
 #include "common.h"
 #include "md.h"
-#include "intrf.h"
 #include "fnctdsk.h"
+#include "log.h"
 
-int check_MD(t_param_disk *disk_car,t_partition *partition,const int debug)
+int check_MD(disk_t *disk_car,partition_t *partition,const int debug)
 {
   unsigned char *buffer=(unsigned char*)MALLOC(MD_SB_BYTES);
   uint64_t offset=MD_NEW_SIZE_SECTORS(partition->part_size/512)*512;
   if(debug>1)
   {
-    ecrit_rapport("Raid offset %llu\n",(long long unsigned)offset/512);
+    log_debug("Raid offset %llu\n",(long long unsigned)offset/512);
   }
   if(disk_car->read(disk_car,MD_SB_BYTES, buffer, partition->part_offset+offset)!=0)
   {
@@ -58,7 +59,7 @@ int check_MD(t_param_disk *disk_car,t_partition *partition,const int debug)
   return 0;
 }
 
-int set_MD_info(t_param_disk *disk_car, const struct mdp_superblock_s *sb,t_partition *partition,const int debug, const int dump_ind)
+int set_MD_info(disk_t *disk_car, const struct mdp_superblock_s *sb,partition_t *partition,const int debug, const int dump_ind)
 {
   unsigned int i;
   sprintf(partition->name,"md%u",(unsigned int)sb->md_minor);
@@ -69,16 +70,20 @@ int set_MD_info(t_param_disk *disk_car, const struct mdp_superblock_s *sb,t_part
     {
       if(strlen(partition->info)<sizeof(partition->info)-26)
       { 
-	sprintf(&partition->info[strlen(partition->info)]," (%u,%u)",(unsigned int)sb->disks[i].major,(unsigned int)sb->disks[i].minor);
+	sprintf(&partition->info[strlen(partition->info)]," %u(%u,%u)",
+	    (unsigned int)sb->disks[i].number,
+	    (unsigned int)sb->disks[i].major,(unsigned int)sb->disks[i].minor);
 	if(sb->disks[i].major==sb->this_disk.major && sb->disks[i].minor==sb->this_disk.minor)
 	  sprintf(&partition->info[strlen(partition->info)],"*");
       }
     }
   }
+  if(debug>0)
+    log_info("%s %s\n", partition->name, partition->info);
   return 0;
 }
 
-int recover_MD(t_param_disk *disk_car, const struct mdp_superblock_s *sb,t_partition *partition,const int debug, const int dump_ind)
+int recover_MD(disk_t *disk_car, const struct mdp_superblock_s *sb,partition_t *partition,const int debug, const int dump_ind)
 {
   uint64_t offset;
   if(test_MD(disk_car,sb,partition,debug,dump_ind)!=0)
@@ -92,19 +97,19 @@ int recover_MD(t_param_disk *disk_car, const struct mdp_superblock_s *sb,t_parti
   return 0;
 }
 
-int test_MD(t_param_disk *disk_car, const struct mdp_superblock_s *sb,t_partition *partition,const int debug, const int dump_ind)
+int test_MD(disk_t *disk_car, const struct mdp_superblock_s *sb,partition_t *partition,const int debug, const int dump_ind)
 {
   if(sb->md_magic==(unsigned int)MD_SB_MAGIC)
   {
-    ecrit_rapport("\nRaid magic value at %u/%u/%u\n", offset2cylinder(disk_car,partition->part_offset),offset2head(disk_car,partition->part_offset),offset2sector(disk_car,partition->part_offset));
-    ecrit_rapport("Raid apparent size: %llu sectors\n",(long long unsigned)(sb->size<<1));
-    ecrit_rapport("Raid chunk size: %llu bytes\n",(long long unsigned)sb->chunk_size);
+    log_info("\nRaid magic value at %u/%u/%u\n", offset2cylinder(disk_car,partition->part_offset),offset2head(disk_car,partition->part_offset),offset2sector(disk_car,partition->part_offset));
+    log_info("Raid apparent size: %llu sectors\n",(long long unsigned)(sb->size<<1));
+    log_info("Raid chunk size: %llu bytes\n",(long long unsigned)sb->chunk_size);
     if(sb->chunk_size==0)
       return 1;
     if(dump_ind!=0)
     {
       /* There is a little offset ... */
-      dump(stdscr,sb,DEFAULT_SECTOR_SIZE);
+      dump_log(sb,DEFAULT_SECTOR_SIZE);
     }
     partition->upart_type=UP_RAID;
     return 0;
