@@ -32,9 +32,9 @@
 #include "types.h"
 #include "common.h"
 #include "netware.h"
-static int test_netware(t_param_disk *disk_car, const struct disk_netware *netware_block,t_partition *partition,const int debug, const int dump_ind);
+static int test_netware(disk_t *disk_car, const struct disk_netware *netware_block,partition_t *partition,const int debug, const int dump_ind);
 
-static int test_netware(t_param_disk *disk_car, const struct disk_netware *netware_block,t_partition *partition,const int debug, const int dump_ind)
+static int test_netware(disk_t *disk_car, const struct disk_netware *netware_block,partition_t *partition,const int debug, const int dump_ind)
 {
   if(memcmp(netware_block->magic,"Nw_PaRtItIoN",12)==0)
   {
@@ -44,7 +44,7 @@ static int test_netware(t_param_disk *disk_car, const struct disk_netware *netwa
   return 1;
 }
 
-int check_netware(t_param_disk *disk_car,t_partition *partition,const int debug)
+int check_netware(disk_t *disk_car,partition_t *partition,const int debug)
 {
   unsigned char *buffer=MALLOC(DEFAULT_SECTOR_SIZE);
   if(disk_car->read(disk_car,DEFAULT_SECTOR_SIZE, buffer, partition->part_offset)!=0)
@@ -61,7 +61,7 @@ int check_netware(t_param_disk *disk_car,t_partition *partition,const int debug)
   return 0;
 }
 
-int recover_netware(t_param_disk *disk_car, const struct disk_netware *netware_block,t_partition *partition)
+int recover_netware(disk_t *disk_car, const struct disk_netware *netware_block,partition_t *partition)
 {
   if(test_netware(disk_car,netware_block,partition,0,0)!=0)
     return 1;
