@@ -29,5 +29,5 @@ typedef struct disk_netware
   int32_t nbr_sectors;
 } disk_netware;
 
-int check_netware(t_param_disk *disk_car,t_partition *partition,const int debug);
-int recover_netware(t_param_disk *disk_car, const struct disk_netware *netware_block, t_partition *partition);
+int check_netware(disk_t *disk_car,partition_t *partition,const int debug);
+int recover_netware(disk_t *disk_car, const struct disk_netware *netware_block, partition_t *partition);
