@@ -2,7 +2,7 @@
 
     File: ntfs.c
 
-    Copyright (C) 1998-2006 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 1998-2007 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -41,17 +41,18 @@
 #include "ntfs.h"
 #include "fnctdsk.h"
 #include "lang.h"
+#include "log.h"
 
-static int ntfs_read_MFT(t_param_disk *disk_car, t_partition *partition, const struct ntfs_boot_sector*ntfs_header,const int my_type,const int debug, const int dump_ind);
-static int ntfs_get_attr_aux(const char *attr_record, const int my_type, t_partition *partition, const char *end, const int debug, const int dump_ind, const char*file_name_to_find);
+static int ntfs_read_MFT(disk_t *disk_car, partition_t *partition, const struct ntfs_boot_sector*ntfs_header,const int my_type,const int debug, const int dump_ind);
+static int ntfs_get_attr_aux(const char *attr_record, const int my_type, partition_t *partition, const char *end, const int debug, const int dump_ind, const char*file_name_to_find);
 
 unsigned int ntfs_sector_size(const struct ntfs_boot_sector *ntfs_header)
 { return (ntfs_header->sector_size[1]<<8)+ntfs_header->sector_size[0]; }
 
-int check_NTFS(t_param_disk *disk_car,t_partition *partition,const int debug,const int dump_ind)
+int check_NTFS(disk_t *disk_car,partition_t *partition,const int debug,const int dump_ind)
 {
   unsigned char *buffer=(unsigned char*)MALLOC(DEFAULT_SECTOR_SIZE);
-/*  ecrit_rapport("check_NTFS part_offset=%llu\n",(long long unsigned)partition->part_offset); */
+/*  log_trace("check_NTFS part_offset=%llu\n",(long long unsigned)partition->part_offset); */
   if(disk_car->read(disk_car,DEFAULT_SECTOR_SIZE, buffer, partition->part_offset)!=0)
   {
     free(buffer);
@@ -67,34 +68,34 @@ int check_NTFS(t_param_disk *disk_car,t_partition *partition,const int debug,con
   return 0;
 }
 
-int recover_NTFS(t_param_disk *disk_car, const struct ntfs_boot_sector*ntfs_header,t_partition *partition,const int debug, const int dump_ind, const int backup)
+int recover_NTFS(disk_t *disk_car, const struct ntfs_boot_sector*ntfs_header,partition_t *partition,const int debug, const int dump_ind, const int backup)
 {
   uint64_t part_size;
   if(test_NTFS(disk_car,ntfs_header,partition,debug,dump_ind)!=0)
     return 1;
   if(debug>0)
   {
-    dump_ntfs_rapport(ntfs_header);
+    log_ntfs_dump(ntfs_header);
   }
   part_size=(uint64_t)(le64(ntfs_header->sectors_nbr)+1)*ntfs_sector_size(ntfs_header);
   if(backup>0)
   {
     if(partition->part_offset+disk_car->sector_size<part_size)
     {
-      ecrit_rapport("NTFS part_offset=%llu, part_size=%llu, sector_size=%u\n",
+      log_warning("NTFS part_offset=%llu, part_size=%llu, sector_size=%u\n",
 	  (long long unsigned)partition->part_offset, (long long unsigned)part_size,
 	  disk_car->sector_size);
-      ecrit_rapport("NTFS partition can not be added (part_offset<part_size).\n");
+      log_warning("NTFS partition cannot be added (part_offset<part_size).\n");
       return 1;
     }
     if(debug>1)
-      ecrit_rapport("NTFS part_offset=%llu, part_size=%llu, sector_size=%u\n",
+      log_info("NTFS part_offset=%llu, part_size=%llu, sector_size=%u\n",
 	  (long long unsigned)partition->part_offset, (long long unsigned)part_size,
 	  disk_car->sector_size);
     partition->boot_sector=part_size/disk_car->sector_size-1;
     partition->part_offset=partition->part_offset+disk_car->sector_size-part_size;
     if(debug>1)
-      ecrit_rapport("part_offset=%llu\n",(long long unsigned)partition->part_offset);
+      log_info("part_offset=%llu\n",(long long unsigned)partition->part_offset);
   }
   partition->part_size=part_size;
   partition->part_type_i386=P_NTFS;
@@ -102,14 +103,17 @@ int recover_NTFS(t_param_disk *disk_car, const struct ntfs_boot_sector*ntfs_head
   return 0;
 }
 
-int set_NTFS_info(t_param_disk *disk_car, const struct ntfs_boot_sector*ntfs_header,t_partition *partition,const int debug, const int dump_ind)
+int set_NTFS_info(disk_t *disk_car, const struct ntfs_boot_sector*ntfs_header,partition_t *partition,const int debug, const int dump_ind)
 {
   partition->name[0]='\0';
-  snprintf(partition->info,sizeof(partition->info),"NTFS");
+  if(partition->boot_sector==0)
+    strncpy(partition->info, "NTFS", sizeof(partition->info));
+  else
+    strncpy(partition->info, "NTFS found using backup sector!", sizeof(partition->info));
   return ntfs_read_MFT(disk_car, partition, ntfs_header,0x60,debug,dump_ind);
 }
 
-int test_NTFS(const t_param_disk *disk_car,const struct ntfs_boot_sector*ntfs_header, t_partition *partition,const int debug, const int dump_ind)
+int test_NTFS(const disk_t *disk_car,const struct ntfs_boot_sector*ntfs_header, partition_t *partition,const int debug, const int dump_ind)
 {
   const char*buffer=(const char*)ntfs_header;
   if(le16(ntfs_header->marker)==0xAA55)
@@ -130,24 +134,24 @@ int test_NTFS(const t_param_disk *disk_car,const struct ntfs_boot_sector*ntfs_he
       }
       if((debug>0) || (dump_ind!=0))
       {
-	ecrit_rapport("NTFS at %u/%u/%u\n", offset2cylinder(disk_car,partition->part_offset),offset2head(disk_car,partition->part_offset),offset2sector(disk_car,partition->part_offset));
+	log_info("NTFS at %u/%u/%u\n", offset2cylinder(disk_car,partition->part_offset),offset2head(disk_car,partition->part_offset),offset2sector(disk_car,partition->part_offset));
 	if(dump_ind!=0)
-	  dump(stdscr,buffer,DEFAULT_SECTOR_SIZE);
+	  dump_ncurses(buffer,DEFAULT_SECTOR_SIZE);
       }
       if(le16(ntfs_header->heads)!=disk_car->CHS.head+1)
       {
 	aff_buffer(BUFFER_ADD,"Warning: Incorrect number of heads/cylinder %u (NTFS) != %u (HD)\n",le16(ntfs_header->heads),disk_car->CHS.head+1);
-	ecrit_rapport("heads/cylinder %u (NTFS) != %u (HD)\n",le16(ntfs_header->heads),disk_car->CHS.head+1);
+	log_warning("heads/cylinder %u (NTFS) != %u (HD)\n",le16(ntfs_header->heads),disk_car->CHS.head+1);
       }
       if(le16(ntfs_header->secs_track)!=disk_car->CHS.sector)
       {
 	aff_buffer(BUFFER_ADD,"Warning: Incorrect number of sectors per track %u (NTFS) != %u (HD)\n",le16(ntfs_header->secs_track),disk_car->CHS.sector);
-	ecrit_rapport("sect/track %u (NTFS) != %u (HD)\n",le16(ntfs_header->secs_track),disk_car->CHS.sector);
+	log_warning("sect/track %u (NTFS) != %u (HD)\n",le16(ntfs_header->secs_track),disk_car->CHS.sector);
       }
       if(ntfs_sector_size(ntfs_header)!=disk_car->sector_size)
       {
 	aff_buffer(BUFFER_ADD,"Warning: Incorrect number of bytes per sector %u (NTFS) != %u (HD)\n",ntfs_sector_size(ntfs_header),disk_car->sector_size);
-	ecrit_rapport("Warning: Incorrect number of bytes per sector %u (NTFS) != %u (HD)\n",ntfs_sector_size(ntfs_header),disk_car->sector_size);
+	log_warning("Warning: Incorrect number of bytes per sector %u (NTFS) != %u (HD)\n",ntfs_sector_size(ntfs_header),disk_car->sector_size);
       }
 
       if(partition->part_size>0)
@@ -157,13 +161,13 @@ int test_NTFS(const t_param_disk *disk_car,const struct ntfs_boot_sector*ntfs_he
 
 	if(part_size*ntfs_sector_size(ntfs_header)>partition->part_size)
 	{
-	  ecrit_rapport("Error: size boot_sector %lu > partition %lu\n",(long unsigned)part_size,(long unsigned)(partition->part_size/disk_car->sector_size));
 	  aff_buffer(BUFFER_ADD,"Error: size boot_sector %lu > partition %lu\n",(long unsigned)part_size,(long unsigned)(partition->part_size/disk_car->sector_size));
+	  log_error("Error: size boot_sector %lu > partition %lu\n",(long unsigned)part_size,(long unsigned)(partition->part_size/disk_car->sector_size));
 	  return 1;
 	}
 	if((debug>0) && (part_size!=partition->part_size/disk_car->sector_size))
 	{
-	    ecrit_rapport("Info: size boot_sector %lu, partition %lu\n",(long unsigned)part_size,(long unsigned)(partition->part_size/disk_car->sector_size));
+	    log_info("Info: size boot_sector %lu, partition %lu\n",(long unsigned)part_size,(long unsigned)(partition->part_size/disk_car->sector_size));
 	}
       }
       partition->upart_type=UP_NTFS;
@@ -174,7 +178,7 @@ int test_NTFS(const t_param_disk *disk_car,const struct ntfs_boot_sector*ntfs_he
 }
 
 /* */
-int ntfs_get_attr(const char *mft_record, const int my_type, t_partition *partition, const char *end, const int debug, const int dump_ind, const char*file_name_to_find)
+int ntfs_get_attr(const char *mft_record, const int my_type, partition_t *partition, const char *end, const int debug, const int dump_ind, const char*file_name_to_find)
 {
   const char *attr_record;
   /* Only check for magic DWORD here, fixup should have happened before */
@@ -191,7 +195,7 @@ int ntfs_get_attr(const char *mft_record, const int my_type, t_partition *partit
   return ntfs_get_attr_aux(attr_record, my_type, partition, end, debug, dump_ind, file_name_to_find);
 }
 
-static int ntfs_get_attr_aux(const char *attr_record, const int my_type, t_partition *partition, const char *end, const int debug, const int dump_ind, const char*file_name_to_find)
+static int ntfs_get_attr_aux(const char *attr_record, const int my_type, partition_t *partition, const char *end, const int debug, const int dump_ind, const char*file_name_to_find)
 {
   int attr_type;
   while(1)
@@ -202,7 +206,7 @@ static int ntfs_get_attr_aux(const char *attr_record, const int my_type, t_parti
     {
       if(debug>1)
       {
-	ecrit_rapport("ntfs_get_attr attr_record+0x18>=end\n");
+	log_error("ntfs_get_attr attr_record+0x18>=end\n");
       }
       return 2;
     }
@@ -214,51 +218,41 @@ static int ntfs_get_attr_aux(const char *attr_record, const int my_type, t_parti
     {
       if(debug>1)
       {
-	ecrit_rapport("ntfs_get_attr attr_type=%x attr_len=%u (attr_len%%8!0)||(attr_len<0x18)\n",attr_type,attr_len);
+	log_error("ntfs_get_attr attr_type=%x attr_len=%u (attr_len%%8!0)||(attr_len<0x18)\n",attr_type,attr_len);
       }
       return 2;
     }
     if(debug>1)
     {
-      ecrit_rapport("attr_type=%x %s\n",attr_type,(NTFS_GETU8(attr_record+8)==0?"resident":"non resident"));
+      log_info("attr_type=%x %s\n",attr_type,(NTFS_GETU8(attr_record+8)==0?"resident":"non resident"));
       dump_log(attr_record,attr_len);
     }
     if(dump_ind)
-    {
-      WINDOW *window=newwin(0,0,0,0);	/* full screen */
-      keypad(window, TRUE); /* Need it to get arrow key */
-      aff_copy(window);
-      dump(window,attr_record,attr_len);
-      delwin(window);
-      (void) clearok(stdscr, TRUE);
-#ifdef HAVE_TOUCHWIN
-      touchwin(stdscr);
-#endif
-    }
+      dump_ncurses(attr_record, attr_len);
     if(NTFS_GETU8(attr_record+8)==0)	/* attribute is resident */
     {
       unsigned int attr_value_length=NTFS_GETU16(attr_record+0x10);
       unsigned int attr_value_offset=NTFS_GETU16(attr_record+0x14);
-      const char *attr_list_entry=attr_record+attr_value_offset;
+      const char *attr_td_list_entry=attr_record+attr_value_offset;
       if(attr_value_offset%8!=0)
       {
 #ifdef NTFS_DEBUG
-	ecrit_rapport("ntfs_get_attr attr_value_offset=%u (%%8!=0)\n",attr_value_offset);
+	log_debug("ntfs_get_attr attr_value_offset=%u (%%8!=0)\n",attr_value_offset);
 #endif
 	return 2;
       }
-      if(attr_list_entry+26>=end)
+      if(attr_td_list_entry+26>=end)
       {
 #ifdef NTFS_DEBUG
-	ecrit_rapport("ntfs_get_attr attr_list_entry+26=%p, end=%p\n",attr_list_entry+26,end);
+	log_debug("ntfs_get_attr attr_td_list_entry+26=%p, end=%p\n",attr_td_list_entry+26,end);
 #endif
 	return 2;
       }
       /* We found the attribute type. Is the name correct, too? */
-      if((attr_value_offset+attr_value_length>attr_len) || (attr_list_entry+attr_len >= end))
+      if((attr_value_offset+attr_value_length>attr_len) || (attr_td_list_entry+attr_len >= end))
       {
 #ifdef NTFS_DEBUG
-	// ecrit_rapport("ntfs_get_attr \n");
+	// log_debug("ntfs_get_attr \n");
 #endif
 	return 2;
       }
@@ -268,7 +262,7 @@ static int ntfs_get_attr_aux(const char *attr_record, const int my_type, t_parti
 	{
 	  case 0x30:	/* AT_FILE_NAME */
 	    {
-	      const char *file_name_attr=attr_list_entry;
+	      const char *file_name_attr=attr_td_list_entry;
 	      unsigned int file_name_length;
 	      const char *name_it;
 	      if(file_name_attr+0x42>=end)
@@ -285,7 +279,7 @@ static int ntfs_get_attr_aux(const char *attr_record, const int my_type, t_parti
 		file_name[i]='\0';
 		if(debug>1)
 		{
-		  ecrit_rapport("file_name=%s\n",file_name);
+		  log_debug("file_name=%s\n",file_name);
 		}
 		if(file_name_to_find!=NULL)
 		{
@@ -309,13 +303,13 @@ static int ntfs_get_attr_aux(const char *attr_record, const int my_type, t_parti
 	      volume_name_length/=2;	/* Unicode */
 	      if(volume_name_length>sizeof(partition->name)-1)
 		volume_name_length=sizeof(partition->name)-1;
-	      for(name_it=attr_list_entry;(volume_name_length>0) && (*name_it!='\0') && (name_it[1]=='\0'); name_it+=2,volume_name_length--)
+	      for(name_it=attr_td_list_entry;(volume_name_length>0) && (*name_it!='\0') && (name_it[1]=='\0'); name_it+=2,volume_name_length--)
 		*dest++=*name_it;
 	      *dest++='\0'; /* 27 january 2003: Correct a bug found by Andreas du Plessis-Denz */
 	    }
 	    return 1;
 	  case 0x90:	/* AT_INDEX_ROOT */
-	    return NTFS_GETU32(attr_list_entry+8);	/* index_block_size */
+	    return NTFS_GETU32(attr_td_list_entry+8);	/* index_block_size */
 	}
       }
     }
@@ -344,22 +338,22 @@ static int ntfs_get_attr_aux(const char *attr_record, const int my_type, t_parti
 		if (b){
 		  if (buf + b > attr_end)
 		  {
-		    ecrit_rapport("Attribut AT_DATA: bad size\n");
+		    log_error("Attribut AT_DATA: bad size\n");
 		    return 0;
 		  }
 		  for (deltaxcn = (int8_t)buf[b--]; b; b--)
 		    deltaxcn = (deltaxcn << 8) + (uint8_t)buf[b];
 		  /* Assume a negative length to indicate data corruption */
 		  if (deltaxcn < 0)
-		    ecrit_rapport("Invalid length in mapping pairs array.\n");
+		    log_error("Invalid length in mapping pairs array.\n");
 		} else { /* The length entry is compulsory. */
-		  ecrit_rapport("Missing length entry in mapping pairs array.\n");
+		  log_error("Missing length entry in mapping pairs array.\n");
 		}
 		if (deltaxcn >= 0)
 		{
 		  if (!(*buf & 0xf0))
 		  {
-		    ecrit_rapport("LCN_HOLE\n");
+		    log_info("LCN_HOLE\n");
 		  }
 		  else
 		  {
@@ -368,7 +362,7 @@ static int ntfs_get_attr_aux(const char *attr_record, const int my_type, t_parti
 		    b = b2 + ((*buf >> 4) & 0xf);
 		    if (buf + b > attr_end)
 		    {
-		      ecrit_rapport("Attribut AT_DATA: bad size\n");
+		      log_error("Attribut AT_DATA: bad size\n");
 		      return 0;
 		    }
 		    for (deltaxcn = (int8_t)buf[b--]; b > b2; b--)
@@ -377,12 +371,12 @@ static int ntfs_get_attr_aux(const char *attr_record, const int my_type, t_parti
 		    lcn += deltaxcn;
 		    /* Check lcn is not below -1. */
 		    if (lcn < -1) {
-		      ecrit_rapport("Invalid LCN < -1 in mapping pairs array.");
+		      log_error("Invalid LCN < -1 in mapping pairs array.");
 		      return 0;
 		    }
 		    if(debug>1)
 		    {
-		      ecrit_rapport("LCN %ld\n",lcn);
+		      log_debug("LCN %ld\n",lcn);
 		    }
 		    if(attr_type==my_type)
 		      return lcn;
@@ -398,7 +392,7 @@ static int ntfs_get_attr_aux(const char *attr_record, const int my_type, t_parti
   }
 }
 
-static int ntfs_read_MFT(t_param_disk *disk_car, t_partition *partition, const struct ntfs_boot_sector*ntfs_header,const int my_type,const int debug, const int dump_ind)
+static int ntfs_read_MFT(disk_t *disk_car, partition_t *partition, const struct ntfs_boot_sector*ntfs_header,const int my_type,const int debug, const int dump_ind)
 {
   unsigned char *buffer;
   char *attr;
@@ -413,15 +407,15 @@ static int ntfs_read_MFT(t_param_disk *disk_car, t_partition *partition, const s
   /* Only need the first 4 MFT record */
   mft_size=4*mft_record_size*ntfs_sector_size(ntfs_header);
 #ifdef NTFS_DEBUG
-  ecrit_rapport("NTFS cluster size = %u\n",ntfs_header->sectors_per_cluster);
-  ecrit_rapport("NTFS MFT cluster = %lu\n",le64(ntfs_header->mft_lcn));
-  ecrit_rapport("NTFS MFT_record_size = %u\n",mft_record_size);
-  ecrit_rapport("NTFS sector size= %u\n", ntfs_sector_size(ntfs_header));
+  log_debug("NTFS cluster size = %u\n",ntfs_header->sectors_per_cluster);
+  log_debug("NTFS MFT cluster = %lu\n",le64(ntfs_header->mft_lcn));
+  log_debug("NTFS MFT_record_size = %u\n",mft_record_size);
+  log_debug("NTFS sector size= %u\n", ntfs_sector_size(ntfs_header));
 #endif
   buffer=(unsigned char *)MALLOC(mft_size);
   if(disk_car->read(disk_car,mft_size, buffer, mft_pos)!=0)
   {
-    ecrit_rapport("NTFS: Can't read MFT\n");
+    log_error("NTFS: Can't read MFT\n");
     free(buffer);
     return 1;
   }
@@ -440,26 +434,30 @@ static int ntfs_read_MFT(t_param_disk *disk_car, t_partition *partition, const s
   return 0;
 }
 
-int is_ntfs(const t_partition *partition)
+int is_part_ntfs(const partition_t *partition)
 {
   switch(partition->part_type_i386)
   {
     case P_NTFS:
     case P_NTFSH:
       return 1;
+    default:
+      return 0;
   }
-  if(partition->upart_type==UP_NTFS)
-    return 1;
-  return 0;
 }
 
-int dump_ntfs_rapport(const struct ntfs_boot_sector *ntfs_header)
+int is_ntfs(const partition_t *partition)
 {
-  ecrit_rapport("filesystem size           %llu\n", (long long unsigned)le64(ntfs_header->sectors_nbr)+1);
-  ecrit_rapport("sectors_per_cluster       %u\n", ntfs_header->sectors_per_cluster);
-  ecrit_rapport("mft_lcn                   %lu\n", (long unsigned int)le64(ntfs_header->mft_lcn));
-  ecrit_rapport("mftmirr_lcn               %lu\n", (long unsigned int)le64(ntfs_header->mftmirr_lcn));
-  ecrit_rapport("clusters_per_mft_record   %d\n", ntfs_header->clusters_per_mft_record);
-  ecrit_rapport("clusters_per_index_record %d\n", ntfs_header->clusters_per_index_record);
+  return(is_part_ntfs(partition) || partition->upart_type==UP_NTFS);
+}
+
+int log_ntfs_dump(const struct ntfs_boot_sector *ntfs_header)
+{
+  log_info("filesystem size           %llu\n", (long long unsigned)le64(ntfs_header->sectors_nbr)+1);
+  log_info("sectors_per_cluster       %u\n", ntfs_header->sectors_per_cluster);
+  log_info("mft_lcn                   %lu\n", (long unsigned int)le64(ntfs_header->mft_lcn));
+  log_info("mftmirr_lcn               %lu\n", (long unsigned int)le64(ntfs_header->mftmirr_lcn));
+  log_info("clusters_per_mft_record   %d\n", ntfs_header->clusters_per_mft_record);
+  log_info("clusters_per_index_record %d\n", ntfs_header->clusters_per_index_record);
   return 0;
 }
