@@ -52,19 +52,20 @@ struct ntfs_boot_sector {
 	uint8_t  	bootstrap[426];             	/* 0x54 Irrelevant (boot up code). */
 	uint16_t	marker;				/* 0x1FE */
 	} __attribute__ ((__packed__));
-int check_NTFS(t_param_disk *disk_car,t_partition *partition,const int debug,const int dump_ind);
-int dump_2ntfs_rapport(const struct ntfs_boot_sector *nh1, const struct ntfs_boot_sector *nh2);
-int dump_ntfs_rapport(const struct ntfs_boot_sector *ntfs_header);
-int is_ntfs(const t_partition *partition);
-int ntfs_get_attr(const char *mft_record, const int my_type, t_partition *partition, const char *end, const int debug, const int dump_ind, const char*file_name_to_find);
-int recover_NTFS(t_param_disk *disk_car, const struct ntfs_boot_sector*ntfs_header,t_partition *partition,const int debug, const int dump_ind, const int backup);
-int set_NTFS_info(t_param_disk *disk_car, const struct ntfs_boot_sector*ntfs_header,t_partition *partition,const int debug, const int dump_ind);
-int test_NTFS(const t_param_disk *disk_car,const struct ntfs_boot_sector*ntfs_header, t_partition *partition,const int debug, const int dump_ind);
+int check_NTFS(disk_t *disk_car,partition_t *partition,const int debug,const int dump_ind);
+int log_ntfs2_dump(const struct ntfs_boot_sector *nh1, const struct ntfs_boot_sector *nh2);
+int log_ntfs_dump(const struct ntfs_boot_sector *ntfs_header);
+int is_ntfs(const partition_t *partition);
+int is_part_ntfs(const partition_t *partition);
+int ntfs_get_attr(const char *mft_record, const int my_type, partition_t *partition, const char *end, const int debug, const int dump_ind, const char*file_name_to_find);
+int recover_NTFS(disk_t *disk_car, const struct ntfs_boot_sector*ntfs_header,partition_t *partition,const int debug, const int dump_ind, const int backup);
+int set_NTFS_info(disk_t *disk_car, const struct ntfs_boot_sector*ntfs_header,partition_t *partition,const int debug, const int dump_ind);
+int test_NTFS(const disk_t *disk_car,const struct ntfs_boot_sector*ntfs_header, partition_t *partition,const int debug, const int dump_ind);
 #define NTFS_GETU8(p)      (*(const uint8_t*)(p))
 #define NTFS_GETU16(p)     (le16(*(const uint16_t*)(p)))
 #define NTFS_GETU32(p)     (le32(*(const uint32_t*)(p)))
 #define NTFS_GETU64(p)     (le64(*(const uint64_t*)(p)))
 unsigned int ntfs_sector_size(const struct ntfs_boot_sector *ntfs_header);
-int rebuild_NTFS_BS(t_param_disk *disk_car,t_partition *partition, const int debug, const int dump_ind,const int interface, const unsigned int expert, char**current_cmd);
-int repair_MFT(t_param_disk *disk_car, t_partition *partition, const int debug);
-int repair_MFT_Vol(t_param_disk *disk_car, t_partition *partition, const int debug);
+int rebuild_NTFS_BS(disk_t *disk_car,partition_t *partition, const int debug, const int dump_ind,const int interface, const unsigned int expert, char**current_cmd);
+int repair_MFT(disk_t *disk_car, partition_t *partition, const int debug, char **current_cmd);
+int repair_MFT_Vol(disk_t *disk_car, partition_t *partition, const int debug);
