@@ -1,7 +1,7 @@
 /**
  * ntfs_dir.c - Part of the TestDisk project.
  *
- * Copyright (c) 2004-2006 Christophe Grenier
+ * Copyright (c) 2004-2007 Christophe Grenier
  *
  * Original version comes from the Linux-NTFS project.
  * Copyright (c) 2003 Lode Leroy
@@ -30,6 +30,7 @@
 #ifdef HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
+#include <stdio.h>
 #ifdef HAVE_SYS_STAT_H
 #include <sys/stat.h>
 #endif
@@ -39,7 +40,9 @@
 #ifdef HAVE_STRING_H
 #include <string.h>
 #endif
+#ifdef HAVE_ERRNO_H
 #include <errno.h>
+#endif
 #ifdef HAVE_SYS_PARAM_H
 #include <sys/param.h>
 #endif
@@ -62,7 +65,9 @@
 #include "dir.h"
 #include "ntfs_dir.h"
 #include "io_redir.h"
-
+#include "ntfs_utl.h"
+#include "ntfs_inc.h"
+#include "log.h"
 
 #ifdef HAVE_LIBNTFS
 #define MAX_PATH    1024
@@ -71,14 +76,6 @@
 #define NTFS_DT_REG             8
 #define NTFS_TIME_OFFSET ((s64)(369 * 365 + 89) * 24 * 3600 * 10000000)
 
-struct list_dir_struct {
-	t_file_data *dir_list;
-	t_file_data *current_file;
-	ntfs_volume *vol;
-	t_my_data *my_data;
-	unsigned long int inode;
-};
-
 /*
  * This is the "ntfs_filldir" function type, used by ntfs_readdir() to let
  * the caller specify what kind of dirent layout it wants to have.
@@ -96,14 +93,35 @@ extern int ntfs_readdir(ntfs_inode *dir_ni, s64 *pos,
 extern u64 ntfs_inode_lookup_by_name(ntfs_inode *dir_ni,
                 const ntfschar *uname, const int uname_len);
 static time_t ntfs2utc (s64 ntfstime);
-static int ntfs_list_entry(  struct list_dir_struct *ls, const ntfschar *name, 
+static int ntfs_td_list_entry(  struct ntfs_dir_struct *ls, const ntfschar *name, 
 		const int name_len, const int name_type, const s64 pos,
 		const MFT_REF mref, const unsigned dt_type);
-static t_file_data *ntfs_dir(t_param_disk *disk_car, const t_partition *partition, t_dir_data *dir_data, const unsigned long int cluster);
-static ATTR_RECORD * find_attribute(const ATTR_TYPES type, ntfs_attr_search_ctx *ctx);
-static ATTR_RECORD * find_first_attribute(const ATTR_TYPES type, MFT_RECORD *mft);
-static int ntfs_copy(t_param_disk *disk_car, const t_partition *partition, t_dir_data *dir_data, const unsigned long int first_inode);
-static void dir_partition_ntfs_close(t_dir_data *dir_data);
+static file_data_t *ntfs_dir(disk_t *disk_car, const partition_t *partition, dir_data_t *dir_data, const unsigned long int cluster);
+static int ntfs_copy(disk_t *disk_car, const partition_t *partition, dir_data_t *dir_data, const file_data_t *file);
+static void dir_partition_ntfs_close(dir_data_t *dir_data);
+
+/**
+ * index_get_size - Find the INDX block size from the index root
+ * @inode:  Inode of the directory to be checked
+ *
+ * Find the size of a directory's INDX block from the INDEX_ROOT attribute.
+ *
+ * Return:  n  Success, the INDX blocks are n bytes in size
+ *	    0  Error, not a directory
+ */
+static int index_get_size(ntfs_inode *inode)
+{
+	ATTR_RECORD *attr90;
+	INDEX_ROOT *iroot;
+
+	attr90 = find_first_attribute(AT_INDEX_ROOT, inode->mrec);
+	if (!attr90)
+		return 0;	// not a directory
+
+	iroot = (INDEX_ROOT*)((u8*)attr90 + le16_to_cpu(attr90->value_offset));
+
+	return iroot->index_block_size;
+}
 
 /**
  * ntfs2utc - Convert an NTFS time to Unix time
@@ -120,10 +138,10 @@ static time_t ntfs2utc (s64 ntfstime)
 }
 
 /**
- * ntfs_list_entry
+ * ntfs_td_list_entry
  * FIXME: Should we print errors as we go along? (AIA)
  */
-static int ntfs_list_entry(  struct list_dir_struct *ls, const ntfschar *name, 
+static int ntfs_td_list_entry(  struct ntfs_dir_struct *ls, const ntfschar *name, 
 		const int name_len, const int name_type, const s64 pos,
 		const MFT_REF mref, const unsigned dt_type)
 {
@@ -132,12 +150,12 @@ static int ntfs_list_entry(  struct list_dir_struct *ls, const ntfschar *name,
   filename = calloc (1, MAX_PATH);
   if (!filename)
   {
-    ecrit_rapport("ntfs_list_entry calloc failed\n");
+    log_critical("ntfs_td_list_entry calloc failed\n");
     return -1;
   }
 
   if (ntfs_ucstombs (name, name_len, &filename, MAX_PATH) < 0) {
-    ecrit_rapport("Cannot represent filename in current locale.\n");
+    log_error("Cannot represent filename in current locale.\n");
     goto free;
   }
 
@@ -183,7 +201,7 @@ static int ntfs_list_entry(  struct list_dir_struct *ls, const ntfschar *name,
     }
 
     {
-      t_file_data *new_file=MALLOC(sizeof(*new_file));
+      file_data_t *new_file=MALLOC(sizeof(*new_file));
       memcpy(new_file->name,filename,(MAX_PATH<sizeof(new_file->name)?MAX_PATH:sizeof(new_file->name)));
       new_file->prev=ls->current_file;
       new_file->next=NULL;
@@ -207,8 +225,7 @@ static int ntfs_list_entry(  struct list_dir_struct *ls, const ntfschar *name,
       new_file->filestat.st_mtime=ntfs2utc(sle64_to_cpu(file_name_attr->last_data_change_time));
       new_file->prev=ls->current_file;
       new_file->next=NULL;
-      /* ecrit_rapport("fat: new file %s de=%p size=%u\n",new_file->name,de,de->size); */
-      /*    fat_write_rapport(new_fat_element); */
+      /* log_debug("fat: new file %s de=%p size=%u\n",new_file->name,de,de->size); */
       if(ls->current_file!=NULL)
 	ls->current_file->next=new_file;
       else
@@ -255,17 +272,17 @@ free:
  * soon as the function returns.
  */
 
-static t_file_data *ntfs_dir(t_param_disk *disk_car, const t_partition *partition, t_dir_data *dir_data, const unsigned long int cluster)
+static file_data_t *ntfs_dir(disk_t *disk_car, const partition_t *partition, dir_data_t *dir_data, const unsigned long int cluster)
 {
   ntfs_inode *inode;
   s64 pos;
-  struct list_dir_struct *ls=(struct list_dir_struct*)dir_data->private_dir_data;
+  struct ntfs_dir_struct *ls=(struct ntfs_dir_struct*)dir_data->private_dir_data;
   ls->dir_list=NULL;
   ls->current_file=NULL;
 
   inode = ntfs_inode_open (ls->vol, cluster);
   if (!inode) {
-    ecrit_rapport("ntfs_dir: ntfs_inode_open failed\n");
+    log_error("ntfs_dir: ntfs_inode_open failed\n");
     return NULL;
   }
 
@@ -275,117 +292,26 @@ static t_file_data *ntfs_dir(t_param_disk *disk_car, const t_partition *partitio
    */
   pos = 0;
   if (inode->mrec->flags & MFT_RECORD_IS_DIRECTORY) {
-    if(ntfs_readdir(inode, &pos, ls, (ntfs_filldir_t)ntfs_list_entry)<0)
+    if(ntfs_readdir(inode, &pos, ls, (ntfs_filldir_t)ntfs_td_list_entry)<0)
     {
-      ecrit_rapport("ntfs_readdir failed\n");
+      log_error("ntfs_readdir failed\n");
     }
   }
   else
-    ecrit_rapport("ntfs_readdir BUG not MFT_RECORD_IS_DIRECTORY\n");
+    log_critical("ntfs_readdir BUG not MFT_RECORD_IS_DIRECTORY\n");
   /* Finished with the inode; release it. */
   ntfs_inode_close(inode);
   return ls->dir_list;
 }
 
-/**
- * find_attribute - Find an attribute of the given type
- * @type:  An attribute type, e.g. AT_FILE_NAME
- * @ctx:   A search context, created using ntfs_get_attr_search_ctx
- *
- * Using the search context to keep track, find the first/next occurrence of a
- * given attribute type.
- *
- * N.B.  This will return a pointer into @mft.  As long as the search context
- *       has been created without an inode, it won't overflow the buffer.
- *
- * Return:  Pointer  Success, an attribute was found
- *	    NULL     Error, no matching attributes were found
- */
-static ATTR_RECORD * find_attribute(const ATTR_TYPES type, ntfs_attr_search_ctx *ctx)
-{
-	if (!ctx) {
-		errno = EINVAL;
-		return NULL;
-	}
-
-	if (ntfs_attr_lookup(type, NULL, 0, 0, 0, NULL, 0, ctx) != 0) {
-		ecrit_rapport("find_attribute didn't find an attribute of type: 0x%02x.\n", type);
-		return NULL;	/* None / no more of that type */
-	}
-
-	ecrit_rapport("find_attribute found an attribute of type: 0x%02x.\n", type);
-	return ctx->attr;
-}
-
-/**
- * find_first_attribute - Find the first attribute of a given type
- * @type:  An attribute type, e.g. AT_FILE_NAME
- * @mft:   A buffer containing a raw MFT record
- *
- * Search through a raw MFT record for an attribute of a given type.
- * The return value is a pointer into the MFT record that was supplied.
- *
- * N.B.  This will return a pointer into @mft.  The pointer won't stray outside
- *       the buffer, since we created the search context without an inode.
- *
- * Return:  Pointer  Success, an attribute was found
- *	    NULL     Error, no matching attributes were found
- */
-static ATTR_RECORD * find_first_attribute(const ATTR_TYPES type, MFT_RECORD *mft)
-{
-	ntfs_attr_search_ctx *ctx;
-	ATTR_RECORD *rec;
-
-	if (!mft) {
-		errno = EINVAL;
-		return NULL;
-	}
-
-	ctx = ntfs_attr_get_search_ctx(NULL, mft);
-	if (!ctx) {
-		ecrit_rapport("Couldn't create a search context.\n");
-		return NULL;
-	}
-
-	rec = find_attribute(type, ctx);
-	ntfs_attr_put_search_ctx(ctx);
-	if (rec)
-		ecrit_rapport("find_first_attribute: found attr of type 0x%02x.\n", type);
-	else
-		ecrit_rapport("find_first_attribute: didn't find attr of type 0x%02x.\n", type);
-	return rec;
-}
-
-/**
- * index_get_size - Find the INDX block size from the index root
- * @inode:  Inode of the directory to be checked
- *
- * Find the size of a directory's INDX block from the INDEX_ROOT attribute.
- *
- * Return:  n  Success, the INDX blocks are n bytes in size
- *	    0  Error, not a directory
- */
-static int index_get_size(ntfs_inode *inode)
-{
-	ATTR_RECORD *attr90;
-	INDEX_ROOT *iroot;
-
-	attr90 = find_first_attribute(AT_INDEX_ROOT, inode->mrec);
-	if (!attr90)
-		return 0;	// not a directory
-
-	iroot = (INDEX_ROOT*)((u8*)attr90 + le16_to_cpu(attr90->value_offset));
-
-	return iroot->index_block_size;
-}
-
-static int ntfs_copy(t_param_disk *disk_car, const t_partition *partition, t_dir_data *dir_data, const unsigned long int first_inode)
+static int ntfs_copy(disk_t *disk_car, const partition_t *partition, dir_data_t *dir_data, const file_data_t *file)
 {
+  const unsigned long int first_inode=file->filestat.st_ino;
   ntfs_inode *inode;
-  struct list_dir_struct *ls=(struct list_dir_struct*)dir_data->private_dir_data;
+  struct ntfs_dir_struct *ls=(struct ntfs_dir_struct*)dir_data->private_dir_data;
   inode = ntfs_inode_open (ls->vol, first_inode);
   if (!inode) {
-    ecrit_rapport("ntfs_copy: ntfs_inode_open failed\n");
+    log_error("ntfs_copy: ntfs_inode_open failed\n");
     return -1;
   }
   {
@@ -403,7 +329,7 @@ static int ntfs_copy(t_param_disk *disk_car, const t_partition *partition, t_dir
     attr = ntfs_attr_open(inode, AT_DATA, NULL, 0);
     if (!attr)
     {
-      ecrit_rapport("Cannot find attribute type 0x%lx.\n", (long) AT_DATA);
+      log_error("Cannot find attribute type 0x%lx.\n", (long) AT_DATA);
       free(buffer);
       return -3;
     }
@@ -419,11 +345,10 @@ static int ntfs_copy(t_param_disk *disk_car, const t_partition *partition, t_dir
     f_out=create_file(new_file);
     if(!f_out)
     {
-      ecrit_rapport("Can't create file %s: %s\n",new_file, strerror(errno));
+      log_critical("Can't create file %s: %s\n",new_file, strerror(errno));
       free(new_file);
       return -4;
     }
-    free(new_file);
     offset = 0;
     for (;;)
     {
@@ -436,7 +361,7 @@ static int ntfs_copy(t_param_disk *disk_car, const t_partition *partition, t_dir
       }
       //ntfs_log_info("read %lld bytes\n", bytes_read);
       if (bytes_read == -1) {
-	ecrit_rapport("ERROR: Couldn't read file");
+	log_error("ERROR: Couldn't read file");
 	break;
       }
       if (!bytes_read)
@@ -445,13 +370,15 @@ static int ntfs_copy(t_param_disk *disk_car, const t_partition *partition, t_dir
       written = fwrite(buffer, 1, bytes_read, f_out);
       if (written != bytes_read)
       {
-	ecrit_rapport("ERROR: Couldn't output all data!");
+	log_error("ERROR: Couldn't output all data!");
 	break;
       }
       offset += bytes_read;
     }
     fclose(f_out);
+    set_date(new_file, file->filestat.st_atime, file->filestat.st_mtime);
     ntfs_attr_close(attr);
+    free(new_file);
     free(buffer);
   }
   /* Finished with the inode; release it. */
@@ -459,11 +386,11 @@ static int ntfs_copy(t_param_disk *disk_car, const t_partition *partition, t_dir
   return 0;
 }
 
-static void dir_partition_ntfs_close(t_dir_data *dir_data)
+static void dir_partition_ntfs_close(dir_data_t *dir_data)
 {
-  const t_partition *partition;
-  t_param_disk *disk_car;
-  struct list_dir_struct *ls=(struct list_dir_struct*)dir_data->private_dir_data;
+  const partition_t *partition;
+  disk_t *disk_car;
+  struct ntfs_dir_struct *ls=(struct ntfs_dir_struct*)dir_data->private_dir_data;
   /* ntfs_umount() will invoke ntfs_device_free() for us. */
   disk_car=ls->my_data->disk_car;
   partition=ls->my_data->partition;
@@ -475,11 +402,11 @@ static void dir_partition_ntfs_close(t_dir_data *dir_data)
 }
 #endif
 
-int dir_partition_ntfs_init(t_param_disk *disk_car, const t_partition *partition, t_dir_data *dir_data, const int debug)
+int dir_partition_ntfs_init(disk_t *disk_car, const partition_t *partition, dir_data_t *dir_data, const int debug)
 {
 #ifdef HAVE_LIBNTFS
   struct ntfs_device *dev;
-  t_my_data *my_data=NULL;
+  my_data_t *my_data=NULL;
   ntfs_volume *vol=NULL;
   if(partition->boot_sector!=0)
     io_redir_add_redir(disk_car,partition->part_offset,DEFAULT_SECTOR_SIZE,partition->part_offset+(uint64_t)partition->boot_sector*disk_car->sector_size,NULL);
@@ -503,7 +430,7 @@ int dir_partition_ntfs_init(t_param_disk *disk_car, const t_partition *partition
       vol = ntfs_volume_startup(dev, MS_RDONLY);
       if(vol)
       {
-	ecrit_rapport("NTFS filesystem need to be repaired.\n");
+	log_warning("NTFS filesystem need to be repaired.\n");
       }
     }
 #endif
@@ -516,10 +443,10 @@ int dir_partition_ntfs_init(t_param_disk *disk_car, const t_partition *partition
     return -1;
   }
   if (vol->flags & VOLUME_IS_DIRTY) {
-    ecrit_rapport("NTFS Volume is dirty.\n");
+    log_warning("NTFS Volume is dirty.\n");
   }
   {
-    struct list_dir_struct *ls=(struct list_dir_struct *)MALLOC(sizeof(*ls));
+    struct ntfs_dir_struct *ls=(struct ntfs_dir_struct *)MALLOC(sizeof(*ls));
     ls->dir_list=NULL;
     ls->current_file=NULL;
     ls->vol=vol;
