@@ -1,7 +1,7 @@
 /*
     File: ntfs_fix.c - Part of the TestDisk project.
   
-    Copyright (C) 1998-2006 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 1998-2007 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,7 +20,8 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
- 
+
+#include <stdio.h>
 #ifdef HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
@@ -40,6 +41,7 @@
 #include "dir.h"
 #include "ntfs_dir.h"
 #include "io_redir.h"
+#include "log.h"
 
 //#define DEBUG_REPAIR_MFT 1
 /*
@@ -47,7 +49,7 @@ dd if=/mnt/data/data_for_testdisk/ntfs.dd skip=127759 count=1 bs=512|hexdump -C
 dd if=/dev/zero of=/mnt/data/data_for_testdisk/ntfs_bad_mft.dd seek=85184 count=1 bs=512 conv=notrunc
 dd if=/dev/zero of=/mnt/data/data_for_testdisk/ntfs_bad_mftmirr.dd seek=127759 count=1 bs=512 conv=notrunc
 */
-int repair_MFT(t_param_disk *disk_car, t_partition *partition, const int debug)
+int repair_MFT(disk_t *disk_car, partition_t *partition, const int debug, char **current_cmd)
 {
   struct ntfs_boot_sector *ntfs_header;
   unsigned char *buffer_mft;
@@ -85,13 +87,13 @@ int repair_MFT(t_param_disk *disk_car, t_partition *partition, const int debug)
     mftmirr_size = cluster_size / mft_record_size;
   mftmirr_size_bytes=mftmirr_size * mft_record_size * ntfs_sector_size(ntfs_header);
 #ifdef DEBUG_REPAIR_MFT
-  ecrit_rapport("mft_pos %lu\n",(unsigned long)(mft_pos/disk_car->sector_size));
-  ecrit_rapport("mftmirr_pos %lu\n",(unsigned long)(mftmirr_pos/disk_car->sector_size));
-  ecrit_rapport("mftmirr_size %u\n", mftmirr_size);
-  ecrit_rapport("cluster_size %u\n", cluster_size);
-  ecrit_rapport("mft_record_size    %u\n", mft_record_size);
-  ecrit_rapport("ntfs_sector_size   %u\n", ntfs_sector_size(ntfs_header));
-  ecrit_rapport("mftmirr_size_bytes %u\n", mftmirr_size_bytes);
+  log_debug("mft_pos %lu\n",(unsigned long)(mft_pos/disk_car->sector_size));
+  log_debug("mftmirr_pos %lu\n",(unsigned long)(mftmirr_pos/disk_car->sector_size));
+  log_debug("mftmirr_size %u\n", mftmirr_size);
+  log_debug("cluster_size %u\n", cluster_size);
+  log_debug("mft_record_size    %u\n", mft_record_size);
+  log_debug("ntfs_sector_size   %u\n", ntfs_sector_size(ntfs_header));
+  log_debug("mftmirr_size_bytes %u\n", mftmirr_size_bytes);
 #endif
   /* Check if MFT mirror is identical to the beginning of MFT */
   buffer_mft=(unsigned char *)MALLOC(mftmirr_size_bytes);
@@ -120,9 +122,9 @@ int repair_MFT(t_param_disk *disk_car, t_partition *partition, const int debug)
     return 0;
   }
 /*
-  ecrit_rapport("MFT\n");
+  log_debug("MFT\n");
   dump_log(buffer_mft, mftmirr_size_bytes);
-  ecrit_rapport("MFT mirror\n");
+  log_debug("MFT mirror\n");
   dump_log(buffer_mftmirr, mftmirr_size_bytes);
   */
   /*
@@ -133,7 +135,7 @@ int repair_MFT(t_param_disk *disk_car, t_partition *partition, const int debug)
   */
   {
     int res1,res2;
-    t_dir_data dir_data;
+    dir_data_t dir_data;
     /* Use MFT */
     io_redir_add_redir(disk_car, mftmirr_pos, mftmirr_size_bytes, 0, buffer_mft);
     res1=dir_partition_ntfs_init(disk_car,partition,&dir_data,debug);
@@ -148,11 +150,11 @@ int repair_MFT(t_param_disk *disk_car, t_partition *partition, const int debug)
     }
     if(res1==0)
     {
-      t_file_data *dir_list;
+      file_data_t *dir_list;
       dir_list=dir_data.get_dir(disk_car,partition,&dir_data,dir_data.current_inode);
       if(dir_list!=NULL)
       {
-	ecrit_rapport("NTFS listing using MFT:\n");
+	log_info("NTFS listing using MFT:\n");
 	dir_aff_log(disk_car, partition, &dir_data, dir_list);
 	delete_list_file(dir_list);
 	res1++;
@@ -165,11 +167,11 @@ int repair_MFT(t_param_disk *disk_car, t_partition *partition, const int debug)
     res2=dir_partition_ntfs_init(disk_car,partition,&dir_data,debug);
     if(res2==0)
     {
-      t_file_data *dir_list;
+      file_data_t *dir_list;
       dir_list=dir_data.get_dir(disk_car,partition,&dir_data,dir_data.current_inode);
       if(dir_list!=NULL)
       {
-	ecrit_rapport("NTFS listing using MFT mirror:\n");
+	log_info("NTFS listing using MFT mirror:\n");
 	dir_aff_log(disk_car, partition, &dir_data, dir_list);
 	delete_list_file(dir_list);
 	res2++;
@@ -190,7 +192,7 @@ int repair_MFT(t_param_disk *disk_car, t_partition *partition, const int debug)
       }
       else
       {
-	ecrit_rapport("Don't fix MFT mirror.\n");
+	log_info("Don't fix MFT mirror.\n");
       }
     }
     else if(res1<res2)
@@ -205,7 +207,7 @@ int repair_MFT(t_param_disk *disk_car, t_partition *partition, const int debug)
       }
       else
       {
-	ecrit_rapport("Don't fix MFT.\n");
+	log_info("Don't fix MFT.\n");
       }
     }
     else if(res1<0)
