@@ -2,7 +2,7 @@
 
     File: parti386.c
 
-    Copyright (C) 1998-2006 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 1998-2007 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -38,6 +38,7 @@
 #include "fnctdsk.h"
 #include "lang.h"
 #include "intrf.h"
+#include "intrfn.h"
 #include "chgtype.h"
 #include "savehdr.h"
 #include "bfs.h"
@@ -58,10 +59,11 @@
 #include "swap.h"
 #include "ufs.h"
 #include "xfs.h"
+#include "log.h"
 
 static int is_extended(const unsigned int part_type);
-static int can_be_ext(const t_param_disk *disk_car, t_partition *partition);
-static int test_structure_i386(t_list_part *list_part);
+static int can_be_ext(const disk_t *disk_car, const partition_t *partition);
+static int test_structure_i386(list_part_t *list_part);
 #define pt_offset_const(b, n) ((const struct partition_dos *)((b) + 0x1be + \
       (n) * sizeof(struct partition_dos)))
 #define pt_offset(b, n) ((struct partition_dos *)((b) + 0x1be + \
@@ -89,35 +91,35 @@ struct partition_dos {
 #define e_sect(p) ((p)->end_sector & (unsigned)0x3f)
 static uint64_t get_start_sect(const struct partition_dos *p);
 static uint64_t get_nr_sects(const struct partition_dos *p);
-static void aff_entry_rapport(const t_param_disk *disk_car, const struct partition_dos*);
-static int get_geometry_from_i386mbr(const unsigned char *buffer, const int debug, t_CHS *geometry);
-static t_list_part *get_ext_data_i386(t_param_disk *disk_car, t_list_part *list_part, const int debug, const int saveheader);
-static void test_MBR_data(t_list_part *list_part);
-static int test_MBR_over(t_param_disk *disk_car,t_list_part *list_part);
-static int write_mbr_i386(t_param_disk *disk_car, const t_list_part *list_part, const int ro, const int debug);
-static int write_all_log_i386(t_param_disk *disk_car, const t_list_part *list_part, const int ro , const int debug, const int align);
-static int diff(const t_param_disk *disk_car,const unsigned char buffer[DEFAULT_SECTOR_SIZE], const unsigned char buffer_org[DEFAULT_SECTOR_SIZE]);
+static void log_dos_entry(const disk_t *disk_car, const struct partition_dos*);
+static int get_geometry_from_i386mbr(const unsigned char *buffer, const int debug, CHS_t *geometry);
+static list_part_t *get_ext_data_i386(disk_t *disk_car, list_part_t *list_part, const int debug, const int saveheader);
+static void test_MBR_data(list_part_t *list_part);
+static int test_MBR_over(disk_t *disk_car,list_part_t *list_part);
+static int write_mbr_i386(disk_t *disk_car, const list_part_t *list_part, const int ro, const int debug);
+static int write_all_log_i386(disk_t *disk_car, const list_part_t *list_part, const int ro , const int debug, const int align);
+static int diff(const disk_t *disk_car,const unsigned char buffer[DEFAULT_SECTOR_SIZE], const unsigned char buffer_org[DEFAULT_SECTOR_SIZE]);
 
-static t_list_part *read_part_i386(t_param_disk *disk_car, const int debug, const int saveheader);
-static int write_part_i386(t_param_disk *disk_car, const t_list_part *list_part, const int ro , const int debug, const int align);
-static t_list_part *init_part_order_i386(const t_param_disk *disk_car, t_list_part *list_part);
-static int write_MBR_code_i386(t_param_disk *disk_car);
+static list_part_t *read_part_i386(disk_t *disk_car, const int debug, const int saveheader);
+static int write_part_i386(disk_t *disk_car, const list_part_t *list_part, const int ro , const int debug, const int align);
+static list_part_t *init_part_order_i386(const disk_t *disk_car, list_part_t *list_part);
+static int write_MBR_code_i386(disk_t *disk_car);
 static int write_MBR_code_i386_aux(unsigned char *buffer);
-static t_list_part *add_partition_i386(t_param_disk *disk_car,t_list_part *list_part, const int debug, char **current_cmd);
-static void set_prev_status_i386(const t_param_disk *disk_car, t_partition *partition);
-static void set_next_status_i386(const t_param_disk *disk_car, t_partition *partition);
-static int set_part_type_i386(t_partition *partition, unsigned int part_type);
-static int is_part_known_i386(const t_partition *partition);
-static void init_structure_i386(const t_param_disk *disk_car,t_list_part *list_part, const int debug);
-static int erase_list_part_i386(t_param_disk *disk_car);
-static int check_part_i386(t_param_disk *disk_car, const int debug,t_partition *partition,const int saveheader);
+static list_part_t *add_partition_i386(disk_t *disk_car,list_part_t *list_part, const int debug, char **current_cmd);
+static void set_prev_status_i386(const disk_t *disk_car, partition_t *partition);
+static void set_next_status_i386(const disk_t *disk_car, partition_t *partition);
+static int set_part_type_i386(partition_t *partition, unsigned int part_type);
+static int is_part_known_i386(const partition_t *partition);
+static void init_structure_i386(const disk_t *disk_car,list_part_t *list_part, const int debug);
+static int erase_list_part_i386(disk_t *disk_car);
+static int check_part_i386(disk_t *disk_car, const int debug,partition_t *partition,const int saveheader);
 
-static void partition2_i386_entry(const t_param_disk *disk_car,const uint64_t pos,const t_partition *partition, struct partition_dos *p);
-static int i386_entry2partition(t_param_disk *disk_car, const uint64_t offset, t_partition *partition, const struct partition_dos *p, const status_type_t status,const unsigned int order,const int debug, const int saveheader);
+static void partition2_i386_entry(const disk_t *disk_car,const uint64_t pos,const partition_t *partition, struct partition_dos *p);
+static int i386_entry2partition(disk_t *disk_car, const uint64_t offset, partition_t *partition, const struct partition_dos *p, const status_type_t status,const unsigned int order,const int debug, const int saveheader);
 static const char* errmsg_i386_entry2partition(const errcode_type_t errcode);
-static const char *get_partition_name_i386(const t_partition *partition);
+static const char *get_partition_name_i386(const partition_t *partition);
 static const char *get_partition_name_i386_aux(const unsigned int part_type_i386);
-static unsigned int get_part_type_i386(const t_partition *partition);
+static unsigned int get_part_type_i386(const partition_t *partition);
 
 static const struct systypes i386_sys_types[] = {
   {P_NO_OS,		"empty"},
@@ -213,7 +215,7 @@ static const struct systypes i386_sys_types[] = {
   {P_NO_OS,		NULL }
 };
 
-t_arch_fnct arch_i386= {
+arch_fnct_t arch_i386= {
   .part_name="Intel",
   .part_name_option="partition_i386",
   .msg_part_type="*=Primary bootable  P=Primary  L=Logical  E=Extended  D=Deleted",
@@ -235,7 +237,7 @@ t_arch_fnct arch_i386= {
   .get_part_type=get_part_type_i386
 };
 
-static unsigned int get_part_type_i386(const t_partition *partition)
+static unsigned int get_part_type_i386(const partition_t *partition)
 {
   return partition->part_type_i386;
 }
@@ -274,15 +276,12 @@ static void set_start_sect(struct partition_dos *p, unsigned int start_sect)
 }
 
 
-int get_geometry_from_i386mbr(const unsigned char *buffer, const int debug, t_CHS *geometry)
+int get_geometry_from_i386mbr(const unsigned char *buffer, const int debug, CHS_t *geometry)
 {
   unsigned int i;
-  geometry->cylinder=0;
-  geometry->head=0;
-  geometry->sector=0;
   if(debug>1)
   {
-    ecrit_rapport("get_geometry_from_i386mbr\n");
+    log_trace("get_geometry_from_i386mbr\n");
   }
   if((buffer[0x1FE]!=(unsigned char)0x55)||(buffer[0x1FF]!=(unsigned char)0xAA))
   {
@@ -301,18 +300,25 @@ int get_geometry_from_i386mbr(const unsigned char *buffer, const int debug, t_CH
 	geometry->sector=e_sect(p);
     }
   }
-  if(geometry->sector>0)
+  if(geometry->sector==32 ||
+      (geometry->sector==63 && (geometry->head==16-1 || geometry->head==32-1 || geometry->head==64-1 || geometry->head==128-1 || geometry->head==240-1 || geometry->head==255-1)))
+    log_info("Geometry from i386 MBR: head=%u sector=%u\n",geometry->head+1,geometry->sector);
+  else
   {
-    ecrit_rapport("Geometry from i386 MBR: head=%u sector=%u\n",geometry->head+1,geometry->sector);
+    if(geometry->sector>0)
+      log_warning("Geometry from i386 MBR: head=%u sector=%u\n",geometry->head+1,geometry->sector);
+    geometry->cylinder=0;
+    geometry->head=0;
+    geometry->sector=0;
   }
   return 0;
 }
 
-static t_list_part *init_part_order_i386(const t_param_disk *disk_car, t_list_part *list_part)
+static list_part_t *init_part_order_i386(const disk_t *disk_car, list_part_t *list_part)
 {
   int nbr_log=0;
   int nbr_prim=0;
-  t_list_part *element;
+  list_part_t *element;
   for(element=list_part;element!=NULL;element=element->next)
   {
     switch(element->part->status)
@@ -326,7 +332,7 @@ static t_list_part *init_part_order_i386(const t_param_disk *disk_car, t_list_pa
 	element->part->order=(++nbr_log)+4;
 	break;
       default:
-	ecrit_rapport("init_part_order_i386: severe error\n");
+	log_critical("init_part_order_i386: severe error\n");
 	break;
     }
   }
@@ -334,20 +340,23 @@ static t_list_part *init_part_order_i386(const t_param_disk *disk_car, t_list_pa
 }
 
 
-static t_list_part *read_part_i386(t_param_disk *disk_car, const int debug, const int saveheader)
+static list_part_t *read_part_i386(disk_t *disk_car, const int debug, const int saveheader)
 {
   unsigned int i;
   int res=0;
-  t_CHS geometry;
-  t_list_part *new_list_part=NULL;
+  CHS_t geometry;
+  list_part_t *new_list_part=NULL;
   unsigned char *buffer=MALLOC(disk_car->sector_size);
   aff_buffer(BUFFER_RESET,"Q");
   if(disk_car->read(disk_car,disk_car->sector_size, buffer, (uint64_t)0))
   {
-    wdoprintf(stdscr,msg_PART_RD_ERR);
+    aff_buffer(BUFFER_ADD, msg_PART_RD_ERR);
     free(buffer);
     return NULL;
   }
+  geometry.cylinder=0;
+  geometry.head=0;
+  geometry.sector=0;
   if(get_geometry_from_i386mbr(buffer,debug,&geometry)!=0)
   {
     aff_buffer(BUFFER_ADD,msg_TBL_NMARK);
@@ -369,10 +378,10 @@ static t_list_part *read_part_i386(t_param_disk *disk_car, const int debug, cons
 	/* don't put a break */
       default:
 	{
-	  t_partition *new_partition=partition_new();
+	  partition_t *new_partition=partition_new();
 	  i386_entry2partition(disk_car, (uint64_t)0, new_partition, p, status,i+1,debug,saveheader);
 	  if(debug>1)
-	    aff_entry_rapport(disk_car,p);
+	    log_dos_entry(disk_car,p);
 	  aff_part_buffer(AFF_PART_ORDER,disk_car,new_partition);
 	  if(new_partition->errcode!=BAD_NOERR)
 	  {
@@ -387,21 +396,22 @@ static t_list_part *read_part_i386(t_param_disk *disk_car, const int debug, cons
 /*  if(res==0) */
   {
     test_MBR_data(new_list_part);
-    if(test_MBR_over(disk_car,new_list_part)==0)
-      new_list_part=get_ext_data_i386(disk_car,new_list_part,debug,saveheader);
+//    if(test_MBR_over(disk_car,new_list_part)==0)
+    test_MBR_over(disk_car,new_list_part);
+    new_list_part=get_ext_data_i386(disk_car,new_list_part,debug,saveheader);
   }
   get_geometry_from_list_part(disk_car, new_list_part, debug);
   free(buffer);
   return new_list_part;
 }
 
-static void test_MBR_data(t_list_part *list_part)
+static void test_MBR_data(list_part_t *list_part)
 {
-  t_list_part *element;
+  list_part_t *element;
   unsigned int nb_dos=0, nb_hidden=0, nb_mb=0, nb_ext=0, nb_boot=0;
   for(element=list_part;element!=NULL;element=element->next)
   {
-    const t_partition *partition=element->part;
+    const partition_t *partition=element->part;
     switch(partition->status)
     {
       case STATUS_PRIM_BOOT:
@@ -428,7 +438,7 @@ static void test_MBR_data(t_list_part *list_part)
 	nb_ext++;
 	break;
       default:
-	ecrit_rapport("test_MBR_data: severe error\n");
+	log_critical("test_MBR_data: severe error\n");
 	break;
     }
   }
@@ -449,11 +459,11 @@ static void test_MBR_data(t_list_part *list_part)
       aff_buffer(BUFFER_ADD,msg_ONLY1MUSTBOOT);
 }
 
-static t_list_part *get_ext_data_i386(t_param_disk *disk_car, t_list_part *list_part, const int debug, const int saveheader)
+static list_part_t *get_ext_data_i386(disk_t *disk_car, list_part_t *list_part, const int debug, const int saveheader)
 {
-  t_list_part *element;
+  list_part_t *element;
   int res=0;
-  t_partition *partition_main_ext=NULL;
+  partition_t *partition_main_ext=NULL;
   for(element=list_part;element!=NULL;element=element->next)
   {
     if(element->part->status==STATUS_EXT)
@@ -461,8 +471,8 @@ static t_list_part *get_ext_data_i386(t_param_disk *disk_car, t_list_part *list_
   }
   if(partition_main_ext!=NULL)
   {
-    t_partition *partition_ext=partition_main_ext;
-    t_partition *partition_next_ext=NULL;
+    partition_t *partition_ext=partition_main_ext;
+    partition_t *partition_next_ext=NULL;
     unsigned int i;
     unsigned int order=5;
     do
@@ -518,10 +528,10 @@ static t_list_part *get_ext_data_i386(t_param_disk *disk_car, t_list_part *list_
 	const struct partition_dos *p=pt_offset(buffer,i);
 	if(p->sys_ind!=0)
 	{
-	  t_partition *new_partition=partition_new();
+	  partition_t *new_partition=partition_new();
 	  new_partition->order=order;
 	  if(debug>1)
-	    aff_entry_rapport(disk_car,p);
+	    log_dos_entry(disk_car,p);
 	  if(is_extended(p->sys_ind))
 	  {
 	    partition_next_ext=new_partition;
@@ -545,7 +555,7 @@ static t_list_part *get_ext_data_i386(t_param_disk *disk_car, t_list_part *list_
 	      {
 		for(element=list_part;element!=NULL;element=element->next)
 		{
-		  t_partition *partition=element->part;
+		  partition_t *partition=element->part;
 		  if(partition->status==STATUS_EXT_IN_EXT)
 		  {
 		    if(((partition->part_offset>=new_partition->part_offset) && (partition->part_offset<=new_partition->part_offset+new_partition->part_size-1)) ||
@@ -566,7 +576,7 @@ static t_list_part *get_ext_data_i386(t_param_disk *disk_car, t_list_part *list_
 	    i386_entry2partition(disk_car,partition_ext->part_offset, new_partition, p, STATUS_LOG,order,debug,saveheader);
 	    order++;
 	    if(debug>1)
-	      aff_entry_rapport(disk_car,p);
+	      log_dos_entry(disk_car,p);
 	    aff_part_buffer(AFF_PART_ORDER,disk_car,new_partition);
 	    if(new_partition->errcode!=BAD_NOERR)
 	    {
@@ -593,10 +603,10 @@ static t_list_part *get_ext_data_i386(t_param_disk *disk_car, t_list_part *list_
   return list_part;
 }
 
-static int test_MBR_over(t_param_disk *disk_car,t_list_part *list_part)
+static int test_MBR_over(disk_t *disk_car,list_part_t *list_part)
 {/* Tester le overlapping des partitions */
   int res=0;
-  t_list_part *element;
+  list_part_t *element;
   for(element=list_part;element!=NULL;element=element->next)
     if((element->next!=NULL) && (element->part->part_offset + element->part->part_size - 1 >= element->next->part->part_offset))
     {
@@ -608,7 +618,7 @@ static int test_MBR_over(t_param_disk *disk_car,t_list_part *list_part)
   return res;
 }
 
-int write_part_i386(t_param_disk *disk_car, const t_list_part *list_part, const int ro, const int debug, const int align)
+int write_part_i386(disk_t *disk_car, const list_part_t *list_part, const int ro, const int debug, const int align)
 {
   int res=0;
   res+=write_mbr_i386(disk_car,list_part,ro,debug);
@@ -616,14 +626,14 @@ int write_part_i386(t_param_disk *disk_car, const t_list_part *list_part, const
   return res;
 }
 
-static int write_mbr_i386(t_param_disk *disk_car, const t_list_part *list_part, const int ro, const int debug)
+static int write_mbr_i386(disk_t *disk_car, const list_part_t *list_part, const int ro, const int debug)
 {
-  const t_list_part *element;
+  const list_part_t *element;
   unsigned char *buffer=MALLOC(disk_car->sector_size);
   unsigned char *buffer_org=MALLOC(disk_car->sector_size);
   if(debug>0)
   {
-    ecrit_rapport("\nwrite_mbr_i386: starting...\n");
+    log_trace("\nwrite_mbr_i386: starting...\n");
   }
   if(disk_car->read(disk_car,DEFAULT_SECTOR_SIZE, buffer_org, (uint64_t)0))
   {
@@ -638,7 +648,7 @@ static int write_mbr_i386(t_param_disk *disk_car, const t_list_part *list_part,
     buffer[0x1FF]=0xAA;
   } else {
     if(debug>0)
-      ecrit_rapport("Store new MBR code\n");
+      log_info("Store new MBR code\n");
     write_MBR_code_i386_aux(buffer);
   }
   for(element=list_part;element!=NULL;element=element->next)
@@ -657,7 +667,7 @@ static int write_mbr_i386(t_param_disk *disk_car, const t_list_part *list_part,
       case STATUS_LOG:
 	break;
       default:
-	ecrit_rapport("write_mbr_i386: severe error\n");
+	log_critical("write_mbr_i386: severe error\n");
 	break;
     }
   }
@@ -667,7 +677,7 @@ static int write_mbr_i386(t_param_disk *disk_car, const t_list_part *list_part,
     for(i=0;i<4;i++)
     {
       const struct partition_dos *p=pt_offset(buffer,i);
-      aff_entry_rapport(disk_car,p);
+      log_dos_entry(disk_car,p);
     }
     diff(disk_car,buffer,buffer_org);
   }
@@ -685,15 +695,15 @@ static int write_mbr_i386(t_param_disk *disk_car, const t_list_part *list_part,
   return 0;
 }
 
-static int write_all_log_i386(t_param_disk *disk_car, const t_list_part *list_part, const int ro, const int debug, const int align)
+static int write_all_log_i386(disk_t *disk_car, const list_part_t *list_part, const int ro, const int debug, const int align)
 {
-  const t_list_part *element;
-  const t_list_part *pos_ext=NULL;
+  const list_part_t *element;
+  const list_part_t *pos_ext=NULL;
   uint64_t current_pos;
-  t_partition *bloc_nextext;
+  partition_t *bloc_nextext;
   int res=0;
   if(debug>0)
-    ecrit_rapport("write_all_log_i386: starting...\n");
+    log_trace("write_all_log_i386: starting...\n");
   for(element=list_part;element!=NULL;element=element->next)
   {
     if(element->part->status==STATUS_EXT)
@@ -701,22 +711,22 @@ static int write_all_log_i386(t_param_disk *disk_car, const t_list_part *list_pa
       if(is_extended(element->part->part_type_i386))
       {
 	if(pos_ext!=NULL)
-	  ecrit_rapport("write_all_log_i386: pos_ext already defined\n");
+	  log_critical("write_all_log_i386: pos_ext already defined\n");
 	pos_ext=element;
       }
       else
       {
-	ecrit_rapport("write_all_log_i386: STATUS_EXT with bad part_type\n");
+	log_critical("write_all_log_i386: STATUS_EXT with bad part_type\n");
       }
     }
   }
   if(pos_ext==NULL)
   {
-    ecrit_rapport(msg_NO_EXT_PART);
+    log_info(msg_NO_EXT_PART);
     return 0;
   }
   current_pos=pos_ext->part->part_offset;
-  bloc_nextext=(t_partition *)MALLOC(sizeof(*bloc_nextext));
+  bloc_nextext=(partition_t *)MALLOC(sizeof(*bloc_nextext));
   bloc_nextext->part_type_i386=P_EXTENDED;       /* Never P_EXTENDX */
   if(pos_ext->next==NULL || (pos_ext->next->part->status!=STATUS_LOG))
   {
@@ -724,7 +734,7 @@ static int write_all_log_i386(t_param_disk *disk_car, const t_list_part *list_pa
     unsigned char buffer_org[DEFAULT_SECTOR_SIZE];
     if(debug>0)
     {
-      ecrit_rapport("write_all_log_i386: CHS: %u/%u/%u,lba=%lu\n", offset2cylinder(disk_car,current_pos), offset2head(disk_car,current_pos), offset2sector(disk_car,current_pos),(long unsigned)(current_pos/disk_car->sector_size));
+      log_info("write_all_log_i386: CHS: %u/%u/%u,lba=%lu\n", offset2cylinder(disk_car,current_pos), offset2head(disk_car,current_pos), offset2sector(disk_car,current_pos),(long unsigned)(current_pos/disk_car->sector_size));
     }
     if(disk_car->read(disk_car,sizeof(buffer_org), &buffer_org, current_pos))
     {
@@ -756,7 +766,7 @@ static int write_all_log_i386(t_param_disk *disk_car, const t_list_part *list_pa
       unsigned char buffer_org[DEFAULT_SECTOR_SIZE];
       if(debug>0)
       {
-	ecrit_rapport("write_all_log_i386: CHS: %u/%u/%u,lba=%lu\n", offset2cylinder(disk_car,current_pos), offset2head(disk_car,current_pos), offset2sector(disk_car,current_pos),(long unsigned)(current_pos/disk_car->sector_size));
+	log_info("write_all_log_i386: CHS: %u/%u/%u,lba=%lu\n", offset2cylinder(disk_car,current_pos), offset2head(disk_car,current_pos), offset2sector(disk_car,current_pos),(long unsigned)(current_pos/disk_car->sector_size));
       }
       if(disk_car->read(disk_car,sizeof(buffer_org), &buffer_org, current_pos))
       {
@@ -769,7 +779,7 @@ static int write_all_log_i386(t_param_disk *disk_car, const t_list_part *list_pa
       partition2_i386_entry(disk_car,current_pos,element->part, pt_offset(buffer,0));
       if(element->next!=NULL && (element->next->part->status==STATUS_LOG))
       { /* Construit le pointeur vers la prochaine partition logique */
-	t_CHS nextext_start;
+	CHS_t nextext_start;
 	bloc_nextext->part_offset=element->next->part->part_offset-disk_car->sector_size;
 	offset2CHS(disk_car,bloc_nextext->part_offset,&nextext_start);
 	if(nextext_start.sector!=disk_car->CHS.sector)
@@ -784,7 +794,7 @@ static int write_all_log_i386(t_param_disk *disk_car, const t_list_part *list_pa
 	}
 	nextext_start.sector=1;
 	if(debug>1)
-	  ecrit_rapport("nextext_start %u/%u/%u %lu ? %lu\n", nextext_start.cylinder,nextext_start.head,nextext_start.sector,
+	  log_debug("nextext_start %u/%u/%u %lu ? %lu\n", nextext_start.cylinder,nextext_start.head,nextext_start.sector,
 	    (long unsigned)(CHS2offset(disk_car,&nextext_start)/disk_car->sector_size),
 	    (long unsigned)((element->part->part_offset+element->part->part_size-1)/disk_car->sector_size));
 	if(CHS2offset(disk_car,&nextext_start)<=element->part->part_offset+element->part->part_size-1)
@@ -792,7 +802,7 @@ static int write_all_log_i386(t_param_disk *disk_car, const t_list_part *list_pa
 	  offset2CHS(disk_car,bloc_nextext->part_offset,&nextext_start);
 	  nextext_start.sector=1;
 	  if(debug>1)
-	    ecrit_rapport("nextext_start %u/%u/%u %lu ? %lu\n", nextext_start.cylinder,nextext_start.head,nextext_start.sector,
+	    log_debug("nextext_start %u/%u/%u %lu ? %lu\n", nextext_start.cylinder,nextext_start.head,nextext_start.sector,
 	    (long unsigned)(CHS2offset(disk_car,&nextext_start)/disk_car->sector_size),
 	    (long unsigned)((element->part->part_offset+element->part->part_size-1)/disk_car->sector_size));
 	  if(CHS2offset(disk_car,&nextext_start)<=element->part->part_offset+element->part->part_size-1)
@@ -801,11 +811,11 @@ static int write_all_log_i386(t_param_disk *disk_car, const t_list_part *list_pa
 	  }
 	}
 	if(debug>1)
-	  ecrit_rapport("nextext_start %u/%u/%u %lu ? %lu\n", nextext_start.cylinder,nextext_start.head,nextext_start.sector,
+	  log_debug("nextext_start %u/%u/%u %lu ? %lu\n", nextext_start.cylinder,nextext_start.head,nextext_start.sector,
 	    (long unsigned)(CHS2offset(disk_car,&nextext_start)/disk_car->sector_size),
 	    (long unsigned)((element->part->part_offset+element->part->part_size-1)/disk_car->sector_size));
 	bloc_nextext->part_offset=CHS2offset(disk_car,&nextext_start);
-	/*      ecrit_rapport("table[i]->next=%p table[i+1]=%p\n",table[i]->next,table[i+1]); */
+	/*      log_debug("table[i]->next=%p table[i+1]=%p\n",table[i]->next,table[i+1]); */
 	bloc_nextext->part_size=(uint64_t)element->next->part->part_offset+element->next->part->part_size-bloc_nextext->part_offset;
 	partition2_i386_entry(disk_car,pos_ext->part->part_offset,bloc_nextext, pt_offset(buffer,1));
       }
@@ -817,7 +827,7 @@ static int write_all_log_i386(t_param_disk *disk_car, const t_list_part *list_pa
 	  {
 	    const struct partition_dos *p=pt_offset(buffer,j);
 	    if(p->sys_ind!=0)
-	      aff_entry_rapport(disk_car,p);
+	      log_dos_entry(disk_car,p);
 	  }
 	  diff(disk_car,buffer,buffer_org);
 	}
@@ -836,35 +846,35 @@ static int write_all_log_i386(t_param_disk *disk_car, const t_list_part *list_pa
   return res;
 }
 
-static int diff(const t_param_disk *disk_car, const unsigned char buffer[DEFAULT_SECTOR_SIZE], const unsigned char buffer_org[DEFAULT_SECTOR_SIZE])
+static int diff(const disk_t *disk_car, const unsigned char buffer[DEFAULT_SECTOR_SIZE], const unsigned char buffer_org[DEFAULT_SECTOR_SIZE])
 {
   int j;
   if(memcmp(buffer,buffer_org,DEFAULT_SECTOR_SIZE))
   {
-    ecrit_rapport("\nSectors are different.\n");
-    ecrit_rapport("buffer_org\n");
+    log_info("\nSectors are different.\n");
+    log_info("buffer_org\n");
     for(j=0;j<4;j++)
     {
       const struct partition_dos *p=pt_offset_const(buffer_org,j);
       if(p->sys_ind!=0)
-	aff_entry_rapport(disk_car,p);
+	log_dos_entry(disk_car,p);
     }
-    ecrit_rapport("buffer\n");
+    log_info("buffer\n");
     for(j=0;j<4;j++)
     {
       const struct partition_dos *p=pt_offset_const(buffer,j);
       if(p->sys_ind!=0)
-	aff_entry_rapport(disk_car,p);
+	log_dos_entry(disk_car,p);
     }
     for(j=0;j<DEFAULT_SECTOR_SIZE;j++)
       if(buffer_org[j]!=buffer[j])
-	ecrit_rapport("%02X %02X %02X\n", j, buffer_org[j], buffer[j]);
-    ecrit_rapport("\n");
+	log_info("%02X %02X %02X\n", j, buffer_org[j], buffer[j]);
+    log_info("\n");
   }
   return 0;
 }
 
-static int write_MBR_code_i386(t_param_disk *disk_car)
+static int write_MBR_code_i386(disk_t *disk_car)
 {
   unsigned char buffer[DEFAULT_SECTOR_SIZE];
   if(disk_car->read(disk_car,DEFAULT_SECTOR_SIZE, buffer, (uint64_t)0))
@@ -924,9 +934,9 @@ static int write_MBR_code_i386_aux(unsigned char *buffer)
   return 0;
 }
 
-static void partition2_i386_entry(const t_param_disk *disk_car, const uint64_t pos, const t_partition *partition, struct partition_dos *p)
+static void partition2_i386_entry(const disk_t *disk_car, const uint64_t pos, const partition_t *partition, struct partition_dos *p)
 {
-  t_CHS start,end;
+  CHS_t start,end;
   offset2CHS(disk_car,partition->part_offset,&start);
   offset2CHS(disk_car,partition->part_offset+partition->part_size-disk_car->sector_size,&end);
   if(partition->status==STATUS_PRIM_BOOT)
@@ -963,10 +973,10 @@ static void partition2_i386_entry(const t_param_disk *disk_car, const uint64_t p
   set_nr_sects(p,partition->part_size/disk_car->sector_size);
 }
 
-static int i386_entry2partition(t_param_disk *disk_car, const uint64_t offset, t_partition *partition, const struct partition_dos *p, const status_type_t status,const unsigned int order,const int debug, const int saveheader)
+static int i386_entry2partition(disk_t *disk_car, const uint64_t offset, partition_t *partition, const struct partition_dos *p, const status_type_t status,const unsigned int order,const int debug, const int saveheader)
 {
-  t_CHS start,end;
-  t_CHS start_calculated,end_calculated;
+  CHS_t start,end;
+  CHS_t start_calculated,end_calculated;
   partition_reset(partition);
   partition->part_type_i386=p->sys_ind;
   partition->part_offset=offset+(uint64_t)get_start_sect(p)*disk_car->sector_size;
@@ -1035,7 +1045,7 @@ static int i386_entry2partition(t_param_disk *disk_car, const uint64_t offset, t
   if(((start_calculated.cylinder<=1023)&& (C_H_S2offset(disk_car,start.cylinder,start.head,start.sector)!=partition->part_offset))
     || ((start_calculated.cylinder>1023)&&(start.cylinder!=1023)&&(start.cylinder!=(start_calculated.cylinder&1023))))
   {
-    ecrit_rapport("BAD_RS LBA=%lu %lu\n",(long unsigned)(partition->part_offset/disk_car->sector_size),C_H_S2LBA(disk_car,start.cylinder,start.head,start.sector));
+    log_error("BAD_RS LBA=%lu %lu\n",(long unsigned)(partition->part_offset/disk_car->sector_size),C_H_S2LBA(disk_car,start.cylinder,start.head,start.sector));
     if(partition->errcode==BAD_NOERR)
       partition->errcode=BAD_RS;
   }
@@ -1065,17 +1075,17 @@ static const char* errmsg_i386_entry2partition(const errcode_type_t errcode)
     case BAD_SCOUNT: return msg_BAD_SCOUNT;
     case BAD_NOERR: return "";
   }
-  ecrit_rapport("errmsg_i386_entry2partition: unhandled error\n");
+  log_critical("errmsg_i386_entry2partition: unhandled error\n");
   return "";
 }
 
-static void aff_entry_rapport(const t_param_disk *disk_car, const struct partition_dos *entree)
+static void log_dos_entry(const disk_t *disk_car, const struct partition_dos *entree)
 {
   if(get_partition_name_i386_aux(entree->sys_ind)!=NULL)
-    ecrit_rapport(" %-20s ", get_partition_name_i386_aux(entree->sys_ind));
+    log_info(" %-20s ", get_partition_name_i386_aux(entree->sys_ind));
   else
-    ecrit_rapport(" Sys=%02X               ", entree->sys_ind);
-  ecrit_rapport("%4u %3u %2u"
+    log_info(" Sys=%02X               ", entree->sys_ind);
+  log_info("%4u %3u %2u"
 	 " %4u %3u %2u"
 	 " %10lu"
 	 " %10lu\n",
@@ -1084,7 +1094,7 @@ static void aff_entry_rapport(const t_param_disk *disk_car, const struct partiti
 	  (long unsigned)get_start_sect(entree),(long unsigned)get_nr_sects(entree));
 }
 
-static int can_be_ext(const t_param_disk *disk_car, t_partition *partition)
+static int can_be_ext(const disk_t *disk_car, const partition_t *partition)
 {
   return((offset2head(disk_car,partition->part_offset)>0)&&
       (offset2cylinder(disk_car,partition->part_offset)!=0 ||
@@ -1092,13 +1102,13 @@ static int can_be_ext(const t_param_disk *disk_car, t_partition *partition)
        offset2sector(disk_car,partition->part_offset)!=1));
 }
 
-static int test_structure_i386(t_list_part *list_part)
+static int test_structure_i386(list_part_t *list_part)
 { /* Return 1 if bad*/
   int nbr_prim=0, nbr_prim_boot=0, nbr_log_block=0;
-  t_list_part *first_log=NULL;
-  t_list_part *new_list_part=NULL;
-  t_list_part *element;
-  t_list_part *new_element;
+  list_part_t *first_log=NULL;
+  list_part_t *new_list_part=NULL;
+  list_part_t *element;
+  list_part_t *new_element;
   int res=0;
   for(element=list_part;element!=NULL;element=element->next)
   {
@@ -1125,7 +1135,7 @@ static int test_structure_i386(t_list_part *list_part)
       case STATUS_DELETED:
 	break;
       default:
-	ecrit_rapport("test_structure_i386: severe error\n");
+	log_critical("test_structure_i386: severe error\n");
 	break;
     }
   }
@@ -1169,10 +1179,10 @@ static int is_extended(const unsigned int part_type)
   return (part_type==(const unsigned char)P_EXTENDX || part_type==(const unsigned char)P_EXTENDED || part_type==(const unsigned char)P_LINUXEXTENDX);
 }
 
-static t_list_part *add_partition_i386(t_param_disk *disk_car,t_list_part *list_part, const int debug, char **current_cmd)
+static list_part_t *add_partition_i386(disk_t *disk_car,list_part_t *list_part, const int debug, char **current_cmd)
 {
-  t_CHS start,end;
-  t_partition *new_partition=partition_new();
+  CHS_t start,end;
+  partition_t *new_partition=partition_new();
   int position=0;
   start.cylinder=0;
   start.head=0;
@@ -1256,9 +1266,9 @@ static t_list_part *add_partition_i386(t_param_disk *disk_car,t_list_part *list_
   }
   if((CHS2offset(disk_car,&end)>new_partition->part_offset)&&(new_partition->part_offset>0)&& new_partition->part_type_i386!=P_NO_OS)
   {
-    t_list_part *new_list_part=insert_new_partition(list_part, new_partition);
+    list_part_t *new_list_part=insert_new_partition(list_part, new_partition);
     if(test_structure_i386(list_part)==0)
-    { /* Determine if the partition can be Logical, Bootable or Primary */
+    { /* Check if the partition can be Logical, Bootable or Primary */
       if(can_be_ext(disk_car,new_partition)!=0)
       {
 	new_partition->status=STATUS_LOG;
@@ -1279,7 +1289,7 @@ static t_list_part *add_partition_i386(t_param_disk *disk_car,t_list_part *list_
   return list_part;
 }
 
-static void set_next_status_i386(const t_param_disk *disk_car, t_partition *partition)
+static void set_next_status_i386(const disk_t *disk_car, partition_t *partition)
 {
   if(partition->status==STATUS_LOG)
     partition->status=STATUS_DELETED;
@@ -1289,7 +1299,7 @@ static void set_next_status_i386(const t_param_disk *disk_car, t_partition *part
     partition->status=STATUS_DELETED;
 }
 
-static void set_prev_status_i386(const t_param_disk *disk_car, t_partition *partition)
+static void set_prev_status_i386(const disk_t *disk_car, partition_t *partition)
 {
   if(partition->status==STATUS_DELETED)
     partition->status=STATUS_LOG;
@@ -1299,7 +1309,7 @@ static void set_prev_status_i386(const t_param_disk *disk_car, t_partition *part
     partition->status--;
 }
 
-static int set_part_type_i386(t_partition *partition, unsigned int part_type)
+static int set_part_type_i386(partition_t *partition, unsigned int part_type)
 {
   if(part_type!=P_NO_OS && part_type <= 255 && is_extended(part_type)==0)
   {
@@ -1309,12 +1319,12 @@ static int set_part_type_i386(t_partition *partition, unsigned int part_type)
   return 1;
 }
 
-static int is_part_known_i386(const t_partition *partition)
+static int is_part_known_i386(const partition_t *partition)
 {
   return (partition->part_type_i386!=P_NO_OS && partition->part_type_i386!=P_UNK);
 }
 
-static void init_structure_i386(const t_param_disk *disk_car,t_list_part *list_part, const int debug)
+static void init_structure_i386(const disk_t *disk_car,list_part_t *list_part, const int debug)
 {
   /* Reconstruit une structure 
    * nbr_prim nombre de partition primaire
@@ -1322,23 +1332,26 @@ static void init_structure_i386(const t_param_disk *disk_car,t_list_part *list_p
    * nbr_log_block : nombre de block de partition etendu
    *                    devrait etre 0 ou 1 */
   unsigned int nbr_prim=0, nbr_log_block=0;
-  t_list_part *element;
-  t_list_part *end_log_block=NULL;
-  t_list_part *end_biggest_log_block=NULL;
+  unsigned int vista_partition=0;
   unsigned int log_block_size=0,biggest_log_block_size=0;
-  t_list_part *new_list_part=NULL;
+  list_part_t *element;
+  list_part_t *end_log_block=NULL;
+  list_part_t *end_biggest_log_block=NULL;
+  list_part_t *new_list_part=NULL;
   /* Create new list */
   for(element=list_part;element!=NULL;element=element->next)
     element->to_be_removed=0;
   for(element=list_part;element!=NULL;element=element->next)
   {
-    t_list_part *element2;
+    list_part_t *element2;
     if(element->part->arch!=NULL && element->part->arch!=disk_car->arch)
     {
       element->to_be_removed=1;
     }
     else
     {
+      if(element->part->part_offset%(2048*512)==0 && element->part->part_size%(2048*512)==0)
+	vista_partition=1;
       for(element2=element->next;element2!=NULL;element2=element2->next)
 	if(element->part->part_offset+element->part->part_size-1 >= element2->part->part_offset)
 	{
@@ -1383,34 +1396,53 @@ static void init_structure_i386(const t_param_disk *disk_car,t_list_part *list_p
     nbr_log_block++;
   }
   if(debug>1)
-    ecrit_rapport("\nRes: nbr_prim %u, nbr_log_block %u\n", nbr_prim, nbr_log_block);
-  /* Set primary, extended, logical */
-  if(nbr_prim+nbr_log_block<=4)
+    log_info("\nRes: nbr_prim %u, nbr_log_block %u, vista_partition=%u\n", nbr_prim, nbr_log_block, vista_partition);
+/* Set primary, extended, logical */
+  if(vista_partition==0 && nbr_prim+nbr_log_block<=4)
   {
     int set_prim_bootable_done=0;
-    for(element=end_biggest_log_block;element&&can_be_ext(disk_car,element->part);element=element->prev)
+    for(element=end_biggest_log_block;element!=NULL && can_be_ext(disk_car,element->part);element=element->prev)
     {
-/*     ecrit_rapport("%p %p %p %d\n",element,element->prev,element->next,element->part->status); */
       element->part->status=STATUS_LOG;
     }
     for(element=new_list_part;element!=NULL;element=element->next)
     {
       if(element->part->status!=STATUS_LOG)
       {
-	if(set_prim_bootable_done)
-	  element->part->status=STATUS_PRIM;
-	else
+	/* The first primary partition is bootable unless it's a swap */
+	if(set_prim_bootable_done==0 &&
+	    element->part->upart_type!=UP_LINSWAP && element->part->upart_type!=UP_LVM && element->part->upart_type!=UP_LVM2)
 	{
-	  /* The first primary partition is bootable unless it's a swap */
-	  if(element->part->upart_type!=UP_LINSWAP && element->part->upart_type!=UP_LVM && element->part->upart_type!=UP_LVM2)
-	  {
-	    element->part->status=STATUS_PRIM_BOOT;
-	    set_prim_bootable_done=1;
-	  }
+	  element->part->status=STATUS_PRIM_BOOT;
+	  set_prim_bootable_done=1;
 	}
+	else
+	  element->part->status=STATUS_PRIM;
       }
     }
   }
+  if(vista_partition>0 || disk_car->arch->test_structure(new_list_part))
+  { /* Handle Vista partition */
+    unsigned int i;
+    int set_prim_bootable_done=0;
+    for(element=new_list_part,i=0;element!=NULL;element=element->next,i++)
+    {
+      if(i<3)
+      {
+	/* The first primary partition is bootable unless it's a swap */
+	if(set_prim_bootable_done==0 &&
+	    element->part->upart_type!=UP_LINSWAP && element->part->upart_type!=UP_LVM && element->part->upart_type!=UP_LVM2)
+	{
+	  element->part->status=STATUS_PRIM_BOOT;
+	  set_prim_bootable_done=1;
+	}
+	else
+	  element->part->status=STATUS_PRIM;
+      }
+      else
+	element->part->status=STATUS_LOG;
+    }
+  }
 #ifdef DEBUG
   check_list_part(new_list_part);
 #endif
@@ -1421,7 +1453,7 @@ static void init_structure_i386(const t_param_disk *disk_car,t_list_part *list_p
   }
   {
     /* free */
-    t_list_part *new_element;
+    list_part_t *new_element;
     for(element=new_list_part;element!=NULL;element=new_element)
     {
       new_element=element->next;
@@ -1433,7 +1465,7 @@ static void init_structure_i386(const t_param_disk *disk_car,t_list_part *list_p
 #endif
 }
 
-static int erase_list_part_i386(t_param_disk *disk_car)
+static int erase_list_part_i386(disk_t *disk_car)
 {
   unsigned char buffer[DEFAULT_SECTOR_SIZE];
   if(disk_car->read(disk_car,DEFAULT_SECTOR_SIZE, buffer, (uint64_t)0))
@@ -1449,7 +1481,7 @@ static int erase_list_part_i386(t_param_disk *disk_car)
   return 0;
 }
 
-static int check_part_i386(t_param_disk *disk_car,const int debug,t_partition *partition, const int saveheader)
+static int check_part_i386(disk_t *disk_car,const int debug,partition_t *partition, const int saveheader)
 {
   int ret=0;
   switch(partition->part_type_i386)
@@ -1535,12 +1567,14 @@ static int check_part_i386(t_param_disk *disk_car,const int debug,t_partition *p
     case P_EXTENDED:
     case P_EXTENDX:
     case P_LINUXEXTENDX:
+      break;
     case P_NETWARE:
+      /* res=check_netware(disk_car, partition, debug); */
       break;
     default:
       if(debug>0)
       {
-	ecrit_rapport("check_part_i386 %u type %02X: no test\n",partition->order,partition->part_type_i386);
+	log_warning("check_part_i386 %u type %02X: no test\n",partition->order,partition->part_type_i386);
       }
       if(saveheader>0)
       {
@@ -1550,7 +1584,7 @@ static int check_part_i386(t_param_disk *disk_car,const int debug,t_partition *p
   }
   if(ret!=0)
   {
-    ecrit_rapport("check_part_i386 failed for partition type %02X\n", partition->part_type_i386);
+    log_error("check_part_i386 failed for partition type %02X\n", partition->part_type_i386);
     aff_part_buffer(AFF_PART_ORDER,disk_car,partition);
     if(saveheader>0)
     {
@@ -1569,7 +1603,7 @@ static const char *get_partition_name_i386_aux(const unsigned int part_type_i386
   return NULL;
 }
 
-static const char *get_partition_name_i386(const t_partition *partition)
+static const char *get_partition_name_i386(const partition_t *partition)
 {
   return get_partition_name_i386_aux(partition->part_type_i386);
 }
