@@ -2,7 +2,7 @@
 
     File: partnone.c
 
-    Copyright (C) 1998-2005 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 1998-2007 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -61,20 +61,21 @@
 #include "swap.h"
 #include "ufs.h"
 #include "xfs.h"
+#include "log.h"
 
-static int check_part_none(t_param_disk *disk_car, const int debug,t_partition *partition,const int saveheader);
-static int get_geometry_from_nonembr(const unsigned char *buffer, const int debug, t_CHS *geometry);
-static t_list_part *read_part_none(t_param_disk *disk_car, const int debug, const int saveheader);
-static t_list_part *init_part_order_none(const t_param_disk *disk_car, t_list_part *list_part);
-static t_list_part *add_partition_none(t_param_disk *disk_car,t_list_part *list_part, const int debug, char **current_cmd);
-static void set_next_status_none(const t_param_disk *disk_car, t_partition *partition);
-static int test_structure_none(t_list_part *list_part);
-static int set_part_type_none(t_partition *partition, unsigned int part_type);
-static int is_part_known_none(const t_partition *partition);
-static void init_structure_none(const t_param_disk *disk_car,t_list_part *list_part, const int debug);
-static const char *get_partition_name_none(const t_partition *partition);
+static int check_part_none(disk_t *disk_car, const int debug,partition_t *partition,const int saveheader);
+static int get_geometry_from_nonembr(const unsigned char *buffer, const int debug, CHS_t *geometry);
+static list_part_t *read_part_none(disk_t *disk_car, const int debug, const int saveheader);
+static list_part_t *init_part_order_none(const disk_t *disk_car, list_part_t *list_part);
+static list_part_t *add_partition_none(disk_t *disk_car,list_part_t *list_part, const int debug, char **current_cmd);
+static void set_next_status_none(const disk_t *disk_car, partition_t *partition);
+static int test_structure_none(list_part_t *list_part);
+static int set_part_type_none(partition_t *partition, unsigned int part_type);
+static int is_part_known_none(const partition_t *partition);
+static void init_structure_none(const disk_t *disk_car,list_part_t *list_part, const int debug);
+static const char *get_partition_name_none(const partition_t *partition);
 static const char *get_partition_name_none_aux(const unsigned int part_type_none);
-static unsigned int get_part_type_none(const t_partition *partition);
+static unsigned int get_part_type_none(const partition_t *partition);
 
 static const struct systypes none_sys_types[] = {
   {UP_BEOS,	"BeFS"},
@@ -115,7 +116,7 @@ static const struct systypes none_sys_types[] = {
   { 0,NULL }
 };
 
-t_arch_fnct arch_none=
+arch_fnct_t arch_none=
 {
   .part_name="None",
   .part_name_option="partition_none",
@@ -138,16 +139,13 @@ t_arch_fnct arch_none=
   .get_part_type=get_part_type_none
 };
 
-static unsigned int get_part_type_none(const t_partition *partition)
+static unsigned int get_part_type_none(const partition_t *partition)
 {
   return partition->upart_type;
 }
 
-int get_geometry_from_nonembr(const unsigned char *buffer, const int debug, t_CHS *geometry)
+int get_geometry_from_nonembr(const unsigned char *buffer, const int debug, CHS_t *geometry)
 {
-  geometry->cylinder=0;
-  geometry->head=0;
-  geometry->sector=0;
   {
     /* Ugly hack to get geometry from FAT and NTFS */
     const struct fat_boot_sector *fat_header=(const struct fat_boot_sector *)buffer;
@@ -164,12 +162,12 @@ int get_geometry_from_nonembr(const unsigned char *buffer, const int debug, t_CH
   return 0;
 }
 
-t_list_part *read_part_none(t_param_disk *disk_car, const int debug, const int saveheader)
+list_part_t *read_part_none(disk_t *disk_car, const int debug, const int saveheader)
 {
   unsigned char *buffer_disk;
-  t_list_part *list_part;
-  t_partition *partition;
-  t_partition *new_partition;
+  list_part_t *list_part;
+  partition_t *partition;
+  partition_t *new_partition;
   int res;
   new_partition=partition_new();
   partition_reset(new_partition);
@@ -193,7 +191,7 @@ t_list_part *read_part_none(t_param_disk *disk_car, const int debug, const int s
     res=search_type_0(buffer_disk,disk_car,partition,debug,0);
   free(buffer_disk);
   if(res>0)
-  { /* limited dup_t_partition */
+  { /* limited dup_partition_t */
     new_partition->boot_sector=partition->boot_sector;
     new_partition->upart_type=partition->upart_type;
     strncpy(new_partition->info,partition->info,sizeof(new_partition->info));
@@ -208,46 +206,46 @@ t_list_part *read_part_none(t_param_disk *disk_car, const int debug, const int s
   return list_part;
 }
 
-static t_list_part *init_part_order_none(const t_param_disk *disk_car, t_list_part *list_part)
+static list_part_t *init_part_order_none(const disk_t *disk_car, list_part_t *list_part)
 {
   return list_part;
 }
 
-static t_list_part *add_partition_none(t_param_disk *disk_car,t_list_part *list_part, const int debug, char **current_cmd)
+static list_part_t *add_partition_none(disk_t *disk_car,list_part_t *list_part, const int debug, char **current_cmd)
 {
   return list_part;
 }
 
-static void set_next_status_none(const t_param_disk *disk_car, t_partition *partition)
+static void set_next_status_none(const disk_t *disk_car, partition_t *partition)
 {
 }
 
-static int test_structure_none(t_list_part *list_part)
+static int test_structure_none(list_part_t *list_part)
 {
   return 0;
 }
 
-static int set_part_type_none(t_partition *partition, unsigned int part_type)
+static int set_part_type_none(partition_t *partition, unsigned int part_type)
 {
   partition->upart_type=part_type;
   return 0;
 }
 
-static int is_part_known_none(const t_partition *partition)
+static int is_part_known_none(const partition_t *partition)
 {
   return 1;
 }
 
-static void init_structure_none(const t_param_disk *disk_car,t_list_part *list_part, const int debug)
+static void init_structure_none(const disk_t *disk_car,list_part_t *list_part, const int debug)
 {
-  t_list_part *element;
+  list_part_t *element;
   for(element=list_part;element!=NULL;element=element->next)
   {
     element->part->status=STATUS_PRIM;
   }
 }
 
-static int check_part_none(t_param_disk *disk_car,const int debug,t_partition *partition, const int saveheader)
+static int check_part_none(disk_t *disk_car,const int debug,partition_t *partition, const int saveheader)
 {
   int ret=0;
   switch(partition->upart_type)
@@ -341,7 +339,7 @@ static int check_part_none(t_param_disk *disk_car,const int debug,t_partition *p
     case UP_UNK:
       if(debug>0)
       {
-	ecrit_rapport("check_part_none %u type %02X: no test\n",partition->order,partition->upart_type);
+	log_info("check_part_none %u type %02X: no test\n",partition->order,partition->upart_type);
       }
       break;
   }
@@ -357,7 +355,7 @@ static const char *get_partition_name_none_aux(const unsigned int part_type_none
   return NULL;
 }
 
-static const char *get_partition_name_none(const t_partition *partition)
+static const char *get_partition_name_none(const partition_t *partition)
 {
   return get_partition_name_none_aux(partition->upart_type);
 }
