@@ -2,7 +2,7 @@
 
     File: partsun.c
 
-    Copyright (C) 1998-2005 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 1998-2007 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -39,6 +39,7 @@
 //#include "analyse.h"
 #include "lang.h"
 #include "intrf.h"
+#include "intrfn.h"
 #include "chgtype.h"
 #include "sun.h"
 #include "swap.h"
@@ -55,21 +56,22 @@
 #include "cramfs.h"
 #include "xfs.h"
 #include "ufs.h"
+#include "log.h"
 
-static int check_part_sun(t_param_disk *disk_car, const int debug,t_partition *partition,const int saveheader);
-static int get_geometry_from_sunmbr(const unsigned char *buffer, const int debug, t_CHS *geometry);
-static t_list_part *read_part_sun(t_param_disk *disk_car, const int debug, const int saveheader);
-static int write_part_sun(t_param_disk *disk_car, const t_list_part *list_part, const int ro , const int debug, const int align);
-static t_list_part *init_part_order_sun(const t_param_disk *disk_car, t_list_part *list_part);
-static t_list_part *add_partition_sun(t_param_disk *disk_car,t_list_part *list_part, const int debug, char **current_cmd);
-static void set_next_status_sun(const t_param_disk *disk_car, t_partition *partition);
-static int test_structure_sun(t_list_part *list_part);
-static int set_part_type_sun(t_partition *partition, unsigned int part_type_sun);
-static int is_part_known_sun(const t_partition *partition);
-static void init_structure_sun(const t_param_disk *disk_car,t_list_part *list_part, const int debug);
-static const char *get_partition_name_sun(const t_partition *partition);
+static int check_part_sun(disk_t *disk_car, const int debug,partition_t *partition,const int saveheader);
+static int get_geometry_from_sunmbr(const unsigned char *buffer, const int debug, CHS_t *geometry);
+static list_part_t *read_part_sun(disk_t *disk_car, const int debug, const int saveheader);
+static int write_part_sun(disk_t *disk_car, const list_part_t *list_part, const int ro , const int debug, const int align);
+static list_part_t *init_part_order_sun(const disk_t *disk_car, list_part_t *list_part);
+static list_part_t *add_partition_sun(disk_t *disk_car,list_part_t *list_part, const int debug, char **current_cmd);
+static void set_next_status_sun(const disk_t *disk_car, partition_t *partition);
+static int test_structure_sun(list_part_t *list_part);
+static int set_part_type_sun(partition_t *partition, unsigned int part_type_sun);
+static int is_part_known_sun(const partition_t *partition);
+static void init_structure_sun(const disk_t *disk_car,list_part_t *list_part, const int debug);
+static const char *get_partition_name_sun(const partition_t *partition);
 static const char *get_partition_name_sun_aux(const unsigned int part_type_sun);
-static unsigned int get_part_type_sun(const t_partition *partition);
+static unsigned int get_part_type_sun(const partition_t *partition);
 
 static const struct systypes sun_sys_types[] = {
   {0x00,	 "Empty"        },
@@ -90,7 +92,7 @@ static const struct systypes sun_sys_types[] = {
   {0, NULL }
 };
 
-t_arch_fnct arch_sun=
+arch_fnct_t arch_sun=
 {
   .part_name="Sun",
   .part_name_option="partition_sun",
@@ -113,33 +115,33 @@ t_arch_fnct arch_sun=
   .get_part_type=get_part_type_sun
 };
 
-static unsigned int get_part_type_sun(const t_partition *partition)
+static unsigned int get_part_type_sun(const partition_t *partition)
 {
   return partition->part_type_sun;
 }
 
-int get_geometry_from_sunmbr(const unsigned char *buffer, const int debug, t_CHS *geometry)
+int get_geometry_from_sunmbr(const unsigned char *buffer, const int debug, CHS_t *geometry)
 {
   const sun_partition *sunlabel=(const sun_partition*)buffer;
   if(debug>1)
   {
-    ecrit_rapport("get_geometry_from_sunmbr\n");
+    log_trace("get_geometry_from_sunmbr\n");
   }
   geometry->cylinder=0;
   geometry->head=be16(sunlabel->ntrks)-1;
   geometry->sector=be16(sunlabel->nsect);
   if(geometry->sector>0)
   {
-    ecrit_rapport("Geometry from SUN MBR: head=%u sector=%u\n",geometry->head+1,geometry->sector);
+    log_info("Geometry from SUN MBR: head=%u sector=%u\n",geometry->head+1,geometry->sector);
   }
   return 0;
 }
 
-t_list_part *read_part_sun(t_param_disk *disk_car, const int debug, const int saveheader)
+list_part_t *read_part_sun(disk_t *disk_car, const int debug, const int saveheader)
 {
   unsigned char buffer[DEFAULT_SECTOR_SIZE];
   sun_partition *sunlabel=(sun_partition*)&buffer;
-  t_list_part *new_list_part=NULL;
+  list_part_t *new_list_part=NULL;
   unsigned int i;
   aff_buffer(BUFFER_RESET,"Q");
   if(disk_car->read(disk_car,DEFAULT_SECTOR_SIZE, buffer, (uint64_t)0))
@@ -158,7 +160,7 @@ t_list_part *read_part_sun(t_param_disk *disk_car, const int debug, const int sa
 	 && sunlabel->infos[i].id > 0
 	 && sunlabel->infos[i].id != PSUN_WHOLE_DISK)
      {
-       t_partition *new_partition=partition_new();
+       partition_t *new_partition=partition_new();
        partition_reset(new_partition);
        new_partition->order=i;
        new_partition->part_type_sun=sunlabel->infos[i].id;
@@ -173,7 +175,7 @@ t_list_part *read_part_sun(t_param_disk *disk_car, const int debug, const int sa
   return new_list_part;
 }
 
-static int write_part_sun(t_param_disk *disk_car, const t_list_part *list_part, const int ro, const int debug, const int align)
+static int write_part_sun(disk_t *disk_car, const list_part_t *list_part, const int ro, const int debug, const int align)
 { /* TODO: Implement it */
   if(ro==0)
   {
@@ -182,11 +184,11 @@ static int write_part_sun(t_param_disk *disk_car, const t_list_part *list_part,
   return 0;
 }
 
-static t_list_part *init_part_order_sun(const t_param_disk *disk_car, t_list_part *list_part)
+static list_part_t *init_part_order_sun(const disk_t *disk_car, list_part_t *list_part)
 {
   int nbr_prim=0;
-  t_partition *new_partition;
-  t_list_part *element;
+  partition_t *new_partition;
+  list_part_t *element;
   for(element=list_part;element!=NULL;element=element->next)
   {
     switch(element->part->status)
@@ -198,7 +200,7 @@ static t_list_part *init_part_order_sun(const t_param_disk *disk_car, t_list_par
 	element->part->order=nbr_prim++;
 	break;
       default:
-	ecrit_rapport("init_part_order_sun: severe error\n");
+	log_critical("init_part_order_sun: severe error\n");
 	break;
     }
   }
@@ -211,10 +213,10 @@ static t_list_part *init_part_order_sun(const t_param_disk *disk_car, t_list_par
   return insert_new_partition(list_part, new_partition);
 }
 
-static t_list_part *add_partition_sun(t_param_disk *disk_car,t_list_part *list_part, const int debug, char **current_cmd)
+static list_part_t *add_partition_sun(disk_t *disk_car,list_part_t *list_part, const int debug, char **current_cmd)
 {
-  t_CHS start,end;
-  t_partition *new_partition=partition_new();
+  CHS_t start,end;
+  partition_t *new_partition=partition_new();
   int position=0;
   start.cylinder=0;
   start.head=0;
@@ -274,7 +276,7 @@ static t_list_part *add_partition_sun(t_param_disk *disk_car,t_list_part *list_p
   }
   if((CHS2offset(disk_car,&end)>new_partition->part_offset)&& new_partition->part_type_sun>0)
   {
-    t_list_part *new_list_part=insert_new_partition(list_part, new_partition);
+    list_part_t *new_list_part=insert_new_partition(list_part, new_partition);
     new_partition->status=STATUS_PRIM;
     if(test_structure_sun(list_part)!=0)
     {
@@ -286,7 +288,7 @@ static t_list_part *add_partition_sun(t_param_disk *disk_car,t_list_part *list_p
   return list_part;
 }
 
-static void set_next_status_sun(const t_param_disk *disk_car, t_partition *partition)
+static void set_next_status_sun(const disk_t *disk_car, partition_t *partition)
 {
   if(partition->status==STATUS_DELETED)
     partition->status=STATUS_PRIM;
@@ -294,11 +296,11 @@ static void set_next_status_sun(const t_param_disk *disk_car, t_partition *parti
     partition->status=STATUS_DELETED;
 }
 
-static int test_structure_sun(t_list_part *list_part)
+static int test_structure_sun(list_part_t *list_part)
 { /* Return 1 if bad*/
-  t_list_part *new_list_part=NULL;
-  t_list_part *element;
-  t_list_part *new_element;
+  list_part_t *new_list_part=NULL;
+  list_part_t *element;
+  list_part_t *new_element;
   int res=0;
   /* Sort list_part in new_list_part */
   for(element=list_part;element!=NULL;element=element->next)
@@ -323,7 +325,7 @@ static int test_structure_sun(t_list_part *list_part)
   return res;
 }
 
-static int set_part_type_sun(t_partition *partition, unsigned int part_type_sun)
+static int set_part_type_sun(partition_t *partition, unsigned int part_type_sun)
 {
   if(part_type_sun>0 && part_type_sun <= 255)
   {
@@ -333,22 +335,22 @@ static int set_part_type_sun(t_partition *partition, unsigned int part_type_sun)
   return 1;
 }
 
-static int is_part_known_sun(const t_partition *partition)
+static int is_part_known_sun(const partition_t *partition)
 {
   return (partition->part_type_sun!=PSUN_UNK);
 }
 
-static void init_structure_sun(const t_param_disk *disk_car,t_list_part *list_part, const int debug)
+static void init_structure_sun(const disk_t *disk_car,list_part_t *list_part, const int debug)
 {
-  t_list_part *element;
-  t_list_part *new_list_part=NULL;
+  list_part_t *element;
+  list_part_t *new_list_part=NULL;
   /* Create new list */
   for(element=list_part;element!=NULL;element=element->next)
     element->to_be_removed=0;
   for(element=list_part;element!=NULL;element=element->next)
   {
     int to_be_removed=0;
-    t_list_part *element2;
+    list_part_t *element2;
     for(element2=element->next;element2!=NULL;element2=element2->next)
       if(element->part->part_offset+element->part->part_size-1 >= element2->part->part_offset)
       {
@@ -372,7 +374,7 @@ static void init_structure_sun(const t_param_disk *disk_car,t_list_part *list_pa
   }
   {
     /* free */
-    t_list_part *new_element;
+    list_part_t *new_element;
     for(element=new_list_part;element!=NULL;element=new_element)
     {
       new_element=element->next;
@@ -384,7 +386,7 @@ static void init_structure_sun(const t_param_disk *disk_car,t_list_part *list_pa
 #endif
 }
 
-static int check_part_sun(t_param_disk *disk_car,const int debug,t_partition *partition, const int saveheader)
+static int check_part_sun(disk_t *disk_car,const int debug,partition_t *partition, const int saveheader)
 {
   int ret=0;
   switch(partition->part_type_sun)
@@ -426,13 +428,13 @@ static int check_part_sun(t_param_disk *disk_car,const int debug,t_partition *pa
     default:
       if(debug>0)
       {
-	ecrit_rapport("check_part_sun %u type %02X: no test\n",partition->order,partition->part_type_sun);
+	log_info("check_part_sun %u type %02X: no test\n",partition->order,partition->part_type_sun);
       }
       break;
   }
   if(ret!=0)
   {
-    ecrit_rapport("check_part_sun failed for partition type %02X\n", partition->part_type_sun);
+    log_error("check_part_sun failed for partition type %02X\n", partition->part_type_sun);
     aff_part_buffer(AFF_PART_ORDER,disk_car,partition);
     if(saveheader>0)
     {
@@ -451,7 +453,7 @@ static const char *get_partition_name_sun_aux(const unsigned int part_type_sun)
   return NULL;
 }
 
-static const char *get_partition_name_sun(const t_partition *partition)
+static const char *get_partition_name_sun(const partition_t *partition)
 {
   return get_partition_name_sun_aux(partition->part_type_sun);
 }
