@@ -2,7 +2,7 @@
 
     File: rfs.c
 
-    Copyright (C) 1998-2006 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 1998-2007 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -34,14 +34,15 @@
 #include "common.h"
 #include "rfs.h"
 #include "fnctdsk.h"
-#include "intrf.h"
-static int set_rfs_info(const t_param_disk *disk_car, const struct reiserfs_super_block *sb,t_partition *partition, const int debug, const int dump_ind);
-static int test_rfs(const t_param_disk *disk_car, const struct reiserfs_super_block *sb,t_partition *partition,const int debug, const int dump_ind);
+#include "log.h"
 
-static int test_rfs4(const t_param_disk *disk_car, const struct reiser4_master_sb*sb,t_partition *partition,const int debug, const int dump_ind);
-static int set_rfs4_info(const t_param_disk *disk_car, const struct reiser4_master_sb*sb,t_partition *partition, const int debug, const int dump_ind);
+static int set_rfs_info(const disk_t *disk_car, const struct reiserfs_super_block *sb,partition_t *partition, const int debug, const int dump_ind);
+static int test_rfs(const disk_t *disk_car, const struct reiserfs_super_block *sb,partition_t *partition,const int debug, const int dump_ind);
 
-int check_rfs(t_param_disk *disk_car,t_partition *partition,const int debug)
+static int test_rfs4(const disk_t *disk_car, const struct reiser4_master_sb*sb,partition_t *partition,const int debug, const int dump_ind);
+static int set_rfs4_info(const disk_t *disk_car, const struct reiser4_master_sb*sb,partition_t *partition, const int debug, const int dump_ind);
+
+int check_rfs(disk_t *disk_car,partition_t *partition,const int debug)
 {
   unsigned char *buffer=(unsigned char*)MALLOC(REISERFS_SUPER_BLOCK_SIZE);
   if(disk_car->read(disk_car,REISERFS_SUPER_BLOCK_SIZE, buffer, partition->part_offset+128*512)!=0) /* 64k offset */
@@ -65,7 +66,7 @@ int check_rfs(t_param_disk *disk_car,t_partition *partition,const int debug)
   return 1;
 }
 
-static int test_rfs(const t_param_disk *disk_car, const struct reiserfs_super_block *sb,t_partition *partition,const int debug, const int dump_ind)
+static int test_rfs(const disk_t *disk_car, const struct reiserfs_super_block *sb,partition_t *partition,const int debug, const int dump_ind)
 {
   if (memcmp(sb->s_magic,REISERFS_SUPER_MAGIC,sizeof(REISERFS_SUPER_MAGIC)) == 0)
   {
@@ -84,7 +85,10 @@ static int test_rfs(const t_param_disk *disk_car, const struct reiserfs_super_bl
     else
       return 1;
   if(debug>0)
-    ecrit_rapport("\nReiserFS Marker at %u/%u/%u\n", offset2cylinder(disk_car,partition->part_offset),offset2head(disk_car,partition->part_offset),offset2sector(disk_car,partition->part_offset));
+    log_info("\nReiserFS Marker at %u/%u/%u\n",
+	offset2cylinder(disk_car,partition->part_offset),
+	offset2head(disk_car,partition->part_offset),
+	offset2sector(disk_car,partition->part_offset));
   /*
    * sanity checks.
    */
@@ -111,7 +115,7 @@ static int test_rfs(const t_param_disk *disk_car, const struct reiserfs_super_bl
   return 0;
 }
 
-static int test_rfs4(const t_param_disk *disk_car, const struct reiser4_master_sb *sb,t_partition *partition,const int debug, const int dump_ind)
+static int test_rfs4(const disk_t *disk_car, const struct reiser4_master_sb *sb,partition_t *partition,const int debug, const int dump_ind)
 {
   if (memcmp(sb->magic,REISERFS4_SUPER_MAGIC,sizeof(REISERFS4_SUPER_MAGIC)) == 0)
   {
@@ -120,7 +124,7 @@ static int test_rfs4(const t_param_disk *disk_car, const struct reiser4_master_s
   else
     return 1;
   if(debug>0)
-    ecrit_rapport("\nReiserFS Marker at %u/%u/%u\n", offset2cylinder(disk_car,partition->part_offset),offset2head(disk_car,partition->part_offset),offset2sector(disk_car,partition->part_offset));
+    log_info("\nReiserFS Marker at %u/%u/%u\n", offset2cylinder(disk_car,partition->part_offset),offset2head(disk_car,partition->part_offset),offset2sector(disk_car,partition->part_offset));
   /*
    * sanity checks.
    */
@@ -130,19 +134,19 @@ static int test_rfs4(const t_param_disk *disk_car, const struct reiser4_master_s
   return 0;
 }
 
-int recover_rfs(t_param_disk *disk_car, const struct reiserfs_super_block *sb,t_partition *partition,const int debug, const int dump_ind)
+int recover_rfs(disk_t *disk_car, const struct reiserfs_super_block *sb,partition_t *partition,const int debug, const int dump_ind)
 {
   const struct reiser4_master_sb *sb4=(const struct reiser4_master_sb *)sb;
   if(test_rfs(disk_car,sb,partition,debug,dump_ind)==0)
   {
     if(debug>0 || dump_ind!=0)
     {
-      ecrit_rapport("\nrecover_rfs\n");
-      ecrit_rapport("block_count=%u\n",(unsigned int)le32(sb->s_block_count));
-      ecrit_rapport("block_size=%u\n",le16(sb->s_blocksize));
+      log_info("\nrecover_rfs\n");
+      log_info("block_count=%u\n",(unsigned int)le32(sb->s_block_count));
+      log_info("block_size=%u\n",le16(sb->s_blocksize));
       if(dump_ind!=0)
       {
-	dump(stdscr,sb,DEFAULT_SECTOR_SIZE);
+	dump_log(sb,DEFAULT_SECTOR_SIZE);
       }
     }
     partition->part_size = (uint64_t)le32(sb->s_block_count) * le16(sb->s_blocksize);
@@ -157,12 +161,12 @@ int recover_rfs(t_param_disk *disk_car, const struct reiserfs_super_block *sb,t_
     const struct format40_super *fmt40_super=(const struct format40_super *)((const char*)sb4+le16(sb4->blocksize));
     if(debug>0 || dump_ind!=0)
     {
-      ecrit_rapport("\nrecover_rfs\n");
-      ecrit_rapport("block_count=%lu\n",(unsigned long int)le64(fmt40_super->sb_block_count));
-      ecrit_rapport("block_size=%u\n",le16(sb4->blocksize));
+      log_info("\nrecover_rfs\n");
+      log_info("block_count=%lu\n",(unsigned long int)le64(fmt40_super->sb_block_count));
+      log_info("block_size=%u\n",le16(sb4->blocksize));
       if(dump_ind!=0)
       {
-	dump(stdscr,sb,DEFAULT_SECTOR_SIZE);
+	dump_log(sb,DEFAULT_SECTOR_SIZE);
       }
     }
     partition->part_size = (uint64_t)le64(fmt40_super->sb_block_count) * le16(sb4->blocksize);
@@ -175,7 +179,7 @@ int recover_rfs(t_param_disk *disk_car, const struct reiserfs_super_block *sb,t_
   return 1;
 }
 
-static int set_rfs_info(const t_param_disk *disk_car,const struct reiserfs_super_block *sb,t_partition *partition, const int debug, const int dump_ind)
+static int set_rfs_info(const disk_t *disk_car,const struct reiserfs_super_block *sb,partition_t *partition, const int debug, const int dump_ind)
 {
   partition->name[0]='\0';
   partition->info[0]='\0';
@@ -207,7 +211,7 @@ static int set_rfs_info(const t_param_disk *disk_car,const struct reiserfs_super
   return 0;
 }
 
-static int set_rfs4_info(const t_param_disk *disk_car,const struct reiser4_master_sb *sb,t_partition *partition, const int debug, const int dump_ind)
+static int set_rfs4_info(const disk_t *disk_car,const struct reiser4_master_sb *sb,partition_t *partition, const int debug, const int dump_ind)
 {
   partition->name[0]='\0';
   partition->info[0]='\0';
