@@ -2,7 +2,7 @@
 
     File: rfs_dir.c
 
-    Copyright (C) 1998-2006 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 1998-2007 Christophe GRENIER <grenier@cgsecurity.org>
     Some code from Yury Umanets <torque@ukrpost.net>
   
     This software is free software; you can redistribute it and/or modify
@@ -23,7 +23,8 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
- 
+
+#include <stdio.h>
 #ifdef HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
@@ -42,6 +43,7 @@
 #include "rfs.h"
 #include "dir.h"
 #include "rfs_dir.h"
+#include "log.h"
 
 #ifdef HAVE_LIBREISERFS
 #include "dal/dal.h"
@@ -53,15 +55,15 @@
 #endif
 #include "reiserfs/reiserfs.h"
 
-struct list_dir_struct {
-	t_file_data *dir_list;
-	t_file_data *current_file;
+struct rfs_dir_struct {
+	file_data_t *dir_list;
+	file_data_t *current_file;
 	reiserfs_fs_t *current_fs;
 	dal_t *dal;
 	int flags;
 };
-static t_file_data *reiser_dir(t_param_disk *disk_car, const t_partition *partition, t_dir_data *dir_data, const unsigned long int cluster);
-static void dir_partition_reiser_close(t_dir_data *dir_data);
+static file_data_t *reiser_dir(disk_t *disk_car, const partition_t *partition, dir_data_t *dir_data, const unsigned long int cluster);
+static void dir_partition_reiser_close(dir_data_t *dir_data);
 
 #ifdef HAVE_STRUCT_DAL_OPS_DEV
 dev_t dal_dev(dal_t *dal) {
@@ -117,8 +119,8 @@ char *dal_error(dal_t *dal) {
 static int file_read(dal_t *dal, void *buff, blk_t block, blk_t count) {
   uint64_t off;
   unsigned int blocklen;
-  t_my_data *my_data=(t_my_data*)dal->data;
-/* ecrit_rapport("reiser file_read(dal=%p,buff=%p,block=%ld, count=%ld)\n",dal,buff,block,count); */
+  my_data_t *my_data=(my_data_t*)dal->data;
+/* log_trace("reiser file_read(dal=%p,buff=%p,block=%ld, count=%ld)\n",dal,buff,block,count); */
   if (!dal || !buff)
     return 0;
 #ifdef HAVE_DAL_T_BLOCK_SIZE
@@ -128,7 +130,7 @@ static int file_read(dal_t *dal, void *buff, blk_t block, blk_t count) {
   off = (uint64_t)block * (uint64_t)dal->blocksize;
   blocklen = count * dal->blocksize;
 #endif
-/* ecrit_rapport("blocklen=%ld\n",blocklen); */
+/* log_debug("blocklen=%ld\n",blocklen); */
   if(my_data->disk_car->read(my_data->disk_car,blocklen,buff,my_data->partition->part_offset+off))
     return 0;
   return 1;
@@ -146,35 +148,39 @@ static int file_write(dal_t *dal, void *buff, blk_t block, blk_t count)
   off = (uint64_t)block * (uint64_t)dal->blocksize;
   blocklen = (uint64_t)count * (uint64_t)dal->blocksize;
 #endif
-  ecrit_rapport("reiser file_write not implemented\n");
-/* if(my_data->disk_car->write(my_data->disk_car,blocklen,buff,my_data->partition->part_offset+off)) */
+#ifdef ENABLE_REISERFS_WRITE
+  if(my_data->disk_car->write(my_data->disk_car,blocklen,buff,my_data->partition->part_offset+off))
     return 0;
-/* return 1; */
+  return 1;
+#else
+  log_info("reiser file_write not implemented\n");
+  return 0;
+#endif
 }
 
 static int file_sync(dal_t *dal)
 {
   if (!dal) return 0;
-/* ecrit_rapport("reiser file_sync\n"); */
+/* log_trace("reiser file_sync\n"); */
   return 1;
 }
 
 static int file_flags(dal_t *dal)
 {
-/* ecrit_rapport("reiser file_flags\n"); */
+/* log_trace("reiser file_flags\n"); */
   if (!dal) return 0;
   return dal->flags;
 }
 
 static int file_equals(dal_t *dal1, dal_t *dal2)
 {
-/* ecrit_rapport("reiser file_equals\n"); */
+/* log_trace("reiser file_equals\n"); */
   if (!dal1 || !dal2)
     return 0;
 /* return !strcmp((char *)dal1->data, (char *)dal2->data); */
   {
-    t_my_data *data1=(t_my_data*)dal1->data;
-    t_my_data *data2=(t_my_data*)dal2->data;
+    my_data_t *data1=(my_data_t*)dal1->data;
+    my_data_t *data2=(my_data_t*)dal2->data;
     return (data1->disk_car==data2->disk_car) && (data1->partition==data2->partition) && (data1->offset==data2->offset);
   }
 }
@@ -182,7 +188,7 @@ static int file_equals(dal_t *dal1, dal_t *dal2)
 #ifdef HAVE_STRUCT_DAL_OPS_DEV
 static int file_stat(dal_t *dal,struct stat *st)
 {
-/* ecrit_rapport("reiser file_stat\n"); */
+/* log_trace("reiser file_stat\n"); */
   if (!dal)
     return 0;
 /* return (unsigned int)st.st_dev; */
@@ -191,7 +197,7 @@ static int file_stat(dal_t *dal,struct stat *st)
 #else
 static unsigned int file_stat(dal_t *dal)
 {
-/* ecrit_rapport("reiser file_stat\n"); */
+/* log_trace("reiser file_stat\n"); */
   if (!dal)
     return 0;
 /* return (unsigned int)st.st_dev; */
@@ -204,8 +210,8 @@ static blk_t   file_len(dal_t *dal) {
 #else
 static count_t file_len(dal_t *dal) {
 #endif
-  t_my_data *my_data=(t_my_data*)dal->data;
-/* ecrit_rapport("reiser file_len\n"); */
+  my_data_t *my_data=(my_data_t*)dal->data;
+/* log_trace("reiser file_len\n"); */
   if (!dal) return 0;
 #ifdef HAVE_DAL_T_BLOCK_SIZE
   return my_data->partition->part_size / dal->block_size;
@@ -228,7 +234,7 @@ static struct dal_ops ops = {
 };
 
 void dal_close(dal_t *dal) {
-/* ecrit_rapport("reiser dal_close\n"); */
+/* log_trace("reiser dal_close\n"); */
 	
 	if (!dal) return;
 	
@@ -239,7 +245,7 @@ void dal_close(dal_t *dal) {
 }
 
 void file_close(dal_t *dal) {
-/* ecrit_rapport("reiser file_close\n"); */
+/* log_trace("reiser file_close\n"); */
 	if (!dal) return;
 	dal_close(dal);
 }
@@ -255,7 +261,7 @@ dal_t *dal_open(struct dal_ops *myops, unsigned blocksize, int flags, void *data
 #endif
 {
 	dal_t *dal;
-/* ecrit_rapport("reiser dal_open\n"); */
+/* log_trace("reiser dal_open\n"); */
 	
 	if (!myops) return NULL;
 	
@@ -323,7 +329,7 @@ int dal_set_blocksize(dal_t *dal, unsigned blocksize) {
 
 int dal_read(dal_t *dal, void *buff, blk_t block, blk_t count) {
 
-/* ecrit_rapport("reiser dal_read\n"); */
+/* log_trace("reiser dal_read\n"); */
 	if (!dal) return 0;
 
 	if (dal->ops->read)
@@ -334,7 +340,7 @@ int dal_read(dal_t *dal, void *buff, blk_t block, blk_t count) {
 
 int dal_write(dal_t *dal, void *buff, blk_t block, blk_t count) {
 
-/* ecrit_rapport("reiser dal_write\n"); */
+/* log_trace("reiser dal_write\n"); */
 	if (!dal) return 0;
 	
 	if (dal->ops->write)
@@ -364,7 +370,7 @@ int dal_flags(dal_t *dal) {
 }
 
 int dal_equals(dal_t *dal1, dal_t *dal2) {
-/* ecrit_rapport("reiserfs dal_equals\n"); */
+/* log_trace("reiserfs dal_equals\n"); */
 	
 	if (!dal1 || !dal2) return 0;
 
@@ -377,7 +383,7 @@ int dal_equals(dal_t *dal1, dal_t *dal2) {
 #if defined(HAVE_STRUCT_DAL_OPS_DEV)
 int dal_stat(dal_t *dal, struct stat *mystat)
 {
-/* ecrit_rapport("reiserfs dal_stat\n"); */
+/* log_trace("reiserfs dal_stat\n"); */
 	if (!dal) return 0;
 	if (dal->ops->stat)
 		return dal->ops->stat(dal,mystat);
@@ -385,7 +391,7 @@ int dal_stat(dal_t *dal, struct stat *mystat)
 }
 #else
 unsigned int dal_stat(dal_t *dal) {
-/* ecrit_rapport("reiserfs dal_stat\n"); */
+/* log_trace("reiserfs dal_stat\n"); */
 	if (!dal) return 0;
 	if (dal->ops->stat)
 		return dal->ops->stat(dal);
@@ -394,7 +400,7 @@ unsigned int dal_stat(dal_t *dal) {
 #endif
 
 blk_t dal_len(dal_t *dal) {
-/* ecrit_rapport("reiserfs dal_len\n"); */
+/* log_trace("reiserfs dal_len\n"); */
 	
 	if (!dal) 
 		return 0;
@@ -405,16 +411,16 @@ blk_t dal_len(dal_t *dal) {
 	return 0;
 }
 
-static t_file_data *reiser_dir(t_param_disk *disk_car, const t_partition *partition, t_dir_data *dir_data, const unsigned long int cluster)
+static file_data_t *reiser_dir(disk_t *disk_car, const partition_t *partition, dir_data_t *dir_data, const unsigned long int cluster)
 {
-  struct list_dir_struct *ls=(struct list_dir_struct*)dir_data->private_dir_data;
+  struct rfs_dir_struct *ls=(struct rfs_dir_struct*)dir_data->private_dir_data;
   reiserfs_dir_t *dir;
   reiserfs_dir_entry_t entry;
   ls->dir_list=NULL;
   ls->current_file=NULL;
   if (!(dir = reiserfs_dir_open(ls->current_fs, dir_data->current_directory))) {
     aff_buffer(BUFFER_ADD,"Couldn't open dir\n");
-    ecrit_rapport("Couldn't open dir\n");
+    log_error("Couldn't open dir\n");
     return NULL;
   }
   while (reiserfs_dir_read(dir, &entry))
@@ -427,7 +433,7 @@ static t_file_data *reiser_dir(t_param_disk *disk_car, const t_partition *partit
     strcat(name,entry.de_name);
     if((entity=reiserfs_object_create(ls->current_fs,name,1)))
     {
-      t_file_data *new_file=MALLOC(sizeof(*new_file));
+      file_data_t *new_file=MALLOC(sizeof(*new_file));
       thislen=(MAX_NAME_LEN(DEFAULT_BLOCK_SIZE)<DIR_NAME_LEN?MAX_NAME_LEN(DEFAULT_BLOCK_SIZE):DIR_NAME_LEN);
       memcpy(new_file->name,entry.de_name,thislen);
       new_file->name[thislen-1]='\0';
@@ -448,22 +454,22 @@ static t_file_data *reiser_dir(t_param_disk *disk_car, const t_partition *partit
   return ls->dir_list;
 }
 
-static void dir_partition_reiser_close(t_dir_data *dir_data)
+static void dir_partition_reiser_close(dir_data_t *dir_data)
 {
-  struct list_dir_struct *ls=(struct list_dir_struct*)dir_data->private_dir_data;
+  struct rfs_dir_struct *ls=(struct rfs_dir_struct*)dir_data->private_dir_data;
   reiserfs_fs_close(ls->current_fs);
   file_close(ls->dal);
   free(ls);
 }
 #endif
 
-int dir_partition_reiser_init(t_param_disk *disk_car, const t_partition *partition, t_dir_data *dir_data, const int debug)
+int dir_partition_reiser_init(disk_t *disk_car, const partition_t *partition, dir_data_t *dir_data, const int debug)
 {
 #ifdef HAVE_LIBREISERFS
   dal_t *dal;
   reiserfs_fs_t *fs;
   reiserfs_path_node_t *leaf;
-  t_my_data *my_data;
+  my_data_t *my_data;
   int32_t offset = 0;
   int error = 0;
   my_data=MALLOC(sizeof(*my_data));
@@ -477,11 +483,11 @@ int dir_partition_reiser_init(t_param_disk *disk_car, const t_partition *partiti
 #endif
   if (!dal)
   {
-    ecrit_rapport("Couldn't open device\n");
+    log_error("Couldn't open device\n");
     free(my_data);
     return -1;
   }
-  /* ecrit_rapport("file_open ok\n"); */
+  /* log_debug("file_open ok\n"); */
 
 #ifdef HAVE_REISERFS_FS_OPEN_FAST
   if (!(fs = reiserfs_fs_open_fast(dal, dal)))
@@ -489,14 +495,14 @@ int dir_partition_reiser_init(t_param_disk *disk_car, const t_partition *partiti
     if (!(fs = reiserfs_fs_open(dal, dal)))
 #endif
     {
-      ecrit_rapport("Couldn't open reiser filesystem %s\n",dal_error(dal));
+      log_error("Couldn't open reiser filesystem %s\n",dal_error(dal));
       /* file_close call free(my_data) */
       file_close(dal);
       return -1;
     }
-  /* ecrit_rapport("reiserfs_fs_open_fast ok\n"); */
+  /* log_debug("reiserfs_fs_open_fast ok\n"); */
   {
-    struct list_dir_struct *ls=(struct list_dir_struct *)MALLOC(sizeof(*ls));
+    struct rfs_dir_struct *ls=(struct rfs_dir_struct *)MALLOC(sizeof(*ls));
     ls->dir_list=NULL;
     ls->current_file=NULL;
     ls->current_fs=fs;
