@@ -20,5 +20,5 @@
 
  */
 
-int dir_partition_reiser_init(t_param_disk *disk_car, const t_partition *partition, t_dir_data *dir_data, const int debug);
+int dir_partition_reiser_init(disk_t *disk_car, const partition_t *partition, dir_data_t *dir_data, const int debug);
 const char*td_reiserfs_version(void);
