@@ -20,16 +20,16 @@
 
  */
 #include "list.h"
-typedef struct backup_disk t_backup_disk;
+typedef struct backup_disk backup_disk_t;
 struct backup_disk
 {
-  struct list_head list;
+  struct td_list_head list;
   time_t my_time;
   char description[128];
-  t_list_part *list_part;
+  list_part_t *list_part;
 };
 
-int save_header(t_param_disk *disk_car,t_partition *partition, const int debug);
-int partition_save(t_param_disk *disk_car, t_list_part *list_part, const int debug);
-t_backup_disk *partition_load(const t_param_disk *disk_car, const int debug);
+int save_header(disk_t *disk_car,partition_t *partition, const int debug);
+int partition_save(disk_t *disk_car, list_part_t *list_part, const int debug);
+backup_disk_t *partition_load(const disk_t *disk_car, const int debug);
 
