@@ -2,7 +2,7 @@
 
     File: sysv.c
 
-    Copyright (C) 2004-2006 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 2004-2007 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@
 #include "common.h"
 #include "sysv.h"
 #include "fnctdsk.h"
-#include "intrf.h"
+#include "log.h"
 
 #define SYSV4_SECTOR_SIZE 512
 #define SYSV4_SBLOCK 8192
@@ -57,10 +57,10 @@
 #define SYSV4_CIGAM_4GB   0x94192305
 
 
-static int set_sysv4_info(const t_param_disk *disk_car, const struct sysv4_super_block *sbd,t_partition *partition, const int debug, const int dump_ind);
-static int test_sysv4(const t_param_disk *disk_car, const struct sysv4_super_block *sbd,t_partition *partition,const int debug, const int dump_ind);
+static int set_sysv4_info(const disk_t *disk_car, const struct sysv4_super_block *sbd,partition_t *partition, const int debug, const int dump_ind);
+static int test_sysv4(const disk_t *disk_car, const struct sysv4_super_block *sbd,partition_t *partition,const int debug, const int dump_ind);
 
-int check_sysv(t_param_disk *disk_car,t_partition *partition,const int debug)
+int check_sysv(disk_t *disk_car,partition_t *partition,const int debug)
 {
   unsigned char *buffer=(unsigned char*)MALLOC(SYSV4_SECTOR_SIZE);
   if(disk_car->read(disk_car,SYSV4_SECTOR_SIZE, buffer, partition->part_offset+0x200)!=0)
@@ -78,7 +78,7 @@ int check_sysv(t_param_disk *disk_car,t_partition *partition,const int debug)
   return 1;
 }
 
-static int test_sysv4(const t_param_disk *disk_car, const struct sysv4_super_block *sbd,t_partition *partition,const int debug, const int dump_ind)
+static int test_sysv4(const disk_t *disk_car, const struct sysv4_super_block *sbd,partition_t *partition,const int debug, const int dump_ind)
 {
   if ((sbd->s_magic== le32(0xfd187e20))||(sbd->s_magic== be32(0xfd187e20)))
   {
@@ -87,20 +87,20 @@ static int test_sysv4(const t_param_disk *disk_car, const struct sysv4_super_blo
   else
     return 1;
   if(debug>0)
-    ecrit_rapport("\nSYSV4 Marker at %u/%u/%u\n", offset2cylinder(disk_car,partition->part_offset),offset2head(disk_car,partition->part_offset),offset2sector(disk_car,partition->part_offset));
+    log_info("\nSYSV4 Marker at %u/%u/%u\n", offset2cylinder(disk_car,partition->part_offset),offset2head(disk_car,partition->part_offset),offset2sector(disk_car,partition->part_offset));
   return 0;
 }
 
-int recover_sysv(t_param_disk *disk_car,  const struct sysv4_super_block *sbd, t_partition *partition,const int debug, const int dump_ind)
+int recover_sysv(disk_t *disk_car,  const struct sysv4_super_block *sbd, partition_t *partition,const int debug, const int dump_ind)
 {
   if(test_sysv4(disk_car,sbd,partition,debug,dump_ind)==0)
   {
     if(debug>0 || dump_ind!=0)
     {
-      ecrit_rapport("\nrecover_sysv4\n");
+      log_info("\nrecover_sysv4\n");
       if(dump_ind!=0)
       {
-	dump(stdscr,sbd,sizeof(*sbd));
+	dump_log(sbd,sizeof(*sbd));
       }
     }
     switch(sbd->s_magic)
@@ -119,7 +119,7 @@ int recover_sysv(t_param_disk *disk_car,  const struct sysv4_super_block *sbd, t
   return 1;
 }
 
-static int set_sysv4_info(const t_param_disk *disk_car,const struct sysv4_super_block *sbd,t_partition *partition, const int debug, const int dump_ind)
+static int set_sysv4_info(const disk_t *disk_car,const struct sysv4_super_block *sbd,partition_t *partition, const int debug, const int dump_ind)
 {
   strncpy(partition->info,"SysV4",sizeof(partition->info));
   set_part_name(partition,sbd->s_fname,sizeof(sbd->s_fname));
