@@ -20,5 +20,5 @@
 
  */
 
-int test_MBR(t_param_disk *disk_car,int debug);
+int test_MBR(disk_t *disk_car,int debug);
 int analyse_file(char *);
