@@ -463,6 +463,6 @@ struct ufs_super_block {
 #define UFS_DYNAMICPOSTBLFMT	1	/* dynamic rotational table format */
 
 
-int check_ufs(t_param_disk *disk_car,t_partition *partition,const int debug);
-int recover_ufs(t_param_disk *disk_car, const struct ufs_super_block *sb, t_partition *partition,const int debug, const int dump_ind);
+int check_ufs(disk_t *disk_car,partition_t *partition,const int debug);
+int recover_ufs(disk_t *disk_car, const struct ufs_super_block *sb, partition_t *partition,const int debug, const int dump_ind);
 
