@@ -2,7 +2,7 @@
 
     File: xfs.c
 
-    Copyright (C) 2004-2006 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 2004-2007 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -34,11 +34,12 @@
 #include "common.h"
 #include "xfs.h"
 #include "fnctdsk.h"
-#include "intrf.h"
-static int set_xfs_info(const t_param_disk *disk_car, const struct xfs_sb *sb,t_partition *partition, const int debug, const int dump_ind);
-static int test_xfs(const t_param_disk *disk_car, const struct xfs_sb *sb,t_partition *partition,const int debug, const int dump_ind);
+#include "log.h"
 
-int check_xfs(t_param_disk *disk_car,t_partition *partition,const int debug)
+static int set_xfs_info(const disk_t *disk_car, const struct xfs_sb *sb,partition_t *partition, const int debug, const int dump_ind);
+static int test_xfs(const disk_t *disk_car, const struct xfs_sb *sb,partition_t *partition,const int debug, const int dump_ind);
+
+int check_xfs(disk_t *disk_car,partition_t *partition,const int debug)
 {
   unsigned char *buffer=(unsigned char*)MALLOC(XFS_SUPERBLOCK_SIZE);
   if(disk_car->read(disk_car,XFS_SUPERBLOCK_SIZE, buffer, partition->part_offset)!=0)
@@ -56,7 +57,7 @@ int check_xfs(t_param_disk *disk_car,t_partition *partition,const int debug)
   return 0;
 }
 
-static int test_xfs(const t_param_disk *disk_car, const struct xfs_sb *sb,t_partition *partition,const int debug, const int dump_ind)
+static int test_xfs(const disk_t *disk_car, const struct xfs_sb *sb,partition_t *partition,const int debug, const int dump_ind)
 {
   if (sb->sb_magicnum==be32(XFS_SB_MAGIC))
   {
@@ -75,7 +76,7 @@ static int test_xfs(const t_param_disk *disk_car, const struct xfs_sb *sb,t_part
 	partition->upart_type = UP_XFS4;
 	break;
       default:
-	ecrit_rapport("Unknown XFS version %x\n",be16(sb->sb_versionnum)& XFS_SB_VERSION_NUMBITS);
+	log_error("Unknown XFS version %x\n",be16(sb->sb_versionnum)& XFS_SB_VERSION_NUMBITS);
 	partition->upart_type = UP_XFS4;
 	break;
     }
@@ -83,20 +84,20 @@ static int test_xfs(const t_param_disk *disk_car, const struct xfs_sb *sb,t_part
   else
     return 1;
   if(debug>0)
-    ecrit_rapport("\nXFS Marker at %u/%u/%u\n", offset2cylinder(disk_car,partition->part_offset),offset2head(disk_car,partition->part_offset),offset2sector(disk_car,partition->part_offset));
+    log_info("\nXFS Marker at %u/%u/%u\n", offset2cylinder(disk_car,partition->part_offset),offset2head(disk_car,partition->part_offset),offset2sector(disk_car,partition->part_offset));
   return 0;
 }
 
-int recover_xfs(t_param_disk *disk_car, const struct xfs_sb *sb,t_partition *partition,const int debug, const int dump_ind)
+int recover_xfs(disk_t *disk_car, const struct xfs_sb *sb,partition_t *partition,const int debug, const int dump_ind)
 {
   if(test_xfs(disk_car,sb,partition,debug,dump_ind)!=0)
     return 1;
   if(debug>0 || dump_ind!=0)
   {
-    ecrit_rapport("\nrecover_xfs\n");
+    log_info("\nrecover_xfs\n");
     if(dump_ind!=0)
     {
-      dump(stdscr,sb,DEFAULT_SECTOR_SIZE);
+      dump_log(sb,DEFAULT_SECTOR_SIZE);
     }
   }
 
@@ -108,7 +109,7 @@ int recover_xfs(t_param_disk *disk_car, const struct xfs_sb *sb,t_partition *par
   return 0;
 }
 
-static int set_xfs_info(const t_param_disk *disk_car,const struct xfs_sb *sb,t_partition *partition, const int debug, const int dump_ind)
+static int set_xfs_info(const disk_t *disk_car,const struct xfs_sb *sb,partition_t *partition, const int debug, const int dump_ind)
 {
   partition->name[0]='\0';
   partition->info[0]='\0';
